# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v1.proto.resources import keyword_plan_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_keyword__plan__pb2
from google.ads.google_ads.v1.proto.services import keyword_plan_service_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2


class KeywordPlanServiceStub(object):
  """Proto file describing the keyword plan service.

  Service to manage keyword plans.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetKeywordPlan = channel.unary_unary(
        '/google.ads.googleads.v1.services.KeywordPlanService/GetKeywordPlan',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.GetKeywordPlanRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_keyword__plan__pb2.KeywordPlan.FromString,
        )
    self.MutateKeywordPlans = channel.unary_unary(
        '/google.ads.googleads.v1.services.KeywordPlanService/MutateKeywordPlans',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.MutateKeywordPlansRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.MutateKeywordPlansResponse.FromString,
        )
    self.GenerateForecastMetrics = channel.unary_unary(
        '/google.ads.googleads.v1.services.KeywordPlanService/GenerateForecastMetrics',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.GenerateForecastMetricsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.GenerateForecastMetricsResponse.FromString,
        )
    self.GenerateHistoricalMetrics = channel.unary_unary(
        '/google.ads.googleads.v1.services.KeywordPlanService/GenerateHistoricalMetrics',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.GenerateHistoricalMetricsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.GenerateHistoricalMetricsResponse.FromString,
        )


class KeywordPlanServiceServicer(object):
  """Proto file describing the keyword plan service.

  Service to manage keyword plans.
  """

  def GetKeywordPlan(self, request, context):
    """Returns the requested plan in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateKeywordPlans(self, request, context):
    """Creates, updates, or removes keyword plans. Operation statuses are
    returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GenerateForecastMetrics(self, request, context):
    """Returns the requested Keyword Plan forecasts.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GenerateHistoricalMetrics(self, request, context):
    """Returns the requested Keyword Plan historical metrics.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_KeywordPlanServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetKeywordPlan': grpc.unary_unary_rpc_method_handler(
          servicer.GetKeywordPlan,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.GetKeywordPlanRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_keyword__plan__pb2.KeywordPlan.SerializeToString,
      ),
      'MutateKeywordPlans': grpc.unary_unary_rpc_method_handler(
          servicer.MutateKeywordPlans,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.MutateKeywordPlansRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.MutateKeywordPlansResponse.SerializeToString,
      ),
      'GenerateForecastMetrics': grpc.unary_unary_rpc_method_handler(
          servicer.GenerateForecastMetrics,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.GenerateForecastMetricsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.GenerateForecastMetricsResponse.SerializeToString,
      ),
      'GenerateHistoricalMetrics': grpc.unary_unary_rpc_method_handler(
          servicer.GenerateHistoricalMetrics,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.GenerateHistoricalMetricsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.GenerateHistoricalMetricsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v1.services.KeywordPlanService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
