# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/enums/conversion_or_adjustment_lag_bucket.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/enums/conversion_or_adjustment_lag_bucket.proto',
  package='google.ads.googleads.v1.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v1.enumsB$ConversionOrAdjustmentLagBucketProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V1.Enums\312\002\035Google\\Ads\\GoogleAds\\V1\\Enums\352\002!Google::Ads::GoogleAds::V1::Enums'),
  serialized_pb=_b('\nMgoogle/ads/googleads_v1/proto/enums/conversion_or_adjustment_lag_bucket.proto\x12\x1dgoogle.ads.googleads.v1.enums\x1a\x1cgoogle/api/annotations.proto\"\xcb\x0c\n#ConversionOrAdjustmentLagBucketEnum\"\xa3\x0c\n\x1f\x43onversionOrAdjustmentLagBucket\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12 \n\x1c\x43ONVERSION_LESS_THAN_ONE_DAY\x10\x02\x12\x1e\n\x1a\x43ONVERSION_ONE_TO_TWO_DAYS\x10\x03\x12 \n\x1c\x43ONVERSION_TWO_TO_THREE_DAYS\x10\x04\x12!\n\x1d\x43ONVERSION_THREE_TO_FOUR_DAYS\x10\x05\x12 \n\x1c\x43ONVERSION_FOUR_TO_FIVE_DAYS\x10\x06\x12\x1f\n\x1b\x43ONVERSION_FIVE_TO_SIX_DAYS\x10\x07\x12 \n\x1c\x43ONVERSION_SIX_TO_SEVEN_DAYS\x10\x08\x12\"\n\x1e\x43ONVERSION_SEVEN_TO_EIGHT_DAYS\x10\t\x12!\n\x1d\x43ONVERSION_EIGHT_TO_NINE_DAYS\x10\n\x12\x1f\n\x1b\x43ONVERSION_NINE_TO_TEN_DAYS\x10\x0b\x12!\n\x1d\x43ONVERSION_TEN_TO_ELEVEN_DAYS\x10\x0c\x12$\n CONVERSION_ELEVEN_TO_TWELVE_DAYS\x10\r\x12&\n\"CONVERSION_TWELVE_TO_THIRTEEN_DAYS\x10\x0e\x12(\n$CONVERSION_THIRTEEN_TO_FOURTEEN_DAYS\x10\x0f\x12*\n&CONVERSION_FOURTEEN_TO_TWENTY_ONE_DAYS\x10\x10\x12(\n$CONVERSION_TWENTY_ONE_TO_THIRTY_DAYS\x10\x11\x12(\n$CONVERSION_THIRTY_TO_FORTY_FIVE_DAYS\x10\x12\x12\'\n#CONVERSION_FORTY_FIVE_TO_SIXTY_DAYS\x10\x13\x12#\n\x1f\x43ONVERSION_SIXTY_TO_NINETY_DAYS\x10\x14\x12 \n\x1c\x41\x44JUSTMENT_LESS_THAN_ONE_DAY\x10\x15\x12\x1e\n\x1a\x41\x44JUSTMENT_ONE_TO_TWO_DAYS\x10\x16\x12 \n\x1c\x41\x44JUSTMENT_TWO_TO_THREE_DAYS\x10\x17\x12!\n\x1d\x41\x44JUSTMENT_THREE_TO_FOUR_DAYS\x10\x18\x12 \n\x1c\x41\x44JUSTMENT_FOUR_TO_FIVE_DAYS\x10\x19\x12\x1f\n\x1b\x41\x44JUSTMENT_FIVE_TO_SIX_DAYS\x10\x1a\x12 \n\x1c\x41\x44JUSTMENT_SIX_TO_SEVEN_DAYS\x10\x1b\x12\"\n\x1e\x41\x44JUSTMENT_SEVEN_TO_EIGHT_DAYS\x10\x1c\x12!\n\x1d\x41\x44JUSTMENT_EIGHT_TO_NINE_DAYS\x10\x1d\x12\x1f\n\x1b\x41\x44JUSTMENT_NINE_TO_TEN_DAYS\x10\x1e\x12!\n\x1d\x41\x44JUSTMENT_TEN_TO_ELEVEN_DAYS\x10\x1f\x12$\n ADJUSTMENT_ELEVEN_TO_TWELVE_DAYS\x10 \x12&\n\"ADJUSTMENT_TWELVE_TO_THIRTEEN_DAYS\x10!\x12(\n$ADJUSTMENT_THIRTEEN_TO_FOURTEEN_DAYS\x10\"\x12*\n&ADJUSTMENT_FOURTEEN_TO_TWENTY_ONE_DAYS\x10#\x12(\n$ADJUSTMENT_TWENTY_ONE_TO_THIRTY_DAYS\x10$\x12(\n$ADJUSTMENT_THIRTY_TO_FORTY_FIVE_DAYS\x10%\x12\'\n#ADJUSTMENT_FORTY_FIVE_TO_SIXTY_DAYS\x10&\x12#\n\x1f\x41\x44JUSTMENT_SIXTY_TO_NINETY_DAYS\x10\'\x12\x38\n4ADJUSTMENT_NINETY_TO_ONE_HUNDRED_AND_FORTY_FIVE_DAYS\x10(\x12\x16\n\x12\x43ONVERSION_UNKNOWN\x10)\x12\x16\n\x12\x41\x44JUSTMENT_UNKNOWN\x10*B\xf9\x01\n!com.google.ads.googleads.v1.enumsB$ConversionOrAdjustmentLagBucketProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V1.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V1\\Enums\xea\x02!Google::Ads::GoogleAds::V1::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_CONVERSIONORADJUSTMENTLAGBUCKETENUM_CONVERSIONORADJUSTMENTLAGBUCKET = _descriptor.EnumDescriptor(
  name='ConversionOrAdjustmentLagBucket',
  full_name='google.ads.googleads.v1.enums.ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_LESS_THAN_ONE_DAY', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_ONE_TO_TWO_DAYS', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_TWO_TO_THREE_DAYS', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_THREE_TO_FOUR_DAYS', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_FOUR_TO_FIVE_DAYS', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_FIVE_TO_SIX_DAYS', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_SIX_TO_SEVEN_DAYS', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_SEVEN_TO_EIGHT_DAYS', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_EIGHT_TO_NINE_DAYS', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_NINE_TO_TEN_DAYS', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_TEN_TO_ELEVEN_DAYS', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_ELEVEN_TO_TWELVE_DAYS', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_TWELVE_TO_THIRTEEN_DAYS', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_THIRTEEN_TO_FOURTEEN_DAYS', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_FOURTEEN_TO_TWENTY_ONE_DAYS', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_TWENTY_ONE_TO_THIRTY_DAYS', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_THIRTY_TO_FORTY_FIVE_DAYS', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_FORTY_FIVE_TO_SIXTY_DAYS', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_SIXTY_TO_NINETY_DAYS', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_LESS_THAN_ONE_DAY', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_ONE_TO_TWO_DAYS', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_TWO_TO_THREE_DAYS', index=23, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_THREE_TO_FOUR_DAYS', index=24, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_FOUR_TO_FIVE_DAYS', index=25, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_FIVE_TO_SIX_DAYS', index=26, number=26,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_SIX_TO_SEVEN_DAYS', index=27, number=27,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_SEVEN_TO_EIGHT_DAYS', index=28, number=28,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_EIGHT_TO_NINE_DAYS', index=29, number=29,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_NINE_TO_TEN_DAYS', index=30, number=30,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_TEN_TO_ELEVEN_DAYS', index=31, number=31,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_ELEVEN_TO_TWELVE_DAYS', index=32, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_TWELVE_TO_THIRTEEN_DAYS', index=33, number=33,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_THIRTEEN_TO_FOURTEEN_DAYS', index=34, number=34,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_FOURTEEN_TO_TWENTY_ONE_DAYS', index=35, number=35,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_TWENTY_ONE_TO_THIRTY_DAYS', index=36, number=36,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_THIRTY_TO_FORTY_FIVE_DAYS', index=37, number=37,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_FORTY_FIVE_TO_SIXTY_DAYS', index=38, number=38,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_SIXTY_TO_NINETY_DAYS', index=39, number=39,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_NINETY_TO_ONE_HUNDRED_AND_FORTY_FIVE_DAYS', index=40, number=40,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_UNKNOWN', index=41, number=41,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUSTMENT_UNKNOWN', index=42, number=42,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=183,
  serialized_end=1754,
)
_sym_db.RegisterEnumDescriptor(_CONVERSIONORADJUSTMENTLAGBUCKETENUM_CONVERSIONORADJUSTMENTLAGBUCKET)


_CONVERSIONORADJUSTMENTLAGBUCKETENUM = _descriptor.Descriptor(
  name='ConversionOrAdjustmentLagBucketEnum',
  full_name='google.ads.googleads.v1.enums.ConversionOrAdjustmentLagBucketEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONVERSIONORADJUSTMENTLAGBUCKETENUM_CONVERSIONORADJUSTMENTLAGBUCKET,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=143,
  serialized_end=1754,
)

_CONVERSIONORADJUSTMENTLAGBUCKETENUM_CONVERSIONORADJUSTMENTLAGBUCKET.containing_type = _CONVERSIONORADJUSTMENTLAGBUCKETENUM
DESCRIPTOR.message_types_by_name['ConversionOrAdjustmentLagBucketEnum'] = _CONVERSIONORADJUSTMENTLAGBUCKETENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConversionOrAdjustmentLagBucketEnum = _reflection.GeneratedProtocolMessageType('ConversionOrAdjustmentLagBucketEnum', (_message.Message,), dict(
  DESCRIPTOR = _CONVERSIONORADJUSTMENTLAGBUCKETENUM,
  __module__ = 'google.ads.googleads_v1.proto.enums.conversion_or_adjustment_lag_bucket_pb2'
  ,
  __doc__ = """Container for enum representing the number of days between the
  impression and the conversion or between the impression and adjustments
  to the conversion.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.enums.ConversionOrAdjustmentLagBucketEnum)
  ))
_sym_db.RegisterMessage(ConversionOrAdjustmentLagBucketEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
