# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/common/tag_snippet.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.enums import tracking_code_page_format_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_tracking__code__page__format__pb2
from google.ads.google_ads.v1.proto.enums import tracking_code_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_tracking__code__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/common/tag_snippet.proto',
  package='google.ads.googleads.v1.common',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.commonB\017TagSnippetProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Common\312\002\036Google\\Ads\\GoogleAds\\V1\\Common\352\002\"Google::Ads::GoogleAds::V1::Common'),
  serialized_pb=_b('\n6google/ads/googleads_v1/proto/common/tag_snippet.proto\x12\x1egoogle.ads.googleads.v1.common\x1a\x43google/ads/googleads_v1/proto/enums/tracking_code_page_format.proto\x1a<google/ads/googleads_v1/proto/enums/tracking_code_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xb3\x02\n\nTagSnippet\x12R\n\x04type\x18\x01 \x01(\x0e\x32\x44.google.ads.googleads.v1.enums.TrackingCodeTypeEnum.TrackingCodeType\x12\x65\n\x0bpage_format\x18\x02 \x01(\x0e\x32P.google.ads.googleads.v1.enums.TrackingCodePageFormatEnum.TrackingCodePageFormat\x12\x35\n\x0fglobal_site_tag\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\revent_snippet\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\xea\x01\n\"com.google.ads.googleads.v1.commonB\x0fTagSnippetProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Common\xea\x02\"Google::Ads::GoogleAds::V1::Commonb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_tracking__code__page__format__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_tracking__code__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_TAGSNIPPET = _descriptor.Descriptor(
  name='TagSnippet',
  full_name='google.ads.googleads.v1.common.TagSnippet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v1.common.TagSnippet.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_format', full_name='google.ads.googleads.v1.common.TagSnippet.page_format', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='global_site_tag', full_name='google.ads.googleads.v1.common.TagSnippet.global_site_tag', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_snippet', full_name='google.ads.googleads.v1.common.TagSnippet.event_snippet', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=284,
  serialized_end=591,
)

_TAGSNIPPET.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_tracking__code__type__pb2._TRACKINGCODETYPEENUM_TRACKINGCODETYPE
_TAGSNIPPET.fields_by_name['page_format'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_tracking__code__page__format__pb2._TRACKINGCODEPAGEFORMATENUM_TRACKINGCODEPAGEFORMAT
_TAGSNIPPET.fields_by_name['global_site_tag'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TAGSNIPPET.fields_by_name['event_snippet'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['TagSnippet'] = _TAGSNIPPET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TagSnippet = _reflection.GeneratedProtocolMessageType('TagSnippet', (_message.Message,), dict(
  DESCRIPTOR = _TAGSNIPPET,
  __module__ = 'google.ads.googleads_v1.proto.common.tag_snippet_pb2'
  ,
  __doc__ = """The site tag and event snippet pair for a TrackingCodeType.
  
  
  Attributes:
      type:
          The type of the generated tag snippets for tracking
          conversions.
      page_format:
          The format of the web page where the tracking tag and snippet
          will be installed, e.g. HTML.
      global_site_tag:
          The site tag that adds visitors to your basic remarketing
          lists and sets new cookies on your domain.
      event_snippet:
          The event snippet that works with the site tag to track
          actions that should be counted as conversions.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.TagSnippet)
  ))
_sym_db.RegisterMessage(TagSnippet)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
