# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/common/user_lists.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.enums import customer_match_upload_key_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_customer__match__upload__key__type__pb2
from google.ads.google_ads.v2.proto.enums import user_list_combined_rule_operator_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__combined__rule__operator__pb2
from google.ads.google_ads.v2.proto.enums import user_list_crm_data_source_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__crm__data__source__type__pb2
from google.ads.google_ads.v2.proto.enums import user_list_date_rule_item_operator_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__date__rule__item__operator__pb2
from google.ads.google_ads.v2.proto.enums import user_list_logical_rule_operator_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__logical__rule__operator__pb2
from google.ads.google_ads.v2.proto.enums import user_list_number_rule_item_operator_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__number__rule__item__operator__pb2
from google.ads.google_ads.v2.proto.enums import user_list_prepopulation_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__prepopulation__status__pb2
from google.ads.google_ads.v2.proto.enums import user_list_rule_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__rule__type__pb2
from google.ads.google_ads.v2.proto.enums import user_list_string_rule_item_operator_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__string__rule__item__operator__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/common/user_lists.proto',
  package='google.ads.googleads.v2.common',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v2.commonB\016UserListsProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V2.Common\312\002\036Google\\Ads\\GoogleAds\\V2\\Common\352\002\"Google::Ads::GoogleAds::V2::Common'),
  serialized_pb=_b('\n5google/ads/googleads_v2/proto/common/user_lists.proto\x12\x1egoogle.ads.googleads.v2.common\x1aHgoogle/ads/googleads_v2/proto/enums/customer_match_upload_key_type.proto\x1aJgoogle/ads/googleads_v2/proto/enums/user_list_combined_rule_operator.proto\x1aHgoogle/ads/googleads_v2/proto/enums/user_list_crm_data_source_type.proto\x1aKgoogle/ads/googleads_v2/proto/enums/user_list_date_rule_item_operator.proto\x1aIgoogle/ads/googleads_v2/proto/enums/user_list_logical_rule_operator.proto\x1aMgoogle/ads/googleads_v2/proto/enums/user_list_number_rule_item_operator.proto\x1aHgoogle/ads/googleads_v2/proto/enums/user_list_prepopulation_status.proto\x1a=google/ads/googleads_v2/proto/enums/user_list_rule_type.proto\x1aMgoogle/ads/googleads_v2/proto/enums/user_list_string_rule_item_operator.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"K\n\x13SimilarUserListInfo\x12\x34\n\x0eseed_user_list\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xa9\x02\n\x14\x43rmBasedUserListInfo\x12,\n\x06\x61pp_id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12q\n\x0fupload_key_type\x18\x02 \x01(\x0e\x32X.google.ads.googleads.v2.enums.CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType\x12p\n\x10\x64\x61ta_source_type\x18\x03 \x01(\x0e\x32V.google.ads.googleads.v2.enums.UserListCrmDataSourceTypeEnum.UserListCrmDataSourceType\"\xc0\x01\n\x10UserListRuleInfo\x12W\n\trule_type\x18\x01 \x01(\x0e\x32\x44.google.ads.googleads.v2.enums.UserListRuleTypeEnum.UserListRuleType\x12S\n\x10rule_item_groups\x18\x02 \x03(\x0b\x32\x39.google.ads.googleads.v2.common.UserListRuleItemGroupInfo\"e\n\x19UserListRuleItemGroupInfo\x12H\n\nrule_items\x18\x01 \x03(\x0b\x32\x34.google.ads.googleads.v2.common.UserListRuleItemInfo\"\xd3\x02\n\x14UserListRuleItemInfo\x12*\n\x04name\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12V\n\x10number_rule_item\x18\x02 \x01(\x0b\x32:.google.ads.googleads.v2.common.UserListNumberRuleItemInfoH\x00\x12V\n\x10string_rule_item\x18\x03 \x01(\x0b\x32:.google.ads.googleads.v2.common.UserListStringRuleItemInfoH\x00\x12R\n\x0e\x64\x61te_rule_item\x18\x04 \x01(\x0b\x32\x38.google.ads.googleads.v2.common.UserListDateRuleItemInfoH\x00\x42\x0b\n\trule_item\"\xec\x01\n\x18UserListDateRuleItemInfo\x12n\n\x08operator\x18\x01 \x01(\x0e\x32\\.google.ads.googleads.v2.enums.UserListDateRuleItemOperatorEnum.UserListDateRuleItemOperator\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\x0eoffset_in_days\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xbd\x01\n\x1aUserListNumberRuleItemInfo\x12r\n\x08operator\x18\x01 \x01(\x0e\x32`.google.ads.googleads.v2.enums.UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperator\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\"\xbd\x01\n\x1aUserListStringRuleItemInfo\x12r\n\x08operator\x18\x01 \x01(\x0e\x32`.google.ads.googleads.v2.enums.UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xa0\x02\n\x18\x43ombinedRuleUserListInfo\x12\x46\n\x0cleft_operand\x18\x01 \x01(\x0b\x32\x30.google.ads.googleads.v2.common.UserListRuleInfo\x12G\n\rright_operand\x18\x02 \x01(\x0b\x32\x30.google.ads.googleads.v2.common.UserListRuleInfo\x12s\n\rrule_operator\x18\x03 \x01(\x0e\x32\\.google.ads.googleads.v2.enums.UserListCombinedRuleOperatorEnum.UserListCombinedRuleOperator\"\xc0\x01\n\x1c\x44\x61teSpecificRuleUserListInfo\x12>\n\x04rule\x18\x01 \x01(\x0b\x32\x30.google.ads.googleads.v2.common.UserListRuleInfo\x12\x30\n\nstart_date\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08\x65nd_date\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\\\n\x1a\x45xpressionRuleUserListInfo\x12>\n\x04rule\x18\x01 \x01(\x0b\x32\x30.google.ads.googleads.v2.common.UserListRuleInfo\"\xcd\x03\n\x15RuleBasedUserListInfo\x12x\n\x14prepopulation_status\x18\x01 \x01(\x0e\x32Z.google.ads.googleads.v2.enums.UserListPrepopulationStatusEnum.UserListPrepopulationStatus\x12[\n\x17\x63ombined_rule_user_list\x18\x02 \x01(\x0b\x32\x38.google.ads.googleads.v2.common.CombinedRuleUserListInfoH\x00\x12\x64\n\x1c\x64\x61te_specific_rule_user_list\x18\x03 \x01(\x0b\x32<.google.ads.googleads.v2.common.DateSpecificRuleUserListInfoH\x00\x12_\n\x19\x65xpression_rule_user_list\x18\x04 \x01(\x0b\x32:.google.ads.googleads.v2.common.ExpressionRuleUserListInfoH\x00\x42\x16\n\x14rule_based_user_list\"]\n\x13LogicalUserListInfo\x12\x46\n\x05rules\x18\x01 \x03(\x0b\x32\x37.google.ads.googleads.v2.common.UserListLogicalRuleInfo\"\xda\x01\n\x17UserListLogicalRuleInfo\x12l\n\x08operator\x18\x01 \x01(\x0e\x32Z.google.ads.googleads.v2.enums.UserListLogicalRuleOperatorEnum.UserListLogicalRuleOperator\x12Q\n\rrule_operands\x18\x02 \x03(\x0b\x32:.google.ads.googleads.v2.common.LogicalUserListOperandInfo\"M\n\x1aLogicalUserListOperandInfo\x12/\n\tuser_list\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"X\n\x11\x42\x61sicUserListInfo\x12\x43\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32\x32.google.ads.googleads.v2.common.UserListActionInfo\"\x9f\x01\n\x12UserListActionInfo\x12\x39\n\x11\x63onversion_action\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x00\x12:\n\x12remarketing_action\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x00\x42\x12\n\x10user_list_actionB\xe9\x01\n\"com.google.ads.googleads.v2.commonB\x0eUserListsProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V2.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V2\\Common\xea\x02\"Google::Ads::GoogleAds::V2::Commonb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_customer__match__upload__key__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__combined__rule__operator__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__crm__data__source__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__date__rule__item__operator__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__logical__rule__operator__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__number__rule__item__operator__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__prepopulation__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__rule__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__string__rule__item__operator__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_SIMILARUSERLISTINFO = _descriptor.Descriptor(
  name='SimilarUserListInfo',
  full_name='google.ads.googleads.v2.common.SimilarUserListInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='seed_user_list', full_name='google.ads.googleads.v2.common.SimilarUserListInfo.seed_user_list', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=822,
  serialized_end=897,
)


_CRMBASEDUSERLISTINFO = _descriptor.Descriptor(
  name='CrmBasedUserListInfo',
  full_name='google.ads.googleads.v2.common.CrmBasedUserListInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='google.ads.googleads.v2.common.CrmBasedUserListInfo.app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upload_key_type', full_name='google.ads.googleads.v2.common.CrmBasedUserListInfo.upload_key_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_source_type', full_name='google.ads.googleads.v2.common.CrmBasedUserListInfo.data_source_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=900,
  serialized_end=1197,
)


_USERLISTRULEINFO = _descriptor.Descriptor(
  name='UserListRuleInfo',
  full_name='google.ads.googleads.v2.common.UserListRuleInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rule_type', full_name='google.ads.googleads.v2.common.UserListRuleInfo.rule_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule_item_groups', full_name='google.ads.googleads.v2.common.UserListRuleInfo.rule_item_groups', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1200,
  serialized_end=1392,
)


_USERLISTRULEITEMGROUPINFO = _descriptor.Descriptor(
  name='UserListRuleItemGroupInfo',
  full_name='google.ads.googleads.v2.common.UserListRuleItemGroupInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rule_items', full_name='google.ads.googleads.v2.common.UserListRuleItemGroupInfo.rule_items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1394,
  serialized_end=1495,
)


_USERLISTRULEITEMINFO = _descriptor.Descriptor(
  name='UserListRuleItemInfo',
  full_name='google.ads.googleads.v2.common.UserListRuleItemInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v2.common.UserListRuleItemInfo.name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_rule_item', full_name='google.ads.googleads.v2.common.UserListRuleItemInfo.number_rule_item', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_rule_item', full_name='google.ads.googleads.v2.common.UserListRuleItemInfo.string_rule_item', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_rule_item', full_name='google.ads.googleads.v2.common.UserListRuleItemInfo.date_rule_item', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='rule_item', full_name='google.ads.googleads.v2.common.UserListRuleItemInfo.rule_item',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1498,
  serialized_end=1837,
)


_USERLISTDATERULEITEMINFO = _descriptor.Descriptor(
  name='UserListDateRuleItemInfo',
  full_name='google.ads.googleads.v2.common.UserListDateRuleItemInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='operator', full_name='google.ads.googleads.v2.common.UserListDateRuleItemInfo.operator', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.ads.googleads.v2.common.UserListDateRuleItemInfo.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset_in_days', full_name='google.ads.googleads.v2.common.UserListDateRuleItemInfo.offset_in_days', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1840,
  serialized_end=2076,
)


_USERLISTNUMBERRULEITEMINFO = _descriptor.Descriptor(
  name='UserListNumberRuleItemInfo',
  full_name='google.ads.googleads.v2.common.UserListNumberRuleItemInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='operator', full_name='google.ads.googleads.v2.common.UserListNumberRuleItemInfo.operator', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.ads.googleads.v2.common.UserListNumberRuleItemInfo.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2079,
  serialized_end=2268,
)


_USERLISTSTRINGRULEITEMINFO = _descriptor.Descriptor(
  name='UserListStringRuleItemInfo',
  full_name='google.ads.googleads.v2.common.UserListStringRuleItemInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='operator', full_name='google.ads.googleads.v2.common.UserListStringRuleItemInfo.operator', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.ads.googleads.v2.common.UserListStringRuleItemInfo.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2271,
  serialized_end=2460,
)


_COMBINEDRULEUSERLISTINFO = _descriptor.Descriptor(
  name='CombinedRuleUserListInfo',
  full_name='google.ads.googleads.v2.common.CombinedRuleUserListInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='left_operand', full_name='google.ads.googleads.v2.common.CombinedRuleUserListInfo.left_operand', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='right_operand', full_name='google.ads.googleads.v2.common.CombinedRuleUserListInfo.right_operand', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule_operator', full_name='google.ads.googleads.v2.common.CombinedRuleUserListInfo.rule_operator', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2463,
  serialized_end=2751,
)


_DATESPECIFICRULEUSERLISTINFO = _descriptor.Descriptor(
  name='DateSpecificRuleUserListInfo',
  full_name='google.ads.googleads.v2.common.DateSpecificRuleUserListInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rule', full_name='google.ads.googleads.v2.common.DateSpecificRuleUserListInfo.rule', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_date', full_name='google.ads.googleads.v2.common.DateSpecificRuleUserListInfo.start_date', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_date', full_name='google.ads.googleads.v2.common.DateSpecificRuleUserListInfo.end_date', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2754,
  serialized_end=2946,
)


_EXPRESSIONRULEUSERLISTINFO = _descriptor.Descriptor(
  name='ExpressionRuleUserListInfo',
  full_name='google.ads.googleads.v2.common.ExpressionRuleUserListInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rule', full_name='google.ads.googleads.v2.common.ExpressionRuleUserListInfo.rule', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2948,
  serialized_end=3040,
)


_RULEBASEDUSERLISTINFO = _descriptor.Descriptor(
  name='RuleBasedUserListInfo',
  full_name='google.ads.googleads.v2.common.RuleBasedUserListInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prepopulation_status', full_name='google.ads.googleads.v2.common.RuleBasedUserListInfo.prepopulation_status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='combined_rule_user_list', full_name='google.ads.googleads.v2.common.RuleBasedUserListInfo.combined_rule_user_list', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_specific_rule_user_list', full_name='google.ads.googleads.v2.common.RuleBasedUserListInfo.date_specific_rule_user_list', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expression_rule_user_list', full_name='google.ads.googleads.v2.common.RuleBasedUserListInfo.expression_rule_user_list', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='rule_based_user_list', full_name='google.ads.googleads.v2.common.RuleBasedUserListInfo.rule_based_user_list',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3043,
  serialized_end=3504,
)


_LOGICALUSERLISTINFO = _descriptor.Descriptor(
  name='LogicalUserListInfo',
  full_name='google.ads.googleads.v2.common.LogicalUserListInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rules', full_name='google.ads.googleads.v2.common.LogicalUserListInfo.rules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3506,
  serialized_end=3599,
)


_USERLISTLOGICALRULEINFO = _descriptor.Descriptor(
  name='UserListLogicalRuleInfo',
  full_name='google.ads.googleads.v2.common.UserListLogicalRuleInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='operator', full_name='google.ads.googleads.v2.common.UserListLogicalRuleInfo.operator', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule_operands', full_name='google.ads.googleads.v2.common.UserListLogicalRuleInfo.rule_operands', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3602,
  serialized_end=3820,
)


_LOGICALUSERLISTOPERANDINFO = _descriptor.Descriptor(
  name='LogicalUserListOperandInfo',
  full_name='google.ads.googleads.v2.common.LogicalUserListOperandInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_list', full_name='google.ads.googleads.v2.common.LogicalUserListOperandInfo.user_list', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3822,
  serialized_end=3899,
)


_BASICUSERLISTINFO = _descriptor.Descriptor(
  name='BasicUserListInfo',
  full_name='google.ads.googleads.v2.common.BasicUserListInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='actions', full_name='google.ads.googleads.v2.common.BasicUserListInfo.actions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3901,
  serialized_end=3989,
)


_USERLISTACTIONINFO = _descriptor.Descriptor(
  name='UserListActionInfo',
  full_name='google.ads.googleads.v2.common.UserListActionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='conversion_action', full_name='google.ads.googleads.v2.common.UserListActionInfo.conversion_action', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remarketing_action', full_name='google.ads.googleads.v2.common.UserListActionInfo.remarketing_action', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='user_list_action', full_name='google.ads.googleads.v2.common.UserListActionInfo.user_list_action',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3992,
  serialized_end=4151,
)

_SIMILARUSERLISTINFO.fields_by_name['seed_user_list'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CRMBASEDUSERLISTINFO.fields_by_name['app_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CRMBASEDUSERLISTINFO.fields_by_name['upload_key_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_customer__match__upload__key__type__pb2._CUSTOMERMATCHUPLOADKEYTYPEENUM_CUSTOMERMATCHUPLOADKEYTYPE
_CRMBASEDUSERLISTINFO.fields_by_name['data_source_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__crm__data__source__type__pb2._USERLISTCRMDATASOURCETYPEENUM_USERLISTCRMDATASOURCETYPE
_USERLISTRULEINFO.fields_by_name['rule_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__rule__type__pb2._USERLISTRULETYPEENUM_USERLISTRULETYPE
_USERLISTRULEINFO.fields_by_name['rule_item_groups'].message_type = _USERLISTRULEITEMGROUPINFO
_USERLISTRULEITEMGROUPINFO.fields_by_name['rule_items'].message_type = _USERLISTRULEITEMINFO
_USERLISTRULEITEMINFO.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USERLISTRULEITEMINFO.fields_by_name['number_rule_item'].message_type = _USERLISTNUMBERRULEITEMINFO
_USERLISTRULEITEMINFO.fields_by_name['string_rule_item'].message_type = _USERLISTSTRINGRULEITEMINFO
_USERLISTRULEITEMINFO.fields_by_name['date_rule_item'].message_type = _USERLISTDATERULEITEMINFO
_USERLISTRULEITEMINFO.oneofs_by_name['rule_item'].fields.append(
  _USERLISTRULEITEMINFO.fields_by_name['number_rule_item'])
_USERLISTRULEITEMINFO.fields_by_name['number_rule_item'].containing_oneof = _USERLISTRULEITEMINFO.oneofs_by_name['rule_item']
_USERLISTRULEITEMINFO.oneofs_by_name['rule_item'].fields.append(
  _USERLISTRULEITEMINFO.fields_by_name['string_rule_item'])
_USERLISTRULEITEMINFO.fields_by_name['string_rule_item'].containing_oneof = _USERLISTRULEITEMINFO.oneofs_by_name['rule_item']
_USERLISTRULEITEMINFO.oneofs_by_name['rule_item'].fields.append(
  _USERLISTRULEITEMINFO.fields_by_name['date_rule_item'])
_USERLISTRULEITEMINFO.fields_by_name['date_rule_item'].containing_oneof = _USERLISTRULEITEMINFO.oneofs_by_name['rule_item']
_USERLISTDATERULEITEMINFO.fields_by_name['operator'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__date__rule__item__operator__pb2._USERLISTDATERULEITEMOPERATORENUM_USERLISTDATERULEITEMOPERATOR
_USERLISTDATERULEITEMINFO.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USERLISTDATERULEITEMINFO.fields_by_name['offset_in_days'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERLISTNUMBERRULEITEMINFO.fields_by_name['operator'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__number__rule__item__operator__pb2._USERLISTNUMBERRULEITEMOPERATORENUM_USERLISTNUMBERRULEITEMOPERATOR
_USERLISTNUMBERRULEITEMINFO.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_USERLISTSTRINGRULEITEMINFO.fields_by_name['operator'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__string__rule__item__operator__pb2._USERLISTSTRINGRULEITEMOPERATORENUM_USERLISTSTRINGRULEITEMOPERATOR
_USERLISTSTRINGRULEITEMINFO.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_COMBINEDRULEUSERLISTINFO.fields_by_name['left_operand'].message_type = _USERLISTRULEINFO
_COMBINEDRULEUSERLISTINFO.fields_by_name['right_operand'].message_type = _USERLISTRULEINFO
_COMBINEDRULEUSERLISTINFO.fields_by_name['rule_operator'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__combined__rule__operator__pb2._USERLISTCOMBINEDRULEOPERATORENUM_USERLISTCOMBINEDRULEOPERATOR
_DATESPECIFICRULEUSERLISTINFO.fields_by_name['rule'].message_type = _USERLISTRULEINFO
_DATESPECIFICRULEUSERLISTINFO.fields_by_name['start_date'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DATESPECIFICRULEUSERLISTINFO.fields_by_name['end_date'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_EXPRESSIONRULEUSERLISTINFO.fields_by_name['rule'].message_type = _USERLISTRULEINFO
_RULEBASEDUSERLISTINFO.fields_by_name['prepopulation_status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__prepopulation__status__pb2._USERLISTPREPOPULATIONSTATUSENUM_USERLISTPREPOPULATIONSTATUS
_RULEBASEDUSERLISTINFO.fields_by_name['combined_rule_user_list'].message_type = _COMBINEDRULEUSERLISTINFO
_RULEBASEDUSERLISTINFO.fields_by_name['date_specific_rule_user_list'].message_type = _DATESPECIFICRULEUSERLISTINFO
_RULEBASEDUSERLISTINFO.fields_by_name['expression_rule_user_list'].message_type = _EXPRESSIONRULEUSERLISTINFO
_RULEBASEDUSERLISTINFO.oneofs_by_name['rule_based_user_list'].fields.append(
  _RULEBASEDUSERLISTINFO.fields_by_name['combined_rule_user_list'])
_RULEBASEDUSERLISTINFO.fields_by_name['combined_rule_user_list'].containing_oneof = _RULEBASEDUSERLISTINFO.oneofs_by_name['rule_based_user_list']
_RULEBASEDUSERLISTINFO.oneofs_by_name['rule_based_user_list'].fields.append(
  _RULEBASEDUSERLISTINFO.fields_by_name['date_specific_rule_user_list'])
_RULEBASEDUSERLISTINFO.fields_by_name['date_specific_rule_user_list'].containing_oneof = _RULEBASEDUSERLISTINFO.oneofs_by_name['rule_based_user_list']
_RULEBASEDUSERLISTINFO.oneofs_by_name['rule_based_user_list'].fields.append(
  _RULEBASEDUSERLISTINFO.fields_by_name['expression_rule_user_list'])
_RULEBASEDUSERLISTINFO.fields_by_name['expression_rule_user_list'].containing_oneof = _RULEBASEDUSERLISTINFO.oneofs_by_name['rule_based_user_list']
_LOGICALUSERLISTINFO.fields_by_name['rules'].message_type = _USERLISTLOGICALRULEINFO
_USERLISTLOGICALRULEINFO.fields_by_name['operator'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_user__list__logical__rule__operator__pb2._USERLISTLOGICALRULEOPERATORENUM_USERLISTLOGICALRULEOPERATOR
_USERLISTLOGICALRULEINFO.fields_by_name['rule_operands'].message_type = _LOGICALUSERLISTOPERANDINFO
_LOGICALUSERLISTOPERANDINFO.fields_by_name['user_list'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_BASICUSERLISTINFO.fields_by_name['actions'].message_type = _USERLISTACTIONINFO
_USERLISTACTIONINFO.fields_by_name['conversion_action'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USERLISTACTIONINFO.fields_by_name['remarketing_action'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USERLISTACTIONINFO.oneofs_by_name['user_list_action'].fields.append(
  _USERLISTACTIONINFO.fields_by_name['conversion_action'])
_USERLISTACTIONINFO.fields_by_name['conversion_action'].containing_oneof = _USERLISTACTIONINFO.oneofs_by_name['user_list_action']
_USERLISTACTIONINFO.oneofs_by_name['user_list_action'].fields.append(
  _USERLISTACTIONINFO.fields_by_name['remarketing_action'])
_USERLISTACTIONINFO.fields_by_name['remarketing_action'].containing_oneof = _USERLISTACTIONINFO.oneofs_by_name['user_list_action']
DESCRIPTOR.message_types_by_name['SimilarUserListInfo'] = _SIMILARUSERLISTINFO
DESCRIPTOR.message_types_by_name['CrmBasedUserListInfo'] = _CRMBASEDUSERLISTINFO
DESCRIPTOR.message_types_by_name['UserListRuleInfo'] = _USERLISTRULEINFO
DESCRIPTOR.message_types_by_name['UserListRuleItemGroupInfo'] = _USERLISTRULEITEMGROUPINFO
DESCRIPTOR.message_types_by_name['UserListRuleItemInfo'] = _USERLISTRULEITEMINFO
DESCRIPTOR.message_types_by_name['UserListDateRuleItemInfo'] = _USERLISTDATERULEITEMINFO
DESCRIPTOR.message_types_by_name['UserListNumberRuleItemInfo'] = _USERLISTNUMBERRULEITEMINFO
DESCRIPTOR.message_types_by_name['UserListStringRuleItemInfo'] = _USERLISTSTRINGRULEITEMINFO
DESCRIPTOR.message_types_by_name['CombinedRuleUserListInfo'] = _COMBINEDRULEUSERLISTINFO
DESCRIPTOR.message_types_by_name['DateSpecificRuleUserListInfo'] = _DATESPECIFICRULEUSERLISTINFO
DESCRIPTOR.message_types_by_name['ExpressionRuleUserListInfo'] = _EXPRESSIONRULEUSERLISTINFO
DESCRIPTOR.message_types_by_name['RuleBasedUserListInfo'] = _RULEBASEDUSERLISTINFO
DESCRIPTOR.message_types_by_name['LogicalUserListInfo'] = _LOGICALUSERLISTINFO
DESCRIPTOR.message_types_by_name['UserListLogicalRuleInfo'] = _USERLISTLOGICALRULEINFO
DESCRIPTOR.message_types_by_name['LogicalUserListOperandInfo'] = _LOGICALUSERLISTOPERANDINFO
DESCRIPTOR.message_types_by_name['BasicUserListInfo'] = _BASICUSERLISTINFO
DESCRIPTOR.message_types_by_name['UserListActionInfo'] = _USERLISTACTIONINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SimilarUserListInfo = _reflection.GeneratedProtocolMessageType('SimilarUserListInfo', (_message.Message,), dict(
  DESCRIPTOR = _SIMILARUSERLISTINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """SimilarUserList is a list of users which are similar to users from
  another UserList. These lists are read-only and automatically created by
  Google.
  
  
  Attributes:
      seed_user_list:
          Seed UserList from which this list is derived.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.SimilarUserListInfo)
  ))
_sym_db.RegisterMessage(SimilarUserListInfo)

CrmBasedUserListInfo = _reflection.GeneratedProtocolMessageType('CrmBasedUserListInfo', (_message.Message,), dict(
  DESCRIPTOR = _CRMBASEDUSERLISTINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """UserList of CRM users provided by the advertiser.
  
  
  Attributes:
      app_id:
          A string that uniquely identifies a mobile application from
          which the data was collected to the Google Ads API. For iOS,
          the ID string is the 9 digit string that appears at the end of
          an App Store URL (e.g., "476943146" for "Flood-It! 2" whose
          App Store link is http://itunes.apple.com/us/app/flood-
          it!-2/id476943146). For Android, the ID string is the
          application's package name (e.g., "com.labpixies.colordrips"
          for "Color Drips" given Google Play link https://play.google.c
          om/store/apps/details?id=com.labpixies.colordrips). Required
          when creating CrmBasedUserList for uploading mobile
          advertising IDs.
      upload_key_type:
          Matching key type of the list. Mixed data types are not
          allowed on the same list. This field is required for an ADD
          operation.
      data_source_type:
          Data source of the list. Default value is FIRST\_PARTY. Only
          whitelisted customers can create third-party sourced CRM
          lists.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.CrmBasedUserListInfo)
  ))
_sym_db.RegisterMessage(CrmBasedUserListInfo)

UserListRuleInfo = _reflection.GeneratedProtocolMessageType('UserListRuleInfo', (_message.Message,), dict(
  DESCRIPTOR = _USERLISTRULEINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """A client defined rule based on custom parameters sent by web sites or
  uploaded by the advertiser.
  
  
  Attributes:
      rule_type:
          Rule type is used to determine how to group rule items.  The
          default is OR of ANDs (disjunctive normal form). That is, rule
          items will be ANDed together within rule item groups and the
          groups themselves will be ORed together.  Currently AND of ORs
          (conjunctive normal form) is only supported for
          ExpressionRuleUserList.
      rule_item_groups:
          List of rule item groups that defines this rule. Rule item
          groups are grouped together based on rule\_type.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.UserListRuleInfo)
  ))
_sym_db.RegisterMessage(UserListRuleInfo)

UserListRuleItemGroupInfo = _reflection.GeneratedProtocolMessageType('UserListRuleItemGroupInfo', (_message.Message,), dict(
  DESCRIPTOR = _USERLISTRULEITEMGROUPINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """A group of rule items.
  
  
  Attributes:
      rule_items:
          Rule items that will be grouped together based on rule\_type.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.UserListRuleItemGroupInfo)
  ))
_sym_db.RegisterMessage(UserListRuleItemGroupInfo)

UserListRuleItemInfo = _reflection.GeneratedProtocolMessageType('UserListRuleItemInfo', (_message.Message,), dict(
  DESCRIPTOR = _USERLISTRULEITEMINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """An atomic rule fragment.
  
  
  Attributes:
      name:
          Rule variable name. It should match the corresponding key name
          fired by the pixel. A name must begin with US-ascii letters or
          underscore or UTF8 code that is greater than 127 and consist
          of US-ascii letters or digits or underscore or UTF8 code that
          is greater than 127. For websites, there are two built-in
          variable URL (name = 'url\_\_') and referrer URL (name =
          'ref\_url\_\_'). This field must be populated when creating a
          new rule item.
      rule_item:
          An atomic rule fragment.
      number_rule_item:
          An atomic rule fragment composed of a number operation.
      string_rule_item:
          An atomic rule fragment composed of a string operation.
      date_rule_item:
          An atomic rule fragment composed of a date operation.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.UserListRuleItemInfo)
  ))
_sym_db.RegisterMessage(UserListRuleItemInfo)

UserListDateRuleItemInfo = _reflection.GeneratedProtocolMessageType('UserListDateRuleItemInfo', (_message.Message,), dict(
  DESCRIPTOR = _USERLISTDATERULEITEMINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """A rule item composed of date operation.
  
  
  Attributes:
      operator:
          Date comparison operator. This field is required and must be
          populated when creating new date rule item.
      value:
          String representing date value to be compared with the rule
          variable. Supported date format is YYYY-MM-DD. Times are
          reported in the customer's time zone.
      offset_in_days:
          The relative date value of the right hand side denoted by
          number of days offset from now. The value field will override
          this field when both are present.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.UserListDateRuleItemInfo)
  ))
_sym_db.RegisterMessage(UserListDateRuleItemInfo)

UserListNumberRuleItemInfo = _reflection.GeneratedProtocolMessageType('UserListNumberRuleItemInfo', (_message.Message,), dict(
  DESCRIPTOR = _USERLISTNUMBERRULEITEMINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """A rule item composed of number operation.
  
  
  Attributes:
      operator:
          Number comparison operator. This field is required and must be
          populated when creating a new number rule item.
      value:
          Number value to be compared with the variable. This field is
          required and must be populated when creating a new number rule
          item.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.UserListNumberRuleItemInfo)
  ))
_sym_db.RegisterMessage(UserListNumberRuleItemInfo)

UserListStringRuleItemInfo = _reflection.GeneratedProtocolMessageType('UserListStringRuleItemInfo', (_message.Message,), dict(
  DESCRIPTOR = _USERLISTSTRINGRULEITEMINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """A rule item fragment composed of date operation.
  
  
  Attributes:
      operator:
          String comparison operator. This field is required and must be
          populated when creating a new string rule item.
      value:
          The right hand side of the string rule item. For URLs or
          referrer URLs, the value can not contain illegal URL chars
          such as newlines, quotes, tabs, or parentheses. This field is
          required and must be populated when creating a new string rule
          item.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.UserListStringRuleItemInfo)
  ))
_sym_db.RegisterMessage(UserListStringRuleItemInfo)

CombinedRuleUserListInfo = _reflection.GeneratedProtocolMessageType('CombinedRuleUserListInfo', (_message.Message,), dict(
  DESCRIPTOR = _COMBINEDRULEUSERLISTINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """User lists defined by combining two rules, left operand and right
  operand. There are two operators: AND where left operand and right
  operand have to be true; AND\_NOT where left operand is true but right
  operand is false.
  
  
  Attributes:
      left_operand:
          Left operand of the combined rule. This field is required and
          must be populated when creating new combined rule based user
          list.
      right_operand:
          Right operand of the combined rule. This field is required and
          must be populated when creating new combined rule based user
          list.
      rule_operator:
          Operator to connect the two operands.  Required for creating a
          combined rule user list.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.CombinedRuleUserListInfo)
  ))
_sym_db.RegisterMessage(CombinedRuleUserListInfo)

DateSpecificRuleUserListInfo = _reflection.GeneratedProtocolMessageType('DateSpecificRuleUserListInfo', (_message.Message,), dict(
  DESCRIPTOR = _DATESPECIFICRULEUSERLISTINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """Visitors of a page during specific dates.
  
  
  Attributes:
      rule:
          Boolean rule that defines visitor of a page.  Required for
          creating a date specific rule user list.
      start_date:
          Start date of users visit. If set to 2000-01-01, then the list
          includes all users before end\_date. The date's format should
          be YYYY-MM-DD.  Required for creating a data specific rule
          user list.
      end_date:
          End date of users visit. If set to 2037-12-30, then the list
          includes all users after start\_date. The date's format should
          be YYYY-MM-DD.  Required for creating a data specific rule
          user list.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.DateSpecificRuleUserListInfo)
  ))
_sym_db.RegisterMessage(DateSpecificRuleUserListInfo)

ExpressionRuleUserListInfo = _reflection.GeneratedProtocolMessageType('ExpressionRuleUserListInfo', (_message.Message,), dict(
  DESCRIPTOR = _EXPRESSIONRULEUSERLISTINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """Visitors of a page. The page visit is defined by one boolean rule
  expression.
  
  
  Attributes:
      rule:
          Boolean rule that defines this user list. The rule consists of
          a list of rule item groups and each rule item group consists
          of a list of rule items. All the rule item groups are ORed or
          ANDed together for evaluation based on rule.rule\_type.
          Required for creating an expression rule user list.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.ExpressionRuleUserListInfo)
  ))
_sym_db.RegisterMessage(ExpressionRuleUserListInfo)

RuleBasedUserListInfo = _reflection.GeneratedProtocolMessageType('RuleBasedUserListInfo', (_message.Message,), dict(
  DESCRIPTOR = _RULEBASEDUSERLISTINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """Representation of a userlist that is generated by a rule.
  
  
  Attributes:
      prepopulation_status:
          The status of pre-population. The field is default to NONE if
          not set which means the previous users will not be considered.
          If set to REQUESTED, past site visitors or app users who match
          the list definition will be included in the list (works on the
          Display Network only). This will only add past users from
          within the last 30 days, depending on the list's membership
          duration and the date when the remarketing tag is added. The
          status will be updated to FINISHED once request is processed,
          or FAILED if the request fails.
      rule_based_user_list:
          Subtypes of rule based user lists.
      combined_rule_user_list:
          User lists defined by combining two rules. There are two
          operators: AND, where the left and right operands have to be
          true; AND\_NOT where left operand is true but right operand is
          false.
      date_specific_rule_user_list:
          Visitors of a page during specific dates. The visiting periods
          are defined as follows: Between start\_date (inclusive) and
          end\_date (inclusive); Before end\_date (exclusive) with
          start\_date = 2000-01-01; After start\_date (exclusive) with
          end\_date = 2037-12-30.
      expression_rule_user_list:
          Visitors of a page. The page visit is defined by one boolean
          rule expression.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.RuleBasedUserListInfo)
  ))
_sym_db.RegisterMessage(RuleBasedUserListInfo)

LogicalUserListInfo = _reflection.GeneratedProtocolMessageType('LogicalUserListInfo', (_message.Message,), dict(
  DESCRIPTOR = _LOGICALUSERLISTINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """Represents a user list that is a custom combination of user lists.
  
  
  Attributes:
      rules:
          Logical list rules that define this user list. The rules are
          defined as a logical operator (ALL/ANY/NONE) and a list of
          user lists. All the rules are ANDed when they are evaluated.
          Required for creating a logical user list.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.LogicalUserListInfo)
  ))
_sym_db.RegisterMessage(LogicalUserListInfo)

UserListLogicalRuleInfo = _reflection.GeneratedProtocolMessageType('UserListLogicalRuleInfo', (_message.Message,), dict(
  DESCRIPTOR = _USERLISTLOGICALRULEINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """A user list logical rule. A rule has a logical operator (and/or/not) and
  a list of user lists as operands.
  
  
  Attributes:
      operator:
          The logical operator of the rule.
      rule_operands:
          The list of operands of the rule.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.UserListLogicalRuleInfo)
  ))
_sym_db.RegisterMessage(UserListLogicalRuleInfo)

LogicalUserListOperandInfo = _reflection.GeneratedProtocolMessageType('LogicalUserListOperandInfo', (_message.Message,), dict(
  DESCRIPTOR = _LOGICALUSERLISTOPERANDINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """Operand of logical user list that consists of a user list.
  
  
  Attributes:
      user_list:
          Resource name of a user list as an operand.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.LogicalUserListOperandInfo)
  ))
_sym_db.RegisterMessage(LogicalUserListOperandInfo)

BasicUserListInfo = _reflection.GeneratedProtocolMessageType('BasicUserListInfo', (_message.Message,), dict(
  DESCRIPTOR = _BASICUSERLISTINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """User list targeting as a collection of conversions or remarketing
  actions.
  
  
  Attributes:
      actions:
          Actions associated with this user list.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.BasicUserListInfo)
  ))
_sym_db.RegisterMessage(BasicUserListInfo)

UserListActionInfo = _reflection.GeneratedProtocolMessageType('UserListActionInfo', (_message.Message,), dict(
  DESCRIPTOR = _USERLISTACTIONINFO,
  __module__ = 'google.ads.googleads_v2.proto.common.user_lists_pb2'
  ,
  __doc__ = """Represents an action type used for building remarketing user lists.
  
  
  Attributes:
      user_list_action:
          Subtypes of user list action.
      conversion_action:
          A conversion action that's not generated from remarketing.
      remarketing_action:
          A remarketing action.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.UserListActionInfo)
  ))
_sym_db.RegisterMessage(UserListActionInfo)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
