# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/keyword_plan_keyword.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.enums import keyword_match_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_keyword__match__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/keyword_plan_keyword.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\027KeywordPlanKeywordProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\nBgoogle/ads/googleads_v1/proto/resources/keyword_plan_keyword.proto\x12!google.ads.googleads.v1.resources\x1a<google/ads/googleads_v1/proto/enums/keyword_match_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xcc\x02\n\x12KeywordPlanKeyword\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12;\n\x15keyword_plan_ad_group\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\'\n\x02id\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12*\n\x04text\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12X\n\nmatch_type\x18\x05 \x01(\x0e\x32\x44.google.ads.googleads.v1.enums.KeywordMatchTypeEnum.KeywordMatchType\x12\x33\n\x0e\x63pc_bid_micros\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x84\x02\n%com.google.ads.googleads.v1.resourcesB\x17KeywordPlanKeywordProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_keyword__match__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_KEYWORDPLANKEYWORD = _descriptor.Descriptor(
  name='KeywordPlanKeyword',
  full_name='google.ads.googleads.v1.resources.KeywordPlanKeyword',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.KeywordPlanKeyword.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_plan_ad_group', full_name='google.ads.googleads.v1.resources.KeywordPlanKeyword.keyword_plan_ad_group', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v1.resources.KeywordPlanKeyword.id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='google.ads.googleads.v1.resources.KeywordPlanKeyword.text', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_type', full_name='google.ads.googleads.v1.resources.KeywordPlanKeyword.match_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpc_bid_micros', full_name='google.ads.googleads.v1.resources.KeywordPlanKeyword.cpc_bid_micros', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=230,
  serialized_end=562,
)

_KEYWORDPLANKEYWORD.fields_by_name['keyword_plan_ad_group'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_KEYWORDPLANKEYWORD.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_KEYWORDPLANKEYWORD.fields_by_name['text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_KEYWORDPLANKEYWORD.fields_by_name['match_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_keyword__match__type__pb2._KEYWORDMATCHTYPEENUM_KEYWORDMATCHTYPE
_KEYWORDPLANKEYWORD.fields_by_name['cpc_bid_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
DESCRIPTOR.message_types_by_name['KeywordPlanKeyword'] = _KEYWORDPLANKEYWORD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KeywordPlanKeyword = _reflection.GeneratedProtocolMessageType('KeywordPlanKeyword', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDPLANKEYWORD,
  __module__ = 'google.ads.googleads_v1.proto.resources.keyword_plan_keyword_pb2'
  ,
  __doc__ = """A Keyword Plan ad group keyword. Max number of keyword plan keywords per
  plan: 2500.
  
  
  Attributes:
      resource_name:
          The resource name of the Keyword Plan ad group keyword.
          KeywordPlanKeyword resource names have the form:  ``customers/
          {customer_id}/keywordPlanKeywords/{kp_ad_group_keyword_id}``
      keyword_plan_ad_group:
          The Keyword Plan ad group to which this keyword belongs.
      id:
          The ID of the Keyword Plan keyword.
      text:
          The keyword text.
      match_type:
          The keyword match type.
      cpc_bid_micros:
          A keyword level max cpc bid in micros, in the account
          currency, that overrides the keyword plan ad group cpc bid.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.KeywordPlanKeyword)
  ))
_sym_db.RegisterMessage(KeywordPlanKeyword)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
