# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/campaign_experiment.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.enums import campaign_experiment_status_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_campaign__experiment__status__pb2
from google.ads.google_ads.v1.proto.enums import campaign_experiment_traffic_split_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_campaign__experiment__traffic__split__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/campaign_experiment.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\027CampaignExperimentProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\nAgoogle/ads/googleads_v1/proto/resources/campaign_experiment.proto\x12!google.ads.googleads.v1.resources\x1a\x44google/ads/googleads_v1/proto/enums/campaign_experiment_status.proto\x1aPgoogle/ads/googleads_v1/proto/enums/campaign_experiment_traffic_split_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xed\x05\n\x12\x43\x61mpaignExperiment\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\'\n\x02id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x34\n\x0e\x63\x61mpaign_draft\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0b\x64\x65scription\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\x15traffic_split_percent\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x84\x01\n\x12traffic_split_type\x18\x07 \x01(\x0e\x32h.google.ads.googleads.v1.enums.CampaignExperimentTrafficSplitTypeEnum.CampaignExperimentTrafficSplitType\x12\x39\n\x13\x65xperiment_campaign\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x64\n\x06status\x18\t \x01(\x0e\x32T.google.ads.googleads.v1.enums.CampaignExperimentStatusEnum.CampaignExperimentStatus\x12<\n\x16long_running_operation\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\nstart_date\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08\x65nd_date\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x84\x02\n%com.google.ads.googleads.v1.resourcesB\x17\x43\x61mpaignExperimentProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_campaign__experiment__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_campaign__experiment__traffic__split__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_CAMPAIGNEXPERIMENT = _descriptor.Descriptor(
  name='CampaignExperiment',
  full_name='google.ads.googleads.v1.resources.CampaignExperiment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.CampaignExperiment.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v1.resources.CampaignExperiment.id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_draft', full_name='google.ads.googleads.v1.resources.CampaignExperiment.campaign_draft', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v1.resources.CampaignExperiment.name', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='google.ads.googleads.v1.resources.CampaignExperiment.description', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='traffic_split_percent', full_name='google.ads.googleads.v1.resources.CampaignExperiment.traffic_split_percent', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='traffic_split_type', full_name='google.ads.googleads.v1.resources.CampaignExperiment.traffic_split_type', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='experiment_campaign', full_name='google.ads.googleads.v1.resources.CampaignExperiment.experiment_campaign', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v1.resources.CampaignExperiment.status', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='long_running_operation', full_name='google.ads.googleads.v1.resources.CampaignExperiment.long_running_operation', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_date', full_name='google.ads.googleads.v1.resources.CampaignExperiment.start_date', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_date', full_name='google.ads.googleads.v1.resources.CampaignExperiment.end_date', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=319,
  serialized_end=1068,
)

_CAMPAIGNEXPERIMENT.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CAMPAIGNEXPERIMENT.fields_by_name['campaign_draft'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGNEXPERIMENT.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGNEXPERIMENT.fields_by_name['description'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGNEXPERIMENT.fields_by_name['traffic_split_percent'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CAMPAIGNEXPERIMENT.fields_by_name['traffic_split_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_campaign__experiment__traffic__split__type__pb2._CAMPAIGNEXPERIMENTTRAFFICSPLITTYPEENUM_CAMPAIGNEXPERIMENTTRAFFICSPLITTYPE
_CAMPAIGNEXPERIMENT.fields_by_name['experiment_campaign'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGNEXPERIMENT.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_campaign__experiment__status__pb2._CAMPAIGNEXPERIMENTSTATUSENUM_CAMPAIGNEXPERIMENTSTATUS
_CAMPAIGNEXPERIMENT.fields_by_name['long_running_operation'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGNEXPERIMENT.fields_by_name['start_date'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGNEXPERIMENT.fields_by_name['end_date'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['CampaignExperiment'] = _CAMPAIGNEXPERIMENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CampaignExperiment = _reflection.GeneratedProtocolMessageType('CampaignExperiment', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNEXPERIMENT,
  __module__ = 'google.ads.googleads_v1.proto.resources.campaign_experiment_pb2'
  ,
  __doc__ = """An A/B experiment that compares the performance of the base campaign
  (the control) and a variation of that campaign (the experiment).
  
  
  Attributes:
      resource_name:
          The resource name of the campaign experiment. Campaign
          experiment resource names have the form:  ``customers/{custome
          r_id}/campaignExperiments/{campaign_experiment_id}``
      id:
          The ID of the campaign experiment.  This field is read-only.
      campaign_draft:
          The campaign draft with staged changes to the base campaign.
      name:
          The name of the campaign experiment.  This field is required
          when creating new campaign experiments and must not conflict
          with the name of another non-removed campaign experiment or
          campaign.  It must not contain any null (code point 0x0), NL
          line feed (code point 0xA) or carriage return (code point 0xD)
          characters.
      description:
          The description of the experiment.
      traffic_split_percent:
          Share of traffic directed to experiment as a percent (must be
          between 1 and 99 inclusive. Base campaign receives the
          remainder of the traffic (100 - traffic\_split\_percent).
          Required for create.
      traffic_split_type:
          Determines the behavior of the traffic split.
      experiment_campaign:
          The experiment campaign, as opposed to the base campaign.
      status:
          The status of the campaign experiment. This field is read-
          only.
      long_running_operation:
          The resource name of the long-running operation that can be
          used to poll for completion of experiment create or promote.
          The most recent long running operation is returned.
      start_date:
          Date when the campaign experiment starts. By default, the
          experiment starts now or on the campaign's start date,
          whichever is later. If this field is set, then the experiment
          starts at the beginning of the specified date in the
          customer's time zone. Cannot be changed once the experiment
          starts.  Format: YYYY-MM-DD Example: 2019-03-14
      end_date:
          Date when the campaign experiment ends. By default, the
          experiment ends on the campaign's end date. If this field is
          set, then the experiment ends at the end of the specified date
          in the customer's time zone.  Format: YYYY-MM-DD Example:
          2019-04-18
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.CampaignExperiment)
  ))
_sym_db.RegisterMessage(CampaignExperiment)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
