# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/recommendation.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.common import criteria_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_criteria__pb2
from google.ads.google_ads.v1.proto.common import extensions_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_extensions__pb2
from google.ads.google_ads.v1.proto.enums import keyword_match_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_keyword__match__type__pb2
from google.ads.google_ads.v1.proto.enums import recommendation_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_recommendation__type__pb2
from google.ads.google_ads.v1.proto.enums import target_cpa_opt_in_recommendation_goal_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_target__cpa__opt__in__recommendation__goal__pb2
from google.ads.google_ads.v1.proto.resources import ad_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_ad__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/recommendation.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\023RecommendationProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\n<google/ads/googleads_v1/proto/resources/recommendation.proto\x12!google.ads.googleads.v1.resources\x1a\x33google/ads/googleads_v1/proto/common/criteria.proto\x1a\x35google/ads/googleads_v1/proto/common/extensions.proto\x1a<google/ads/googleads_v1/proto/enums/keyword_match_type.proto\x1a=google/ads/googleads_v1/proto/enums/recommendation_type.proto\x1aOgoogle/ads/googleads_v1/proto/enums/target_cpa_opt_in_recommendation_goal.proto\x1a\x30google/ads/googleads_v1/proto/resources/ad.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xd8(\n\x0eRecommendation\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12V\n\x04type\x18\x02 \x01(\x0e\x32H.google.ads.googleads.v1.enums.RecommendationTypeEnum.RecommendationType\x12V\n\x06impact\x18\x03 \x01(\x0b\x32\x46.google.ads.googleads.v1.resources.Recommendation.RecommendationImpact\x12\x35\n\x0f\x63\x61mpaign_budget\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08\x63\x61mpaign\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08\x61\x64_group\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\tdismissed\x18\r \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12x\n\x1e\x63\x61mpaign_budget_recommendation\x18\x04 \x01(\x0b\x32N.google.ads.googleads.v1.resources.Recommendation.CampaignBudgetRecommendationH\x00\x12i\n\x16keyword_recommendation\x18\x08 \x01(\x0b\x32G.google.ads.googleads.v1.resources.Recommendation.KeywordRecommendationH\x00\x12h\n\x16text_ad_recommendation\x18\t \x01(\x0b\x32\x46.google.ads.googleads.v1.resources.Recommendation.TextAdRecommendationH\x00\x12z\n target_cpa_opt_in_recommendation\x18\n \x01(\x0b\x32N.google.ads.googleads.v1.resources.Recommendation.TargetCpaOptInRecommendationH\x00\x12\x8e\x01\n*maximize_conversions_opt_in_recommendation\x18\x0b \x01(\x0b\x32X.google.ads.googleads.v1.resources.Recommendation.MaximizeConversionsOptInRecommendationH\x00\x12~\n\"enhanced_cpc_opt_in_recommendation\x18\x0c \x01(\x0b\x32P.google.ads.googleads.v1.resources.Recommendation.EnhancedCpcOptInRecommendationH\x00\x12\x84\x01\n%search_partners_opt_in_recommendation\x18\x0e \x01(\x0b\x32S.google.ads.googleads.v1.resources.Recommendation.SearchPartnersOptInRecommendationH\x00\x12\x84\x01\n%maximize_clicks_opt_in_recommendation\x18\x0f \x01(\x0b\x32S.google.ads.googleads.v1.resources.Recommendation.MaximizeClicksOptInRecommendationH\x00\x12\x81\x01\n#optimize_ad_rotation_recommendation\x18\x10 \x01(\x0b\x32R.google.ads.googleads.v1.resources.Recommendation.OptimizeAdRotationRecommendationH\x00\x12|\n callout_extension_recommendation\x18\x11 \x01(\x0b\x32P.google.ads.googleads.v1.resources.Recommendation.CalloutExtensionRecommendationH\x00\x12~\n!sitelink_extension_recommendation\x18\x12 \x01(\x0b\x32Q.google.ads.googleads.v1.resources.Recommendation.SitelinkExtensionRecommendationH\x00\x12v\n\x1d\x63\x61ll_extension_recommendation\x18\x13 \x01(\x0b\x32M.google.ads.googleads.v1.resources.Recommendation.CallExtensionRecommendationH\x00\x12}\n!keyword_match_type_recommendation\x18\x14 \x01(\x0b\x32P.google.ads.googleads.v1.resources.Recommendation.KeywordMatchTypeRecommendationH\x00\x12}\n!move_unused_budget_recommendation\x18\x15 \x01(\x0b\x32P.google.ads.googleads.v1.resources.Recommendation.MoveUnusedBudgetRecommendationH\x00\x1a\xd9\x01\n\x14RecommendationImpact\x12]\n\x0c\x62\x61se_metrics\x18\x01 \x01(\x0b\x32G.google.ads.googleads.v1.resources.Recommendation.RecommendationMetrics\x12\x62\n\x11potential_metrics\x18\x02 \x01(\x0b\x32G.google.ads.googleads.v1.resources.Recommendation.RecommendationMetrics\x1a\x90\x02\n\x15RecommendationMetrics\x12\x31\n\x0bimpressions\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12,\n\x06\x63licks\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x30\n\x0b\x63ost_micros\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0b\x63onversions\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x31\n\x0bvideo_views\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x1a\xee\x03\n\x1c\x43\x61mpaignBudgetRecommendation\x12\x41\n\x1c\x63urrent_budget_amount_micros\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x45\n recommended_budget_amount_micros\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x89\x01\n\x0e\x62udget_options\x18\x03 \x03(\x0b\x32q.google.ads.googleads.v1.resources.Recommendation.CampaignBudgetRecommendation.CampaignBudgetRecommendationOption\x1a\xb7\x01\n\"CampaignBudgetRecommendationOption\x12\x39\n\x14\x62udget_amount_micros\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12V\n\x06impact\x18\x02 \x01(\x0b\x32\x46.google.ads.googleads.v1.resources.Recommendation.RecommendationImpact\x1a\x96\x01\n\x15KeywordRecommendation\x12<\n\x07keyword\x18\x01 \x01(\x0b\x32+.google.ads.googleads.v1.common.KeywordInfo\x12?\n\x1arecommended_cpc_bid_micros\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1a\xc4\x01\n\x1eKeywordMatchTypeRecommendation\x12<\n\x07keyword\x18\x01 \x01(\x0b\x32+.google.ads.googleads.v1.common.KeywordInfo\x12\x64\n\x16recommended_match_type\x18\x02 \x01(\x0e\x32\x44.google.ads.googleads.v1.enums.KeywordMatchTypeEnum.KeywordMatchType\x1a\xb5\x01\n\x14TextAdRecommendation\x12\x31\n\x02\x61\x64\x18\x01 \x01(\x0b\x32%.google.ads.googleads.v1.resources.Ad\x12\x33\n\rcreation_date\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0f\x61uto_apply_date\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x1a#\n!SearchPartnersOptInRecommendation\x1aj\n!MaximizeClicksOptInRecommendation\x12\x45\n recommended_budget_amount_micros\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1aq\n\x1e\x43\x61lloutExtensionRecommendation\x12O\n\x16recommended_extensions\x18\x01 \x03(\x0b\x32/.google.ads.googleads.v1.common.CalloutFeedItem\x1a\xdf\x04\n\x1cTargetCpaOptInRecommendation\x12\x82\x01\n\x07options\x18\x01 \x03(\x0b\x32q.google.ads.googleads.v1.resources.Recommendation.TargetCpaOptInRecommendation.TargetCpaOptInRecommendationOption\x12\x42\n\x1drecommended_target_cpa_micros\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1a\xf5\x02\n\"TargetCpaOptInRecommendationOption\x12r\n\x04goal\x18\x01 \x01(\x0e\x32\x64.google.ads.googleads.v1.enums.TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal\x12\x36\n\x11target_cpa_micros\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12K\n&required_campaign_budget_amount_micros\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12V\n\x06impact\x18\x04 \x01(\x0b\x32\x46.google.ads.googleads.v1.resources.Recommendation.RecommendationImpact\x1ao\n&MaximizeConversionsOptInRecommendation\x12\x45\n recommended_budget_amount_micros\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1a \n\x1e\x45nhancedCpcOptInRecommendation\x1a\"\n OptimizeAdRotationRecommendation\x1as\n\x1fSitelinkExtensionRecommendation\x12P\n\x16recommended_extensions\x18\x01 \x03(\x0b\x32\x30.google.ads.googleads.v1.common.SitelinkFeedItem\x1ak\n\x1b\x43\x61llExtensionRecommendation\x12L\n\x16recommended_extensions\x18\x01 \x03(\x0b\x32,.google.ads.googleads.v1.common.CallFeedItem\x1a\xcd\x01\n\x1eMoveUnusedBudgetRecommendation\x12<\n\x16\x65xcess_campaign_budget\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12m\n\x15\x62udget_recommendation\x18\x02 \x01(\x0b\x32N.google.ads.googleads.v1.resources.Recommendation.CampaignBudgetRecommendationB\x10\n\x0erecommendationB\x80\x02\n%com.google.ads.googleads.v1.resourcesB\x13RecommendationProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_criteria__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_extensions__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_keyword__match__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_recommendation__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_target__cpa__opt__in__recommendation__goal__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_ad__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_RECOMMENDATION_RECOMMENDATIONIMPACT = _descriptor.Descriptor(
  name='RecommendationImpact',
  full_name='google.ads.googleads.v1.resources.Recommendation.RecommendationImpact',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_metrics', full_name='google.ads.googleads.v1.resources.Recommendation.RecommendationImpact.base_metrics', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='potential_metrics', full_name='google.ads.googleads.v1.resources.Recommendation.RecommendationImpact.potential_metrics', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2704,
  serialized_end=2921,
)

_RECOMMENDATION_RECOMMENDATIONMETRICS = _descriptor.Descriptor(
  name='RecommendationMetrics',
  full_name='google.ads.googleads.v1.resources.Recommendation.RecommendationMetrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='impressions', full_name='google.ads.googleads.v1.resources.Recommendation.RecommendationMetrics.impressions', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clicks', full_name='google.ads.googleads.v1.resources.Recommendation.RecommendationMetrics.clicks', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cost_micros', full_name='google.ads.googleads.v1.resources.Recommendation.RecommendationMetrics.cost_micros', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversions', full_name='google.ads.googleads.v1.resources.Recommendation.RecommendationMetrics.conversions', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='video_views', full_name='google.ads.googleads.v1.resources.Recommendation.RecommendationMetrics.video_views', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2924,
  serialized_end=3196,
)

_RECOMMENDATION_CAMPAIGNBUDGETRECOMMENDATION_CAMPAIGNBUDGETRECOMMENDATIONOPTION = _descriptor.Descriptor(
  name='CampaignBudgetRecommendationOption',
  full_name='google.ads.googleads.v1.resources.Recommendation.CampaignBudgetRecommendation.CampaignBudgetRecommendationOption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='budget_amount_micros', full_name='google.ads.googleads.v1.resources.Recommendation.CampaignBudgetRecommendation.CampaignBudgetRecommendationOption.budget_amount_micros', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='impact', full_name='google.ads.googleads.v1.resources.Recommendation.CampaignBudgetRecommendation.CampaignBudgetRecommendationOption.impact', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3510,
  serialized_end=3693,
)

_RECOMMENDATION_CAMPAIGNBUDGETRECOMMENDATION = _descriptor.Descriptor(
  name='CampaignBudgetRecommendation',
  full_name='google.ads.googleads.v1.resources.Recommendation.CampaignBudgetRecommendation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='current_budget_amount_micros', full_name='google.ads.googleads.v1.resources.Recommendation.CampaignBudgetRecommendation.current_budget_amount_micros', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recommended_budget_amount_micros', full_name='google.ads.googleads.v1.resources.Recommendation.CampaignBudgetRecommendation.recommended_budget_amount_micros', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='budget_options', full_name='google.ads.googleads.v1.resources.Recommendation.CampaignBudgetRecommendation.budget_options', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_RECOMMENDATION_CAMPAIGNBUDGETRECOMMENDATION_CAMPAIGNBUDGETRECOMMENDATIONOPTION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3199,
  serialized_end=3693,
)

_RECOMMENDATION_KEYWORDRECOMMENDATION = _descriptor.Descriptor(
  name='KeywordRecommendation',
  full_name='google.ads.googleads.v1.resources.Recommendation.KeywordRecommendation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='keyword', full_name='google.ads.googleads.v1.resources.Recommendation.KeywordRecommendation.keyword', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recommended_cpc_bid_micros', full_name='google.ads.googleads.v1.resources.Recommendation.KeywordRecommendation.recommended_cpc_bid_micros', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3696,
  serialized_end=3846,
)

_RECOMMENDATION_KEYWORDMATCHTYPERECOMMENDATION = _descriptor.Descriptor(
  name='KeywordMatchTypeRecommendation',
  full_name='google.ads.googleads.v1.resources.Recommendation.KeywordMatchTypeRecommendation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='keyword', full_name='google.ads.googleads.v1.resources.Recommendation.KeywordMatchTypeRecommendation.keyword', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recommended_match_type', full_name='google.ads.googleads.v1.resources.Recommendation.KeywordMatchTypeRecommendation.recommended_match_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3849,
  serialized_end=4045,
)

_RECOMMENDATION_TEXTADRECOMMENDATION = _descriptor.Descriptor(
  name='TextAdRecommendation',
  full_name='google.ads.googleads.v1.resources.Recommendation.TextAdRecommendation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ad', full_name='google.ads.googleads.v1.resources.Recommendation.TextAdRecommendation.ad', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creation_date', full_name='google.ads.googleads.v1.resources.Recommendation.TextAdRecommendation.creation_date', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auto_apply_date', full_name='google.ads.googleads.v1.resources.Recommendation.TextAdRecommendation.auto_apply_date', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4048,
  serialized_end=4229,
)

_RECOMMENDATION_SEARCHPARTNERSOPTINRECOMMENDATION = _descriptor.Descriptor(
  name='SearchPartnersOptInRecommendation',
  full_name='google.ads.googleads.v1.resources.Recommendation.SearchPartnersOptInRecommendation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4231,
  serialized_end=4266,
)

_RECOMMENDATION_MAXIMIZECLICKSOPTINRECOMMENDATION = _descriptor.Descriptor(
  name='MaximizeClicksOptInRecommendation',
  full_name='google.ads.googleads.v1.resources.Recommendation.MaximizeClicksOptInRecommendation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recommended_budget_amount_micros', full_name='google.ads.googleads.v1.resources.Recommendation.MaximizeClicksOptInRecommendation.recommended_budget_amount_micros', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4268,
  serialized_end=4374,
)

_RECOMMENDATION_CALLOUTEXTENSIONRECOMMENDATION = _descriptor.Descriptor(
  name='CalloutExtensionRecommendation',
  full_name='google.ads.googleads.v1.resources.Recommendation.CalloutExtensionRecommendation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recommended_extensions', full_name='google.ads.googleads.v1.resources.Recommendation.CalloutExtensionRecommendation.recommended_extensions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4376,
  serialized_end=4489,
)

_RECOMMENDATION_TARGETCPAOPTINRECOMMENDATION_TARGETCPAOPTINRECOMMENDATIONOPTION = _descriptor.Descriptor(
  name='TargetCpaOptInRecommendationOption',
  full_name='google.ads.googleads.v1.resources.Recommendation.TargetCpaOptInRecommendation.TargetCpaOptInRecommendationOption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='goal', full_name='google.ads.googleads.v1.resources.Recommendation.TargetCpaOptInRecommendation.TargetCpaOptInRecommendationOption.goal', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_cpa_micros', full_name='google.ads.googleads.v1.resources.Recommendation.TargetCpaOptInRecommendation.TargetCpaOptInRecommendationOption.target_cpa_micros', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='required_campaign_budget_amount_micros', full_name='google.ads.googleads.v1.resources.Recommendation.TargetCpaOptInRecommendation.TargetCpaOptInRecommendationOption.required_campaign_budget_amount_micros', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='impact', full_name='google.ads.googleads.v1.resources.Recommendation.TargetCpaOptInRecommendation.TargetCpaOptInRecommendationOption.impact', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4726,
  serialized_end=5099,
)

_RECOMMENDATION_TARGETCPAOPTINRECOMMENDATION = _descriptor.Descriptor(
  name='TargetCpaOptInRecommendation',
  full_name='google.ads.googleads.v1.resources.Recommendation.TargetCpaOptInRecommendation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='options', full_name='google.ads.googleads.v1.resources.Recommendation.TargetCpaOptInRecommendation.options', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recommended_target_cpa_micros', full_name='google.ads.googleads.v1.resources.Recommendation.TargetCpaOptInRecommendation.recommended_target_cpa_micros', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_RECOMMENDATION_TARGETCPAOPTINRECOMMENDATION_TARGETCPAOPTINRECOMMENDATIONOPTION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4492,
  serialized_end=5099,
)

_RECOMMENDATION_MAXIMIZECONVERSIONSOPTINRECOMMENDATION = _descriptor.Descriptor(
  name='MaximizeConversionsOptInRecommendation',
  full_name='google.ads.googleads.v1.resources.Recommendation.MaximizeConversionsOptInRecommendation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recommended_budget_amount_micros', full_name='google.ads.googleads.v1.resources.Recommendation.MaximizeConversionsOptInRecommendation.recommended_budget_amount_micros', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5101,
  serialized_end=5212,
)

_RECOMMENDATION_ENHANCEDCPCOPTINRECOMMENDATION = _descriptor.Descriptor(
  name='EnhancedCpcOptInRecommendation',
  full_name='google.ads.googleads.v1.resources.Recommendation.EnhancedCpcOptInRecommendation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5214,
  serialized_end=5246,
)

_RECOMMENDATION_OPTIMIZEADROTATIONRECOMMENDATION = _descriptor.Descriptor(
  name='OptimizeAdRotationRecommendation',
  full_name='google.ads.googleads.v1.resources.Recommendation.OptimizeAdRotationRecommendation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5248,
  serialized_end=5282,
)

_RECOMMENDATION_SITELINKEXTENSIONRECOMMENDATION = _descriptor.Descriptor(
  name='SitelinkExtensionRecommendation',
  full_name='google.ads.googleads.v1.resources.Recommendation.SitelinkExtensionRecommendation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recommended_extensions', full_name='google.ads.googleads.v1.resources.Recommendation.SitelinkExtensionRecommendation.recommended_extensions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5284,
  serialized_end=5399,
)

_RECOMMENDATION_CALLEXTENSIONRECOMMENDATION = _descriptor.Descriptor(
  name='CallExtensionRecommendation',
  full_name='google.ads.googleads.v1.resources.Recommendation.CallExtensionRecommendation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recommended_extensions', full_name='google.ads.googleads.v1.resources.Recommendation.CallExtensionRecommendation.recommended_extensions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5401,
  serialized_end=5508,
)

_RECOMMENDATION_MOVEUNUSEDBUDGETRECOMMENDATION = _descriptor.Descriptor(
  name='MoveUnusedBudgetRecommendation',
  full_name='google.ads.googleads.v1.resources.Recommendation.MoveUnusedBudgetRecommendation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='excess_campaign_budget', full_name='google.ads.googleads.v1.resources.Recommendation.MoveUnusedBudgetRecommendation.excess_campaign_budget', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='budget_recommendation', full_name='google.ads.googleads.v1.resources.Recommendation.MoveUnusedBudgetRecommendation.budget_recommendation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5511,
  serialized_end=5716,
)

_RECOMMENDATION = _descriptor.Descriptor(
  name='Recommendation',
  full_name='google.ads.googleads.v1.resources.Recommendation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.Recommendation.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v1.resources.Recommendation.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='impact', full_name='google.ads.googleads.v1.resources.Recommendation.impact', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_budget', full_name='google.ads.googleads.v1.resources.Recommendation.campaign_budget', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign', full_name='google.ads.googleads.v1.resources.Recommendation.campaign', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group', full_name='google.ads.googleads.v1.resources.Recommendation.ad_group', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dismissed', full_name='google.ads.googleads.v1.resources.Recommendation.dismissed', index=6,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_budget_recommendation', full_name='google.ads.googleads.v1.resources.Recommendation.campaign_budget_recommendation', index=7,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_recommendation', full_name='google.ads.googleads.v1.resources.Recommendation.keyword_recommendation', index=8,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_ad_recommendation', full_name='google.ads.googleads.v1.resources.Recommendation.text_ad_recommendation', index=9,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_cpa_opt_in_recommendation', full_name='google.ads.googleads.v1.resources.Recommendation.target_cpa_opt_in_recommendation', index=10,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maximize_conversions_opt_in_recommendation', full_name='google.ads.googleads.v1.resources.Recommendation.maximize_conversions_opt_in_recommendation', index=11,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enhanced_cpc_opt_in_recommendation', full_name='google.ads.googleads.v1.resources.Recommendation.enhanced_cpc_opt_in_recommendation', index=12,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_partners_opt_in_recommendation', full_name='google.ads.googleads.v1.resources.Recommendation.search_partners_opt_in_recommendation', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maximize_clicks_opt_in_recommendation', full_name='google.ads.googleads.v1.resources.Recommendation.maximize_clicks_opt_in_recommendation', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='optimize_ad_rotation_recommendation', full_name='google.ads.googleads.v1.resources.Recommendation.optimize_ad_rotation_recommendation', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='callout_extension_recommendation', full_name='google.ads.googleads.v1.resources.Recommendation.callout_extension_recommendation', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sitelink_extension_recommendation', full_name='google.ads.googleads.v1.resources.Recommendation.sitelink_extension_recommendation', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_extension_recommendation', full_name='google.ads.googleads.v1.resources.Recommendation.call_extension_recommendation', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_match_type_recommendation', full_name='google.ads.googleads.v1.resources.Recommendation.keyword_match_type_recommendation', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='move_unused_budget_recommendation', full_name='google.ads.googleads.v1.resources.Recommendation.move_unused_budget_recommendation', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_RECOMMENDATION_RECOMMENDATIONIMPACT, _RECOMMENDATION_RECOMMENDATIONMETRICS, _RECOMMENDATION_CAMPAIGNBUDGETRECOMMENDATION, _RECOMMENDATION_KEYWORDRECOMMENDATION, _RECOMMENDATION_KEYWORDMATCHTYPERECOMMENDATION, _RECOMMENDATION_TEXTADRECOMMENDATION, _RECOMMENDATION_SEARCHPARTNERSOPTINRECOMMENDATION, _RECOMMENDATION_MAXIMIZECLICKSOPTINRECOMMENDATION, _RECOMMENDATION_CALLOUTEXTENSIONRECOMMENDATION, _RECOMMENDATION_TARGETCPAOPTINRECOMMENDATION, _RECOMMENDATION_MAXIMIZECONVERSIONSOPTINRECOMMENDATION, _RECOMMENDATION_ENHANCEDCPCOPTINRECOMMENDATION, _RECOMMENDATION_OPTIMIZEADROTATIONRECOMMENDATION, _RECOMMENDATION_SITELINKEXTENSIONRECOMMENDATION, _RECOMMENDATION_CALLEXTENSIONRECOMMENDATION, _RECOMMENDATION_MOVEUNUSEDBUDGETRECOMMENDATION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='recommendation', full_name='google.ads.googleads.v1.resources.Recommendation.recommendation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=526,
  serialized_end=5734,
)

_RECOMMENDATION_RECOMMENDATIONIMPACT.fields_by_name['base_metrics'].message_type = _RECOMMENDATION_RECOMMENDATIONMETRICS
_RECOMMENDATION_RECOMMENDATIONIMPACT.fields_by_name['potential_metrics'].message_type = _RECOMMENDATION_RECOMMENDATIONMETRICS
_RECOMMENDATION_RECOMMENDATIONIMPACT.containing_type = _RECOMMENDATION
_RECOMMENDATION_RECOMMENDATIONMETRICS.fields_by_name['impressions'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_RECOMMENDATION_RECOMMENDATIONMETRICS.fields_by_name['clicks'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_RECOMMENDATION_RECOMMENDATIONMETRICS.fields_by_name['cost_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_RECOMMENDATION_RECOMMENDATIONMETRICS.fields_by_name['conversions'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_RECOMMENDATION_RECOMMENDATIONMETRICS.fields_by_name['video_views'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_RECOMMENDATION_RECOMMENDATIONMETRICS.containing_type = _RECOMMENDATION
_RECOMMENDATION_CAMPAIGNBUDGETRECOMMENDATION_CAMPAIGNBUDGETRECOMMENDATIONOPTION.fields_by_name['budget_amount_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_RECOMMENDATION_CAMPAIGNBUDGETRECOMMENDATION_CAMPAIGNBUDGETRECOMMENDATIONOPTION.fields_by_name['impact'].message_type = _RECOMMENDATION_RECOMMENDATIONIMPACT
_RECOMMENDATION_CAMPAIGNBUDGETRECOMMENDATION_CAMPAIGNBUDGETRECOMMENDATIONOPTION.containing_type = _RECOMMENDATION_CAMPAIGNBUDGETRECOMMENDATION
_RECOMMENDATION_CAMPAIGNBUDGETRECOMMENDATION.fields_by_name['current_budget_amount_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_RECOMMENDATION_CAMPAIGNBUDGETRECOMMENDATION.fields_by_name['recommended_budget_amount_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_RECOMMENDATION_CAMPAIGNBUDGETRECOMMENDATION.fields_by_name['budget_options'].message_type = _RECOMMENDATION_CAMPAIGNBUDGETRECOMMENDATION_CAMPAIGNBUDGETRECOMMENDATIONOPTION
_RECOMMENDATION_CAMPAIGNBUDGETRECOMMENDATION.containing_type = _RECOMMENDATION
_RECOMMENDATION_KEYWORDRECOMMENDATION.fields_by_name['keyword'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_criteria__pb2._KEYWORDINFO
_RECOMMENDATION_KEYWORDRECOMMENDATION.fields_by_name['recommended_cpc_bid_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_RECOMMENDATION_KEYWORDRECOMMENDATION.containing_type = _RECOMMENDATION
_RECOMMENDATION_KEYWORDMATCHTYPERECOMMENDATION.fields_by_name['keyword'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_criteria__pb2._KEYWORDINFO
_RECOMMENDATION_KEYWORDMATCHTYPERECOMMENDATION.fields_by_name['recommended_match_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_keyword__match__type__pb2._KEYWORDMATCHTYPEENUM_KEYWORDMATCHTYPE
_RECOMMENDATION_KEYWORDMATCHTYPERECOMMENDATION.containing_type = _RECOMMENDATION
_RECOMMENDATION_TEXTADRECOMMENDATION.fields_by_name['ad'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_ad__pb2._AD
_RECOMMENDATION_TEXTADRECOMMENDATION.fields_by_name['creation_date'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RECOMMENDATION_TEXTADRECOMMENDATION.fields_by_name['auto_apply_date'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RECOMMENDATION_TEXTADRECOMMENDATION.containing_type = _RECOMMENDATION
_RECOMMENDATION_SEARCHPARTNERSOPTINRECOMMENDATION.containing_type = _RECOMMENDATION
_RECOMMENDATION_MAXIMIZECLICKSOPTINRECOMMENDATION.fields_by_name['recommended_budget_amount_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_RECOMMENDATION_MAXIMIZECLICKSOPTINRECOMMENDATION.containing_type = _RECOMMENDATION
_RECOMMENDATION_CALLOUTEXTENSIONRECOMMENDATION.fields_by_name['recommended_extensions'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_extensions__pb2._CALLOUTFEEDITEM
_RECOMMENDATION_CALLOUTEXTENSIONRECOMMENDATION.containing_type = _RECOMMENDATION
_RECOMMENDATION_TARGETCPAOPTINRECOMMENDATION_TARGETCPAOPTINRECOMMENDATIONOPTION.fields_by_name['goal'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_target__cpa__opt__in__recommendation__goal__pb2._TARGETCPAOPTINRECOMMENDATIONGOALENUM_TARGETCPAOPTINRECOMMENDATIONGOAL
_RECOMMENDATION_TARGETCPAOPTINRECOMMENDATION_TARGETCPAOPTINRECOMMENDATIONOPTION.fields_by_name['target_cpa_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_RECOMMENDATION_TARGETCPAOPTINRECOMMENDATION_TARGETCPAOPTINRECOMMENDATIONOPTION.fields_by_name['required_campaign_budget_amount_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_RECOMMENDATION_TARGETCPAOPTINRECOMMENDATION_TARGETCPAOPTINRECOMMENDATIONOPTION.fields_by_name['impact'].message_type = _RECOMMENDATION_RECOMMENDATIONIMPACT
_RECOMMENDATION_TARGETCPAOPTINRECOMMENDATION_TARGETCPAOPTINRECOMMENDATIONOPTION.containing_type = _RECOMMENDATION_TARGETCPAOPTINRECOMMENDATION
_RECOMMENDATION_TARGETCPAOPTINRECOMMENDATION.fields_by_name['options'].message_type = _RECOMMENDATION_TARGETCPAOPTINRECOMMENDATION_TARGETCPAOPTINRECOMMENDATIONOPTION
_RECOMMENDATION_TARGETCPAOPTINRECOMMENDATION.fields_by_name['recommended_target_cpa_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_RECOMMENDATION_TARGETCPAOPTINRECOMMENDATION.containing_type = _RECOMMENDATION
_RECOMMENDATION_MAXIMIZECONVERSIONSOPTINRECOMMENDATION.fields_by_name['recommended_budget_amount_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_RECOMMENDATION_MAXIMIZECONVERSIONSOPTINRECOMMENDATION.containing_type = _RECOMMENDATION
_RECOMMENDATION_ENHANCEDCPCOPTINRECOMMENDATION.containing_type = _RECOMMENDATION
_RECOMMENDATION_OPTIMIZEADROTATIONRECOMMENDATION.containing_type = _RECOMMENDATION
_RECOMMENDATION_SITELINKEXTENSIONRECOMMENDATION.fields_by_name['recommended_extensions'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_extensions__pb2._SITELINKFEEDITEM
_RECOMMENDATION_SITELINKEXTENSIONRECOMMENDATION.containing_type = _RECOMMENDATION
_RECOMMENDATION_CALLEXTENSIONRECOMMENDATION.fields_by_name['recommended_extensions'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_extensions__pb2._CALLFEEDITEM
_RECOMMENDATION_CALLEXTENSIONRECOMMENDATION.containing_type = _RECOMMENDATION
_RECOMMENDATION_MOVEUNUSEDBUDGETRECOMMENDATION.fields_by_name['excess_campaign_budget'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RECOMMENDATION_MOVEUNUSEDBUDGETRECOMMENDATION.fields_by_name['budget_recommendation'].message_type = _RECOMMENDATION_CAMPAIGNBUDGETRECOMMENDATION
_RECOMMENDATION_MOVEUNUSEDBUDGETRECOMMENDATION.containing_type = _RECOMMENDATION
_RECOMMENDATION.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_recommendation__type__pb2._RECOMMENDATIONTYPEENUM_RECOMMENDATIONTYPE
_RECOMMENDATION.fields_by_name['impact'].message_type = _RECOMMENDATION_RECOMMENDATIONIMPACT
_RECOMMENDATION.fields_by_name['campaign_budget'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RECOMMENDATION.fields_by_name['campaign'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RECOMMENDATION.fields_by_name['ad_group'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RECOMMENDATION.fields_by_name['dismissed'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_RECOMMENDATION.fields_by_name['campaign_budget_recommendation'].message_type = _RECOMMENDATION_CAMPAIGNBUDGETRECOMMENDATION
_RECOMMENDATION.fields_by_name['keyword_recommendation'].message_type = _RECOMMENDATION_KEYWORDRECOMMENDATION
_RECOMMENDATION.fields_by_name['text_ad_recommendation'].message_type = _RECOMMENDATION_TEXTADRECOMMENDATION
_RECOMMENDATION.fields_by_name['target_cpa_opt_in_recommendation'].message_type = _RECOMMENDATION_TARGETCPAOPTINRECOMMENDATION
_RECOMMENDATION.fields_by_name['maximize_conversions_opt_in_recommendation'].message_type = _RECOMMENDATION_MAXIMIZECONVERSIONSOPTINRECOMMENDATION
_RECOMMENDATION.fields_by_name['enhanced_cpc_opt_in_recommendation'].message_type = _RECOMMENDATION_ENHANCEDCPCOPTINRECOMMENDATION
_RECOMMENDATION.fields_by_name['search_partners_opt_in_recommendation'].message_type = _RECOMMENDATION_SEARCHPARTNERSOPTINRECOMMENDATION
_RECOMMENDATION.fields_by_name['maximize_clicks_opt_in_recommendation'].message_type = _RECOMMENDATION_MAXIMIZECLICKSOPTINRECOMMENDATION
_RECOMMENDATION.fields_by_name['optimize_ad_rotation_recommendation'].message_type = _RECOMMENDATION_OPTIMIZEADROTATIONRECOMMENDATION
_RECOMMENDATION.fields_by_name['callout_extension_recommendation'].message_type = _RECOMMENDATION_CALLOUTEXTENSIONRECOMMENDATION
_RECOMMENDATION.fields_by_name['sitelink_extension_recommendation'].message_type = _RECOMMENDATION_SITELINKEXTENSIONRECOMMENDATION
_RECOMMENDATION.fields_by_name['call_extension_recommendation'].message_type = _RECOMMENDATION_CALLEXTENSIONRECOMMENDATION
_RECOMMENDATION.fields_by_name['keyword_match_type_recommendation'].message_type = _RECOMMENDATION_KEYWORDMATCHTYPERECOMMENDATION
_RECOMMENDATION.fields_by_name['move_unused_budget_recommendation'].message_type = _RECOMMENDATION_MOVEUNUSEDBUDGETRECOMMENDATION
_RECOMMENDATION.oneofs_by_name['recommendation'].fields.append(
  _RECOMMENDATION.fields_by_name['campaign_budget_recommendation'])
_RECOMMENDATION.fields_by_name['campaign_budget_recommendation'].containing_oneof = _RECOMMENDATION.oneofs_by_name['recommendation']
_RECOMMENDATION.oneofs_by_name['recommendation'].fields.append(
  _RECOMMENDATION.fields_by_name['keyword_recommendation'])
_RECOMMENDATION.fields_by_name['keyword_recommendation'].containing_oneof = _RECOMMENDATION.oneofs_by_name['recommendation']
_RECOMMENDATION.oneofs_by_name['recommendation'].fields.append(
  _RECOMMENDATION.fields_by_name['text_ad_recommendation'])
_RECOMMENDATION.fields_by_name['text_ad_recommendation'].containing_oneof = _RECOMMENDATION.oneofs_by_name['recommendation']
_RECOMMENDATION.oneofs_by_name['recommendation'].fields.append(
  _RECOMMENDATION.fields_by_name['target_cpa_opt_in_recommendation'])
_RECOMMENDATION.fields_by_name['target_cpa_opt_in_recommendation'].containing_oneof = _RECOMMENDATION.oneofs_by_name['recommendation']
_RECOMMENDATION.oneofs_by_name['recommendation'].fields.append(
  _RECOMMENDATION.fields_by_name['maximize_conversions_opt_in_recommendation'])
_RECOMMENDATION.fields_by_name['maximize_conversions_opt_in_recommendation'].containing_oneof = _RECOMMENDATION.oneofs_by_name['recommendation']
_RECOMMENDATION.oneofs_by_name['recommendation'].fields.append(
  _RECOMMENDATION.fields_by_name['enhanced_cpc_opt_in_recommendation'])
_RECOMMENDATION.fields_by_name['enhanced_cpc_opt_in_recommendation'].containing_oneof = _RECOMMENDATION.oneofs_by_name['recommendation']
_RECOMMENDATION.oneofs_by_name['recommendation'].fields.append(
  _RECOMMENDATION.fields_by_name['search_partners_opt_in_recommendation'])
_RECOMMENDATION.fields_by_name['search_partners_opt_in_recommendation'].containing_oneof = _RECOMMENDATION.oneofs_by_name['recommendation']
_RECOMMENDATION.oneofs_by_name['recommendation'].fields.append(
  _RECOMMENDATION.fields_by_name['maximize_clicks_opt_in_recommendation'])
_RECOMMENDATION.fields_by_name['maximize_clicks_opt_in_recommendation'].containing_oneof = _RECOMMENDATION.oneofs_by_name['recommendation']
_RECOMMENDATION.oneofs_by_name['recommendation'].fields.append(
  _RECOMMENDATION.fields_by_name['optimize_ad_rotation_recommendation'])
_RECOMMENDATION.fields_by_name['optimize_ad_rotation_recommendation'].containing_oneof = _RECOMMENDATION.oneofs_by_name['recommendation']
_RECOMMENDATION.oneofs_by_name['recommendation'].fields.append(
  _RECOMMENDATION.fields_by_name['callout_extension_recommendation'])
_RECOMMENDATION.fields_by_name['callout_extension_recommendation'].containing_oneof = _RECOMMENDATION.oneofs_by_name['recommendation']
_RECOMMENDATION.oneofs_by_name['recommendation'].fields.append(
  _RECOMMENDATION.fields_by_name['sitelink_extension_recommendation'])
_RECOMMENDATION.fields_by_name['sitelink_extension_recommendation'].containing_oneof = _RECOMMENDATION.oneofs_by_name['recommendation']
_RECOMMENDATION.oneofs_by_name['recommendation'].fields.append(
  _RECOMMENDATION.fields_by_name['call_extension_recommendation'])
_RECOMMENDATION.fields_by_name['call_extension_recommendation'].containing_oneof = _RECOMMENDATION.oneofs_by_name['recommendation']
_RECOMMENDATION.oneofs_by_name['recommendation'].fields.append(
  _RECOMMENDATION.fields_by_name['keyword_match_type_recommendation'])
_RECOMMENDATION.fields_by_name['keyword_match_type_recommendation'].containing_oneof = _RECOMMENDATION.oneofs_by_name['recommendation']
_RECOMMENDATION.oneofs_by_name['recommendation'].fields.append(
  _RECOMMENDATION.fields_by_name['move_unused_budget_recommendation'])
_RECOMMENDATION.fields_by_name['move_unused_budget_recommendation'].containing_oneof = _RECOMMENDATION.oneofs_by_name['recommendation']
DESCRIPTOR.message_types_by_name['Recommendation'] = _RECOMMENDATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Recommendation = _reflection.GeneratedProtocolMessageType('Recommendation', (_message.Message,), dict(

  RecommendationImpact = _reflection.GeneratedProtocolMessageType('RecommendationImpact', (_message.Message,), dict(
    DESCRIPTOR = _RECOMMENDATION_RECOMMENDATIONIMPACT,
    __module__ = 'google.ads.googleads_v1.proto.resources.recommendation_pb2'
    ,
    __doc__ = """The impact of making the change as described in the recommendation. Some
    types of recommendations may not have impact information.
    
    
    Attributes:
        base_metrics:
            Base metrics at the time the recommendation was generated.
        potential_metrics:
            Estimated metrics if the recommendation is applied.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.Recommendation.RecommendationImpact)
    ))
  ,

  RecommendationMetrics = _reflection.GeneratedProtocolMessageType('RecommendationMetrics', (_message.Message,), dict(
    DESCRIPTOR = _RECOMMENDATION_RECOMMENDATIONMETRICS,
    __module__ = 'google.ads.googleads_v1.proto.resources.recommendation_pb2'
    ,
    __doc__ = """Weekly account performance metrics. For some recommendation types, these
    are averaged over the past 90-day period and hence can be fractional.
    
    
    Attributes:
        impressions:
            Number of ad impressions.
        clicks:
            Number of ad clicks.
        cost_micros:
            Cost (in micros) for advertising, in the local currency for
            the account.
        conversions:
            Number of conversions.
        video_views:
            Number of video views for a video ad campaign.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.Recommendation.RecommendationMetrics)
    ))
  ,

  CampaignBudgetRecommendation = _reflection.GeneratedProtocolMessageType('CampaignBudgetRecommendation', (_message.Message,), dict(

    CampaignBudgetRecommendationOption = _reflection.GeneratedProtocolMessageType('CampaignBudgetRecommendationOption', (_message.Message,), dict(
      DESCRIPTOR = _RECOMMENDATION_CAMPAIGNBUDGETRECOMMENDATION_CAMPAIGNBUDGETRECOMMENDATIONOPTION,
      __module__ = 'google.ads.googleads_v1.proto.resources.recommendation_pb2'
      ,
      __doc__ = """The impact estimates for a given budget amount.
      
      
      Attributes:
          budget_amount_micros:
              The budget amount for this option.
          impact:
              The impact estimate if budget is changed to amount specified
              in this option.
      """,
      # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.Recommendation.CampaignBudgetRecommendation.CampaignBudgetRecommendationOption)
      ))
    ,
    DESCRIPTOR = _RECOMMENDATION_CAMPAIGNBUDGETRECOMMENDATION,
    __module__ = 'google.ads.googleads_v1.proto.resources.recommendation_pb2'
    ,
    __doc__ = """The budget recommendation for budget constrained campaigns.
    
    
    Attributes:
        current_budget_amount_micros:
            The current budget amount in micros.
        recommended_budget_amount_micros:
            The recommended budget amount in micros.
        budget_options:
            The budget amounts and associated impact estimates for some
            values of possible budget amounts.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.Recommendation.CampaignBudgetRecommendation)
    ))
  ,

  KeywordRecommendation = _reflection.GeneratedProtocolMessageType('KeywordRecommendation', (_message.Message,), dict(
    DESCRIPTOR = _RECOMMENDATION_KEYWORDRECOMMENDATION,
    __module__ = 'google.ads.googleads_v1.proto.resources.recommendation_pb2'
    ,
    __doc__ = """The keyword recommendation.
    
    
    Attributes:
        keyword:
            The recommended keyword.
        recommended_cpc_bid_micros:
            The recommended CPC (cost-per-click) bid.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.Recommendation.KeywordRecommendation)
    ))
  ,

  KeywordMatchTypeRecommendation = _reflection.GeneratedProtocolMessageType('KeywordMatchTypeRecommendation', (_message.Message,), dict(
    DESCRIPTOR = _RECOMMENDATION_KEYWORDMATCHTYPERECOMMENDATION,
    __module__ = 'google.ads.googleads_v1.proto.resources.recommendation_pb2'
    ,
    __doc__ = """The keyword match type recommendation.
    
    
    Attributes:
        keyword:
            The existing keyword where the match type should be more
            broad.
        recommended_match_type:
            The recommended new match type.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.Recommendation.KeywordMatchTypeRecommendation)
    ))
  ,

  TextAdRecommendation = _reflection.GeneratedProtocolMessageType('TextAdRecommendation', (_message.Message,), dict(
    DESCRIPTOR = _RECOMMENDATION_TEXTADRECOMMENDATION,
    __module__ = 'google.ads.googleads_v1.proto.resources.recommendation_pb2'
    ,
    __doc__ = """The text ad recommendation.
    
    
    Attributes:
        ad:
            Recommended ad.
        creation_date:
            Creation date of the recommended ad. YYYY-MM-DD format, e.g.,
            2018-04-17.
        auto_apply_date:
            Date, if present, is the earliest when the recommendation will
            be auto applied. YYYY-MM-DD format, e.g., 2018-04-17.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.Recommendation.TextAdRecommendation)
    ))
  ,

  SearchPartnersOptInRecommendation = _reflection.GeneratedProtocolMessageType('SearchPartnersOptInRecommendation', (_message.Message,), dict(
    DESCRIPTOR = _RECOMMENDATION_SEARCHPARTNERSOPTINRECOMMENDATION,
    __module__ = 'google.ads.googleads_v1.proto.resources.recommendation_pb2'
    ,
    __doc__ = """The Search Partners Opt-In recommendation.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.Recommendation.SearchPartnersOptInRecommendation)
    ))
  ,

  MaximizeClicksOptInRecommendation = _reflection.GeneratedProtocolMessageType('MaximizeClicksOptInRecommendation', (_message.Message,), dict(
    DESCRIPTOR = _RECOMMENDATION_MAXIMIZECLICKSOPTINRECOMMENDATION,
    __module__ = 'google.ads.googleads_v1.proto.resources.recommendation_pb2'
    ,
    __doc__ = """The Maximize Clicks opt-in recommendation.
    
    
    Attributes:
        recommended_budget_amount_micros:
            The recommended new budget amount. Only set if the current
            budget is too high.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.Recommendation.MaximizeClicksOptInRecommendation)
    ))
  ,

  CalloutExtensionRecommendation = _reflection.GeneratedProtocolMessageType('CalloutExtensionRecommendation', (_message.Message,), dict(
    DESCRIPTOR = _RECOMMENDATION_CALLOUTEXTENSIONRECOMMENDATION,
    __module__ = 'google.ads.googleads_v1.proto.resources.recommendation_pb2'
    ,
    __doc__ = """The Callout extension recommendation.
    
    
    Attributes:
        recommended_extensions:
            Callout extensions recommended to be added.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.Recommendation.CalloutExtensionRecommendation)
    ))
  ,

  TargetCpaOptInRecommendation = _reflection.GeneratedProtocolMessageType('TargetCpaOptInRecommendation', (_message.Message,), dict(

    TargetCpaOptInRecommendationOption = _reflection.GeneratedProtocolMessageType('TargetCpaOptInRecommendationOption', (_message.Message,), dict(
      DESCRIPTOR = _RECOMMENDATION_TARGETCPAOPTINRECOMMENDATION_TARGETCPAOPTINRECOMMENDATIONOPTION,
      __module__ = 'google.ads.googleads_v1.proto.resources.recommendation_pb2'
      ,
      __doc__ = """The Target CPA opt-in option with impact estimate.
      
      
      Attributes:
          goal:
              The goal achieved by this option.
          target_cpa_micros:
              Average CPA target.
          required_campaign_budget_amount_micros:
              The minimum campaign budget, in local currency for the
              account, required to achieve the target CPA. Amount is
              specified in micros, where one million is equivalent to one
              currency unit.
          impact:
              The impact estimate if this option is selected.
      """,
      # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.Recommendation.TargetCpaOptInRecommendation.TargetCpaOptInRecommendationOption)
      ))
    ,
    DESCRIPTOR = _RECOMMENDATION_TARGETCPAOPTINRECOMMENDATION,
    __module__ = 'google.ads.googleads_v1.proto.resources.recommendation_pb2'
    ,
    __doc__ = """The Target CPA opt-in recommendation.
    
    
    Attributes:
        options:
            The available goals and corresponding options for Target CPA
            strategy.
        recommended_target_cpa_micros:
            The recommended average CPA target. See required budget amount
            and impact of using this recommendation in options list.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.Recommendation.TargetCpaOptInRecommendation)
    ))
  ,

  MaximizeConversionsOptInRecommendation = _reflection.GeneratedProtocolMessageType('MaximizeConversionsOptInRecommendation', (_message.Message,), dict(
    DESCRIPTOR = _RECOMMENDATION_MAXIMIZECONVERSIONSOPTINRECOMMENDATION,
    __module__ = 'google.ads.googleads_v1.proto.resources.recommendation_pb2'
    ,
    __doc__ = """The Maximize Conversions Opt-In recommendation.
    
    
    Attributes:
        recommended_budget_amount_micros:
            The recommended new budget amount.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.Recommendation.MaximizeConversionsOptInRecommendation)
    ))
  ,

  EnhancedCpcOptInRecommendation = _reflection.GeneratedProtocolMessageType('EnhancedCpcOptInRecommendation', (_message.Message,), dict(
    DESCRIPTOR = _RECOMMENDATION_ENHANCEDCPCOPTINRECOMMENDATION,
    __module__ = 'google.ads.googleads_v1.proto.resources.recommendation_pb2'
    ,
    __doc__ = """The Enhanced Cost-Per-Click Opt-In recommendation.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.Recommendation.EnhancedCpcOptInRecommendation)
    ))
  ,

  OptimizeAdRotationRecommendation = _reflection.GeneratedProtocolMessageType('OptimizeAdRotationRecommendation', (_message.Message,), dict(
    DESCRIPTOR = _RECOMMENDATION_OPTIMIZEADROTATIONRECOMMENDATION,
    __module__ = 'google.ads.googleads_v1.proto.resources.recommendation_pb2'
    ,
    __doc__ = """The Optimize Ad Rotation recommendation.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.Recommendation.OptimizeAdRotationRecommendation)
    ))
  ,

  SitelinkExtensionRecommendation = _reflection.GeneratedProtocolMessageType('SitelinkExtensionRecommendation', (_message.Message,), dict(
    DESCRIPTOR = _RECOMMENDATION_SITELINKEXTENSIONRECOMMENDATION,
    __module__ = 'google.ads.googleads_v1.proto.resources.recommendation_pb2'
    ,
    __doc__ = """The Sitelink extension recommendation.
    
    
    Attributes:
        recommended_extensions:
            Sitelink extensions recommended to be added.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.Recommendation.SitelinkExtensionRecommendation)
    ))
  ,

  CallExtensionRecommendation = _reflection.GeneratedProtocolMessageType('CallExtensionRecommendation', (_message.Message,), dict(
    DESCRIPTOR = _RECOMMENDATION_CALLEXTENSIONRECOMMENDATION,
    __module__ = 'google.ads.googleads_v1.proto.resources.recommendation_pb2'
    ,
    __doc__ = """The Call extension recommendation.
    
    
    Attributes:
        recommended_extensions:
            Call extensions recommended to be added.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.Recommendation.CallExtensionRecommendation)
    ))
  ,

  MoveUnusedBudgetRecommendation = _reflection.GeneratedProtocolMessageType('MoveUnusedBudgetRecommendation', (_message.Message,), dict(
    DESCRIPTOR = _RECOMMENDATION_MOVEUNUSEDBUDGETRECOMMENDATION,
    __module__ = 'google.ads.googleads_v1.proto.resources.recommendation_pb2'
    ,
    __doc__ = """The move unused budget recommendation.
    
    
    Attributes:
        excess_campaign_budget:
            The excess budget's resource\_name.
        budget_recommendation:
            The recommendation for the constrained budget to increase.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.Recommendation.MoveUnusedBudgetRecommendation)
    ))
  ,
  DESCRIPTOR = _RECOMMENDATION,
  __module__ = 'google.ads.googleads_v1.proto.resources.recommendation_pb2'
  ,
  __doc__ = """A recommendation.
  
  
  Attributes:
      resource_name:
          The resource name of the recommendation.  ``customers/{custome
          r_id}/recommendations/{recommendation_id}``
      type:
          The type of recommendation.
      impact:
          The impact on account performance as a result of applying the
          recommendation.
      campaign_budget:
          The budget targeted by this recommendation. This will be set
          only when the recommendation affects a single campaign budget.
          This field will be set for the following recommendation types:
          CAMPAIGN\_BUDGET
      campaign:
          The campaign targeted by this recommendation. This will be set
          only when the recommendation affects a single campaign.  This
          field will be set for the following recommendation types:
          ENHANCED\_CPC\_OPT\_IN, KEYWORD, MAXIMIZE\_CLICKS\_OPT\_IN,
          MAXIMIZE\_CONVERSIONS\_OPT\_IN, OPTIMIZE\_AD\_ROTATION,
          SEARCH\_PARTNERS\_OPT\_IN, TARGET\_CPA\_OPT\_IN, TEXT\_AD
      ad_group:
          The ad group targeted by this recommendation. This will be set
          only when the recommendation affects a single ad group.  This
          field will be set for the following recommendation types:
          KEYWORD, OPTIMIZE\_AD\_ROTATION, TEXT\_AD
      dismissed:
          Whether the recommendation is dismissed or not.
      recommendation:
          The details of recommendation.
      campaign_budget_recommendation:
          The campaign budget recommendation.
      keyword_recommendation:
          The keyword recommendation.
      text_ad_recommendation:
          Add expanded text ad recommendation.
      target_cpa_opt_in_recommendation:
          The TargetCPA opt-in recommendation.
      maximize_conversions_opt_in_recommendation:
          The MaximizeConversions Opt-In recommendation.
      enhanced_cpc_opt_in_recommendation:
          The Enhanced Cost-Per-Click Opt-In recommendation.
      search_partners_opt_in_recommendation:
          The Search Partners Opt-In recommendation.
      maximize_clicks_opt_in_recommendation:
          The MaximizeClicks Opt-In recommendation.
      optimize_ad_rotation_recommendation:
          The Optimize Ad Rotation recommendation.
      callout_extension_recommendation:
          The Callout extension recommendation.
      sitelink_extension_recommendation:
          The Sitelink extension recommendation.
      call_extension_recommendation:
          The Call extension recommendation.
      keyword_match_type_recommendation:
          The keyword match type recommendation.
      move_unused_budget_recommendation:
          The move unused budget recommendation.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.Recommendation)
  ))
_sym_db.RegisterMessage(Recommendation)
_sym_db.RegisterMessage(Recommendation.RecommendationImpact)
_sym_db.RegisterMessage(Recommendation.RecommendationMetrics)
_sym_db.RegisterMessage(Recommendation.CampaignBudgetRecommendation)
_sym_db.RegisterMessage(Recommendation.CampaignBudgetRecommendation.CampaignBudgetRecommendationOption)
_sym_db.RegisterMessage(Recommendation.KeywordRecommendation)
_sym_db.RegisterMessage(Recommendation.KeywordMatchTypeRecommendation)
_sym_db.RegisterMessage(Recommendation.TextAdRecommendation)
_sym_db.RegisterMessage(Recommendation.SearchPartnersOptInRecommendation)
_sym_db.RegisterMessage(Recommendation.MaximizeClicksOptInRecommendation)
_sym_db.RegisterMessage(Recommendation.CalloutExtensionRecommendation)
_sym_db.RegisterMessage(Recommendation.TargetCpaOptInRecommendation)
_sym_db.RegisterMessage(Recommendation.TargetCpaOptInRecommendation.TargetCpaOptInRecommendationOption)
_sym_db.RegisterMessage(Recommendation.MaximizeConversionsOptInRecommendation)
_sym_db.RegisterMessage(Recommendation.EnhancedCpcOptInRecommendation)
_sym_db.RegisterMessage(Recommendation.OptimizeAdRotationRecommendation)
_sym_db.RegisterMessage(Recommendation.SitelinkExtensionRecommendation)
_sym_db.RegisterMessage(Recommendation.CallExtensionRecommendation)
_sym_db.RegisterMessage(Recommendation.MoveUnusedBudgetRecommendation)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
