# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import custom_interest_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_custom__interest__pb2
from google.ads.google_ads.v2.proto.services import custom_interest_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_custom__interest__service__pb2


class CustomInterestServiceStub(object):
  """Proto file describing the Custom Interest service.

  Service to manage custom interests.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetCustomInterest = channel.unary_unary(
        '/google.ads.googleads.v2.services.CustomInterestService/GetCustomInterest',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_custom__interest__service__pb2.GetCustomInterestRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_custom__interest__pb2.CustomInterest.FromString,
        )
    self.MutateCustomInterests = channel.unary_unary(
        '/google.ads.googleads.v2.services.CustomInterestService/MutateCustomInterests',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_custom__interest__service__pb2.MutateCustomInterestsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_custom__interest__service__pb2.MutateCustomInterestsResponse.FromString,
        )


class CustomInterestServiceServicer(object):
  """Proto file describing the Custom Interest service.

  Service to manage custom interests.
  """

  def GetCustomInterest(self, request, context):
    """Returns the requested custom interest in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateCustomInterests(self, request, context):
    """Creates or updates custom interests. Operation statuses are returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CustomInterestServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetCustomInterest': grpc.unary_unary_rpc_method_handler(
          servicer.GetCustomInterest,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_custom__interest__service__pb2.GetCustomInterestRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_custom__interest__pb2.CustomInterest.SerializeToString,
      ),
      'MutateCustomInterests': grpc.unary_unary_rpc_method_handler(
          servicer.MutateCustomInterests,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_custom__interest__service__pb2.MutateCustomInterestsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_custom__interest__service__pb2.MutateCustomInterestsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.CustomInterestService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
