# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/enums/reach_plan_age_range.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/enums/reach_plan_age_range.proto',
  package='google.ads.googleads.v2.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v2.enumsB\026ReachPlanAgeRangeProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v2/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V2.Enums\312\002\035Google\\Ads\\GoogleAds\\V2\\Enums\352\002!Google::Ads::GoogleAds::V2::Enums'),
  serialized_pb=_b('\n>google/ads/googleads_v2/proto/enums/reach_plan_age_range.proto\x12\x1dgoogle.ads.googleads.v2.enums\x1a\x1cgoogle/api/annotations.proto\"\x8b\x05\n\x15ReachPlanAgeRangeEnum\"\xf1\x04\n\x11ReachPlanAgeRange\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x15\n\x0f\x41GE_RANGE_18_24\x10\xd9\xd9\x1e\x12\x13\n\x0f\x41GE_RANGE_18_34\x10\x02\x12\x13\n\x0f\x41GE_RANGE_18_44\x10\x03\x12\x13\n\x0f\x41GE_RANGE_18_49\x10\x04\x12\x13\n\x0f\x41GE_RANGE_18_54\x10\x05\x12\x13\n\x0f\x41GE_RANGE_18_64\x10\x06\x12\x16\n\x12\x41GE_RANGE_18_65_UP\x10\x07\x12\x13\n\x0f\x41GE_RANGE_21_34\x10\x08\x12\x15\n\x0f\x41GE_RANGE_25_34\x10\xda\xd9\x1e\x12\x13\n\x0f\x41GE_RANGE_25_44\x10\t\x12\x13\n\x0f\x41GE_RANGE_25_49\x10\n\x12\x13\n\x0f\x41GE_RANGE_25_54\x10\x0b\x12\x13\n\x0f\x41GE_RANGE_25_64\x10\x0c\x12\x16\n\x12\x41GE_RANGE_25_65_UP\x10\r\x12\x15\n\x0f\x41GE_RANGE_35_44\x10\xdb\xd9\x1e\x12\x13\n\x0f\x41GE_RANGE_35_49\x10\x0e\x12\x13\n\x0f\x41GE_RANGE_35_54\x10\x0f\x12\x13\n\x0f\x41GE_RANGE_35_64\x10\x10\x12\x16\n\x12\x41GE_RANGE_35_65_UP\x10\x11\x12\x15\n\x0f\x41GE_RANGE_45_54\x10\xdc\xd9\x1e\x12\x13\n\x0f\x41GE_RANGE_45_64\x10\x12\x12\x16\n\x12\x41GE_RANGE_45_65_UP\x10\x13\x12\x16\n\x12\x41GE_RANGE_50_65_UP\x10\x14\x12\x15\n\x0f\x41GE_RANGE_55_64\x10\xdd\xd9\x1e\x12\x16\n\x12\x41GE_RANGE_55_65_UP\x10\x15\x12\x15\n\x0f\x41GE_RANGE_65_UP\x10\xde\xd9\x1e\x42\xeb\x01\n!com.google.ads.googleads.v2.enumsB\x16ReachPlanAgeRangeProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v2/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V2.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V2\\Enums\xea\x02!Google::Ads::GoogleAds::V2::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_REACHPLANAGERANGEENUM_REACHPLANAGERANGE = _descriptor.EnumDescriptor(
  name='ReachPlanAgeRange',
  full_name='google.ads.googleads.v2.enums.ReachPlanAgeRangeEnum.ReachPlanAgeRange',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_18_24', index=2, number=503001,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_18_34', index=3, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_18_44', index=4, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_18_49', index=5, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_18_54', index=6, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_18_64', index=7, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_18_65_UP', index=8, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_21_34', index=9, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_25_34', index=10, number=503002,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_25_44', index=11, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_25_49', index=12, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_25_54', index=13, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_25_64', index=14, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_25_65_UP', index=15, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_35_44', index=16, number=503003,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_35_49', index=17, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_35_54', index=18, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_35_64', index=19, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_35_65_UP', index=20, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_45_54', index=21, number=503004,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_45_64', index=22, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_45_65_UP', index=23, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_50_65_UP', index=24, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_55_64', index=25, number=503005,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_55_65_UP', index=26, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_65_UP', index=27, number=503006,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=154,
  serialized_end=779,
)
_sym_db.RegisterEnumDescriptor(_REACHPLANAGERANGEENUM_REACHPLANAGERANGE)


_REACHPLANAGERANGEENUM = _descriptor.Descriptor(
  name='ReachPlanAgeRangeEnum',
  full_name='google.ads.googleads.v2.enums.ReachPlanAgeRangeEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _REACHPLANAGERANGEENUM_REACHPLANAGERANGE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=128,
  serialized_end=779,
)

_REACHPLANAGERANGEENUM_REACHPLANAGERANGE.containing_type = _REACHPLANAGERANGEENUM
DESCRIPTOR.message_types_by_name['ReachPlanAgeRangeEnum'] = _REACHPLANAGERANGEENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ReachPlanAgeRangeEnum = _reflection.GeneratedProtocolMessageType('ReachPlanAgeRangeEnum', (_message.Message,), dict(
  DESCRIPTOR = _REACHPLANAGERANGEENUM,
  __module__ = 'google.ads.googleads_v2.proto.enums.reach_plan_age_range_pb2'
  ,
  __doc__ = """Message describing plannable age ranges.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.enums.ReachPlanAgeRangeEnum)
  ))
_sym_db.RegisterMessage(ReachPlanAgeRangeEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
