# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import ad_group_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__pb2
from google.ads.google_ads.v2.proto.services import ad_group_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__service__pb2


class AdGroupServiceStub(object):
  """Proto file describing the Ad Group service.

  Service to manage ad groups.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetAdGroup = channel.unary_unary(
        '/google.ads.googleads.v2.services.AdGroupService/GetAdGroup',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__service__pb2.GetAdGroupRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__pb2.AdGroup.FromString,
        )
    self.MutateAdGroups = channel.unary_unary(
        '/google.ads.googleads.v2.services.AdGroupService/MutateAdGroups',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__service__pb2.MutateAdGroupsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__service__pb2.MutateAdGroupsResponse.FromString,
        )


class AdGroupServiceServicer(object):
  """Proto file describing the Ad Group service.

  Service to manage ad groups.
  """

  def GetAdGroup(self, request, context):
    """Returns the requested ad group in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateAdGroups(self, request, context):
    """Creates, updates, or removes ad groups. Operation statuses are returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_AdGroupServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetAdGroup': grpc.unary_unary_rpc_method_handler(
          servicer.GetAdGroup,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__service__pb2.GetAdGroupRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__pb2.AdGroup.SerializeToString,
      ),
      'MutateAdGroups': grpc.unary_unary_rpc_method_handler(
          servicer.MutateAdGroups,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__service__pb2.MutateAdGroupsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__service__pb2.MutateAdGroupsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.AdGroupService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
