# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/enums/promotion_extension_occasion.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/enums/promotion_extension_occasion.proto',
  package='google.ads.googleads.v1.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v1.enumsB\037PromotionExtensionOccasionProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V1.Enums\312\002\035Google\\Ads\\GoogleAds\\V1\\Enums\352\002!Google::Ads::GoogleAds::V1::Enums'),
  serialized_pb=_b('\nFgoogle/ads/googleads_v1/proto/enums/promotion_extension_occasion.proto\x12\x1dgoogle.ads.googleads.v1.enums\x1a\x1cgoogle/api/annotations.proto\"\xbc\x05\n\x1ePromotionExtensionOccasionEnum\"\x99\x05\n\x1aPromotionExtensionOccasion\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\r\n\tNEW_YEARS\x10\x02\x12\x14\n\x10\x43HINESE_NEW_YEAR\x10\x03\x12\x12\n\x0eVALENTINES_DAY\x10\x04\x12\n\n\x06\x45\x41STER\x10\x05\x12\x0f\n\x0bMOTHERS_DAY\x10\x06\x12\x0f\n\x0b\x46\x41THERS_DAY\x10\x07\x12\r\n\tLABOR_DAY\x10\x08\x12\x12\n\x0e\x42\x41\x43K_TO_SCHOOL\x10\t\x12\r\n\tHALLOWEEN\x10\n\x12\x10\n\x0c\x42LACK_FRIDAY\x10\x0b\x12\x10\n\x0c\x43YBER_MONDAY\x10\x0c\x12\r\n\tCHRISTMAS\x10\r\x12\x0e\n\nBOXING_DAY\x10\x0e\x12\x14\n\x10INDEPENDENCE_DAY\x10\x0f\x12\x10\n\x0cNATIONAL_DAY\x10\x10\x12\x11\n\rEND_OF_SEASON\x10\x11\x12\x0f\n\x0bWINTER_SALE\x10\x12\x12\x0f\n\x0bSUMMER_SALE\x10\x13\x12\r\n\tFALL_SALE\x10\x14\x12\x0f\n\x0bSPRING_SALE\x10\x15\x12\x0b\n\x07RAMADAN\x10\x16\x12\x0f\n\x0b\x45ID_AL_FITR\x10\x17\x12\x0f\n\x0b\x45ID_AL_ADHA\x10\x18\x12\x0f\n\x0bSINGLES_DAY\x10\x19\x12\x0e\n\nWOMENS_DAY\x10\x1a\x12\x08\n\x04HOLI\x10\x1b\x12\x0f\n\x0bPARENTS_DAY\x10\x1c\x12\x13\n\x0fST_NICHOLAS_DAY\x10\x1d\x12\x0c\n\x08\x43\x41RNIVAL\x10\x1e\x12\x0c\n\x08\x45PIPHANY\x10\x1f\x12\x11\n\rROSH_HASHANAH\x10 \x12\x0c\n\x08PASSOVER\x10!\x12\x0c\n\x08HANUKKAH\x10\"\x12\n\n\x06\x44IWALI\x10#\x12\x0c\n\x08NAVRATRI\x10$\x12\x0c\n\x08SONGKRAN\x10%\x12\x11\n\rYEAR_END_GIFT\x10&B\xf4\x01\n!com.google.ads.googleads.v1.enumsB\x1fPromotionExtensionOccasionProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V1.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V1\\Enums\xea\x02!Google::Ads::GoogleAds::V1::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_PROMOTIONEXTENSIONOCCASIONENUM_PROMOTIONEXTENSIONOCCASION = _descriptor.EnumDescriptor(
  name='PromotionExtensionOccasion',
  full_name='google.ads.googleads.v1.enums.PromotionExtensionOccasionEnum.PromotionExtensionOccasion',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NEW_YEARS', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHINESE_NEW_YEAR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VALENTINES_DAY', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EASTER', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOTHERS_DAY', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FATHERS_DAY', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LABOR_DAY', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BACK_TO_SCHOOL', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HALLOWEEN', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BLACK_FRIDAY', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CYBER_MONDAY', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHRISTMAS', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOXING_DAY', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INDEPENDENCE_DAY', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NATIONAL_DAY', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='END_OF_SEASON', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WINTER_SALE', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUMMER_SALE', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FALL_SALE', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SPRING_SALE', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RAMADAN', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EID_AL_FITR', index=23, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EID_AL_ADHA', index=24, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SINGLES_DAY', index=25, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WOMENS_DAY', index=26, number=26,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HOLI', index=27, number=27,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARENTS_DAY', index=28, number=28,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_NICHOLAS_DAY', index=29, number=29,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CARNIVAL', index=30, number=30,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EPIPHANY', index=31, number=31,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ROSH_HASHANAH', index=32, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PASSOVER', index=33, number=33,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HANUKKAH', index=34, number=34,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DIWALI', index=35, number=35,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NAVRATRI', index=36, number=36,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SONGKRAN', index=37, number=37,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='YEAR_END_GIFT', index=38, number=38,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=171,
  serialized_end=836,
)
_sym_db.RegisterEnumDescriptor(_PROMOTIONEXTENSIONOCCASIONENUM_PROMOTIONEXTENSIONOCCASION)


_PROMOTIONEXTENSIONOCCASIONENUM = _descriptor.Descriptor(
  name='PromotionExtensionOccasionEnum',
  full_name='google.ads.googleads.v1.enums.PromotionExtensionOccasionEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PROMOTIONEXTENSIONOCCASIONENUM_PROMOTIONEXTENSIONOCCASION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=136,
  serialized_end=836,
)

_PROMOTIONEXTENSIONOCCASIONENUM_PROMOTIONEXTENSIONOCCASION.containing_type = _PROMOTIONEXTENSIONOCCASIONENUM
DESCRIPTOR.message_types_by_name['PromotionExtensionOccasionEnum'] = _PROMOTIONEXTENSIONOCCASIONENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PromotionExtensionOccasionEnum = _reflection.GeneratedProtocolMessageType('PromotionExtensionOccasionEnum', (_message.Message,), dict(
  DESCRIPTOR = _PROMOTIONEXTENSIONOCCASIONENUM,
  __module__ = 'google.ads.googleads_v1.proto.enums.promotion_extension_occasion_pb2'
  ,
  __doc__ = """Container for enum describing a promotion extension occasion. For more
  information about the occasions please check:
  https://support.google.com/google-ads/answer/7367521
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.enums.PromotionExtensionOccasionEnum)
  ))
_sym_db.RegisterMessage(PromotionExtensionOccasionEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
