# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/services/recommendation_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.common import extensions_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_extensions__pb2
from google.ads.google_ads.v1.proto.enums import keyword_match_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_keyword__match__type__pb2
from google.ads.google_ads.v1.proto.resources import ad_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_ad__pb2
from google.ads.google_ads.v1.proto.resources import recommendation_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_recommendation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/services/recommendation_service.proto',
  package='google.ads.googleads.v1.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v1.servicesB\032RecommendationServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V1.Services\312\002 Google\\Ads\\GoogleAds\\V1\\Services\352\002$Google::Ads::GoogleAds::V1::Services'),
  serialized_pb=_b('\nCgoogle/ads/googleads_v1/proto/services/recommendation_service.proto\x12 google.ads.googleads.v1.services\x1a\x35google/ads/googleads_v1/proto/common/extensions.proto\x1a<google/ads/googleads_v1/proto/enums/keyword_match_type.proto\x1a\x30google/ads/googleads_v1/proto/resources/ad.proto\x1a<google/ads/googleads_v1/proto/resources/recommendation.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x17google/rpc/status.proto\"1\n\x18GetRecommendationRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\x9e\x01\n\x1a\x41pplyRecommendationRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12R\n\noperations\x18\x02 \x03(\x0b\x32>.google.ads.googleads.v1.services.ApplyRecommendationOperation\x12\x17\n\x0fpartial_failure\x18\x03 \x01(\x08\"\x82\x0f\n\x1c\x41pplyRecommendationOperation\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12r\n\x0f\x63\x61mpaign_budget\x18\x02 \x01(\x0b\x32W.google.ads.googleads.v1.services.ApplyRecommendationOperation.CampaignBudgetParametersH\x00\x12\x62\n\x07text_ad\x18\x03 \x01(\x0b\x32O.google.ads.googleads.v1.services.ApplyRecommendationOperation.TextAdParametersH\x00\x12\x63\n\x07keyword\x18\x04 \x01(\x0b\x32P.google.ads.googleads.v1.services.ApplyRecommendationOperation.KeywordParametersH\x00\x12t\n\x11target_cpa_opt_in\x18\x05 \x01(\x0b\x32W.google.ads.googleads.v1.services.ApplyRecommendationOperation.TargetCpaOptInParametersH\x00\x12v\n\x11\x63\x61llout_extension\x18\x06 \x01(\x0b\x32Y.google.ads.googleads.v1.services.ApplyRecommendationOperation.CalloutExtensionParametersH\x00\x12p\n\x0e\x63\x61ll_extension\x18\x07 \x01(\x0b\x32V.google.ads.googleads.v1.services.ApplyRecommendationOperation.CallExtensionParametersH\x00\x12x\n\x12sitelink_extension\x18\x08 \x01(\x0b\x32Z.google.ads.googleads.v1.services.ApplyRecommendationOperation.SitelinkExtensionParametersH\x00\x12w\n\x12move_unused_budget\x18\t \x01(\x0b\x32Y.google.ads.googleads.v1.services.ApplyRecommendationOperation.MoveUnusedBudgetParametersH\x00\x1aY\n\x18\x43\x61mpaignBudgetParameters\x12=\n\x18new_budget_amount_micros\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1a\x45\n\x10TextAdParameters\x12\x31\n\x02\x61\x64\x18\x01 \x01(\x0b\x32%.google.ads.googleads.v1.resources.Ad\x1a\xd2\x01\n\x11KeywordParameters\x12.\n\x08\x61\x64_group\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12X\n\nmatch_type\x18\x02 \x01(\x0e\x32\x44.google.ads.googleads.v1.enums.KeywordMatchTypeEnum.KeywordMatchType\x12\x33\n\x0e\x63pc_bid_micros\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1a\x9a\x01\n\x18TargetCpaOptInParameters\x12\x36\n\x11target_cpa_micros\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x46\n!new_campaign_budget_amount_micros\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1ai\n\x1a\x43\x61lloutExtensionParameters\x12K\n\x12\x63\x61llout_extensions\x18\x01 \x03(\x0b\x32/.google.ads.googleads.v1.common.CalloutFeedItem\x1a`\n\x17\x43\x61llExtensionParameters\x12\x45\n\x0f\x63\x61ll_extensions\x18\x01 \x03(\x0b\x32,.google.ads.googleads.v1.common.CallFeedItem\x1al\n\x1bSitelinkExtensionParameters\x12M\n\x13sitelink_extensions\x18\x01 \x03(\x0b\x32\x30.google.ads.googleads.v1.common.SitelinkFeedItem\x1aX\n\x1aMoveUnusedBudgetParameters\x12:\n\x15\x62udget_micros_to_move\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x12\n\x10\x61pply_parameters\"\x9e\x01\n\x1b\x41pplyRecommendationResponse\x12L\n\x07results\x18\x01 \x03(\x0b\x32;.google.ads.googleads.v1.services.ApplyRecommendationResult\x12\x31\n\x15partial_failure_error\x18\x02 \x01(\x0b\x32\x12.google.rpc.Status\"2\n\x19\x41pplyRecommendationResult\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\xf8\x01\n\x1c\x44ismissRecommendationRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12q\n\noperations\x18\x03 \x03(\x0b\x32].google.ads.googleads.v1.services.DismissRecommendationRequest.DismissRecommendationOperation\x12\x17\n\x0fpartial_failure\x18\x02 \x01(\x08\x1a\x37\n\x1e\x44ismissRecommendationOperation\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\xf6\x01\n\x1d\x44ismissRecommendationResponse\x12l\n\x07results\x18\x01 \x03(\x0b\x32[.google.ads.googleads.v1.services.DismissRecommendationResponse.DismissRecommendationResult\x12\x31\n\x15partial_failure_error\x18\x02 \x01(\x0b\x32\x12.google.rpc.Status\x1a\x34\n\x1b\x44ismissRecommendationResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\x89\x05\n\x15RecommendationService\x12\xbd\x01\n\x11GetRecommendation\x12:.google.ads.googleads.v1.services.GetRecommendationRequest\x1a\x31.google.ads.googleads.v1.resources.Recommendation\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/v1/{resource_name=customers/*/recommendations/*}\x12\xd2\x01\n\x13\x41pplyRecommendation\x12<.google.ads.googleads.v1.services.ApplyRecommendationRequest\x1a=.google.ads.googleads.v1.services.ApplyRecommendationResponse\">\x82\xd3\xe4\x93\x02\x38\"3/v1/customers/{customer_id=*}/recommendations:apply:\x01*\x12\xda\x01\n\x15\x44ismissRecommendation\x12>.google.ads.googleads.v1.services.DismissRecommendationRequest\x1a?.google.ads.googleads.v1.services.DismissRecommendationResponse\"@\x82\xd3\xe4\x93\x02:\"5/v1/customers/{customer_id=*}/recommendations:dismiss:\x01*B\x81\x02\n$com.google.ads.googleads.v1.servicesB\x1aRecommendationServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V1.Services\xca\x02 Google\\Ads\\GoogleAds\\V1\\Services\xea\x02$Google::Ads::GoogleAds::V1::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_extensions__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_keyword__match__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_ad__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_recommendation__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,])




_GETRECOMMENDATIONREQUEST = _descriptor.Descriptor(
  name='GetRecommendationRequest',
  full_name='google.ads.googleads.v1.services.GetRecommendationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.GetRecommendationRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=421,
  serialized_end=470,
)


_APPLYRECOMMENDATIONREQUEST = _descriptor.Descriptor(
  name='ApplyRecommendationRequest',
  full_name='google.ads.googleads.v1.services.ApplyRecommendationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v1.services.ApplyRecommendationRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v1.services.ApplyRecommendationRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partial_failure', full_name='google.ads.googleads.v1.services.ApplyRecommendationRequest.partial_failure', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=473,
  serialized_end=631,
)


_APPLYRECOMMENDATIONOPERATION_CAMPAIGNBUDGETPARAMETERS = _descriptor.Descriptor(
  name='CampaignBudgetParameters',
  full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.CampaignBudgetParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='new_budget_amount_micros', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.CampaignBudgetParameters.new_budget_amount_micros', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1601,
  serialized_end=1690,
)

_APPLYRECOMMENDATIONOPERATION_TEXTADPARAMETERS = _descriptor.Descriptor(
  name='TextAdParameters',
  full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.TextAdParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ad', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.TextAdParameters.ad', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1692,
  serialized_end=1761,
)

_APPLYRECOMMENDATIONOPERATION_KEYWORDPARAMETERS = _descriptor.Descriptor(
  name='KeywordParameters',
  full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.KeywordParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ad_group', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.KeywordParameters.ad_group', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_type', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.KeywordParameters.match_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpc_bid_micros', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.KeywordParameters.cpc_bid_micros', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1764,
  serialized_end=1974,
)

_APPLYRECOMMENDATIONOPERATION_TARGETCPAOPTINPARAMETERS = _descriptor.Descriptor(
  name='TargetCpaOptInParameters',
  full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.TargetCpaOptInParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_cpa_micros', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.TargetCpaOptInParameters.target_cpa_micros', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_campaign_budget_amount_micros', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.TargetCpaOptInParameters.new_campaign_budget_amount_micros', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1977,
  serialized_end=2131,
)

_APPLYRECOMMENDATIONOPERATION_CALLOUTEXTENSIONPARAMETERS = _descriptor.Descriptor(
  name='CalloutExtensionParameters',
  full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.CalloutExtensionParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='callout_extensions', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.CalloutExtensionParameters.callout_extensions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2133,
  serialized_end=2238,
)

_APPLYRECOMMENDATIONOPERATION_CALLEXTENSIONPARAMETERS = _descriptor.Descriptor(
  name='CallExtensionParameters',
  full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.CallExtensionParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_extensions', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.CallExtensionParameters.call_extensions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2240,
  serialized_end=2336,
)

_APPLYRECOMMENDATIONOPERATION_SITELINKEXTENSIONPARAMETERS = _descriptor.Descriptor(
  name='SitelinkExtensionParameters',
  full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.SitelinkExtensionParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sitelink_extensions', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.SitelinkExtensionParameters.sitelink_extensions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2338,
  serialized_end=2446,
)

_APPLYRECOMMENDATIONOPERATION_MOVEUNUSEDBUDGETPARAMETERS = _descriptor.Descriptor(
  name='MoveUnusedBudgetParameters',
  full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.MoveUnusedBudgetParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='budget_micros_to_move', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.MoveUnusedBudgetParameters.budget_micros_to_move', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2448,
  serialized_end=2536,
)

_APPLYRECOMMENDATIONOPERATION = _descriptor.Descriptor(
  name='ApplyRecommendationOperation',
  full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_budget', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.campaign_budget', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_ad', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.text_ad', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.keyword', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_cpa_opt_in', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.target_cpa_opt_in', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='callout_extension', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.callout_extension', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_extension', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.call_extension', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sitelink_extension', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.sitelink_extension', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='move_unused_budget', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.move_unused_budget', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_APPLYRECOMMENDATIONOPERATION_CAMPAIGNBUDGETPARAMETERS, _APPLYRECOMMENDATIONOPERATION_TEXTADPARAMETERS, _APPLYRECOMMENDATIONOPERATION_KEYWORDPARAMETERS, _APPLYRECOMMENDATIONOPERATION_TARGETCPAOPTINPARAMETERS, _APPLYRECOMMENDATIONOPERATION_CALLOUTEXTENSIONPARAMETERS, _APPLYRECOMMENDATIONOPERATION_CALLEXTENSIONPARAMETERS, _APPLYRECOMMENDATIONOPERATION_SITELINKEXTENSIONPARAMETERS, _APPLYRECOMMENDATIONOPERATION_MOVEUNUSEDBUDGETPARAMETERS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='apply_parameters', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.apply_parameters',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=634,
  serialized_end=2556,
)


_APPLYRECOMMENDATIONRESPONSE = _descriptor.Descriptor(
  name='ApplyRecommendationResponse',
  full_name='google.ads.googleads.v1.services.ApplyRecommendationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v1.services.ApplyRecommendationResponse.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partial_failure_error', full_name='google.ads.googleads.v1.services.ApplyRecommendationResponse.partial_failure_error', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2559,
  serialized_end=2717,
)


_APPLYRECOMMENDATIONRESULT = _descriptor.Descriptor(
  name='ApplyRecommendationResult',
  full_name='google.ads.googleads.v1.services.ApplyRecommendationResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.ApplyRecommendationResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2719,
  serialized_end=2769,
)


_DISMISSRECOMMENDATIONREQUEST_DISMISSRECOMMENDATIONOPERATION = _descriptor.Descriptor(
  name='DismissRecommendationOperation',
  full_name='google.ads.googleads.v1.services.DismissRecommendationRequest.DismissRecommendationOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.DismissRecommendationRequest.DismissRecommendationOperation.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2965,
  serialized_end=3020,
)

_DISMISSRECOMMENDATIONREQUEST = _descriptor.Descriptor(
  name='DismissRecommendationRequest',
  full_name='google.ads.googleads.v1.services.DismissRecommendationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v1.services.DismissRecommendationRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v1.services.DismissRecommendationRequest.operations', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partial_failure', full_name='google.ads.googleads.v1.services.DismissRecommendationRequest.partial_failure', index=2,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DISMISSRECOMMENDATIONREQUEST_DISMISSRECOMMENDATIONOPERATION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2772,
  serialized_end=3020,
)


_DISMISSRECOMMENDATIONRESPONSE_DISMISSRECOMMENDATIONRESULT = _descriptor.Descriptor(
  name='DismissRecommendationResult',
  full_name='google.ads.googleads.v1.services.DismissRecommendationResponse.DismissRecommendationResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.DismissRecommendationResponse.DismissRecommendationResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3217,
  serialized_end=3269,
)

_DISMISSRECOMMENDATIONRESPONSE = _descriptor.Descriptor(
  name='DismissRecommendationResponse',
  full_name='google.ads.googleads.v1.services.DismissRecommendationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v1.services.DismissRecommendationResponse.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partial_failure_error', full_name='google.ads.googleads.v1.services.DismissRecommendationResponse.partial_failure_error', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DISMISSRECOMMENDATIONRESPONSE_DISMISSRECOMMENDATIONRESULT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3023,
  serialized_end=3269,
)

_APPLYRECOMMENDATIONREQUEST.fields_by_name['operations'].message_type = _APPLYRECOMMENDATIONOPERATION
_APPLYRECOMMENDATIONOPERATION_CAMPAIGNBUDGETPARAMETERS.fields_by_name['new_budget_amount_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_APPLYRECOMMENDATIONOPERATION_CAMPAIGNBUDGETPARAMETERS.containing_type = _APPLYRECOMMENDATIONOPERATION
_APPLYRECOMMENDATIONOPERATION_TEXTADPARAMETERS.fields_by_name['ad'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_ad__pb2._AD
_APPLYRECOMMENDATIONOPERATION_TEXTADPARAMETERS.containing_type = _APPLYRECOMMENDATIONOPERATION
_APPLYRECOMMENDATIONOPERATION_KEYWORDPARAMETERS.fields_by_name['ad_group'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_APPLYRECOMMENDATIONOPERATION_KEYWORDPARAMETERS.fields_by_name['match_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_keyword__match__type__pb2._KEYWORDMATCHTYPEENUM_KEYWORDMATCHTYPE
_APPLYRECOMMENDATIONOPERATION_KEYWORDPARAMETERS.fields_by_name['cpc_bid_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_APPLYRECOMMENDATIONOPERATION_KEYWORDPARAMETERS.containing_type = _APPLYRECOMMENDATIONOPERATION
_APPLYRECOMMENDATIONOPERATION_TARGETCPAOPTINPARAMETERS.fields_by_name['target_cpa_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_APPLYRECOMMENDATIONOPERATION_TARGETCPAOPTINPARAMETERS.fields_by_name['new_campaign_budget_amount_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_APPLYRECOMMENDATIONOPERATION_TARGETCPAOPTINPARAMETERS.containing_type = _APPLYRECOMMENDATIONOPERATION
_APPLYRECOMMENDATIONOPERATION_CALLOUTEXTENSIONPARAMETERS.fields_by_name['callout_extensions'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_extensions__pb2._CALLOUTFEEDITEM
_APPLYRECOMMENDATIONOPERATION_CALLOUTEXTENSIONPARAMETERS.containing_type = _APPLYRECOMMENDATIONOPERATION
_APPLYRECOMMENDATIONOPERATION_CALLEXTENSIONPARAMETERS.fields_by_name['call_extensions'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_extensions__pb2._CALLFEEDITEM
_APPLYRECOMMENDATIONOPERATION_CALLEXTENSIONPARAMETERS.containing_type = _APPLYRECOMMENDATIONOPERATION
_APPLYRECOMMENDATIONOPERATION_SITELINKEXTENSIONPARAMETERS.fields_by_name['sitelink_extensions'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_extensions__pb2._SITELINKFEEDITEM
_APPLYRECOMMENDATIONOPERATION_SITELINKEXTENSIONPARAMETERS.containing_type = _APPLYRECOMMENDATIONOPERATION
_APPLYRECOMMENDATIONOPERATION_MOVEUNUSEDBUDGETPARAMETERS.fields_by_name['budget_micros_to_move'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_APPLYRECOMMENDATIONOPERATION_MOVEUNUSEDBUDGETPARAMETERS.containing_type = _APPLYRECOMMENDATIONOPERATION
_APPLYRECOMMENDATIONOPERATION.fields_by_name['campaign_budget'].message_type = _APPLYRECOMMENDATIONOPERATION_CAMPAIGNBUDGETPARAMETERS
_APPLYRECOMMENDATIONOPERATION.fields_by_name['text_ad'].message_type = _APPLYRECOMMENDATIONOPERATION_TEXTADPARAMETERS
_APPLYRECOMMENDATIONOPERATION.fields_by_name['keyword'].message_type = _APPLYRECOMMENDATIONOPERATION_KEYWORDPARAMETERS
_APPLYRECOMMENDATIONOPERATION.fields_by_name['target_cpa_opt_in'].message_type = _APPLYRECOMMENDATIONOPERATION_TARGETCPAOPTINPARAMETERS
_APPLYRECOMMENDATIONOPERATION.fields_by_name['callout_extension'].message_type = _APPLYRECOMMENDATIONOPERATION_CALLOUTEXTENSIONPARAMETERS
_APPLYRECOMMENDATIONOPERATION.fields_by_name['call_extension'].message_type = _APPLYRECOMMENDATIONOPERATION_CALLEXTENSIONPARAMETERS
_APPLYRECOMMENDATIONOPERATION.fields_by_name['sitelink_extension'].message_type = _APPLYRECOMMENDATIONOPERATION_SITELINKEXTENSIONPARAMETERS
_APPLYRECOMMENDATIONOPERATION.fields_by_name['move_unused_budget'].message_type = _APPLYRECOMMENDATIONOPERATION_MOVEUNUSEDBUDGETPARAMETERS
_APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters'].fields.append(
  _APPLYRECOMMENDATIONOPERATION.fields_by_name['campaign_budget'])
_APPLYRECOMMENDATIONOPERATION.fields_by_name['campaign_budget'].containing_oneof = _APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters']
_APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters'].fields.append(
  _APPLYRECOMMENDATIONOPERATION.fields_by_name['text_ad'])
_APPLYRECOMMENDATIONOPERATION.fields_by_name['text_ad'].containing_oneof = _APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters']
_APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters'].fields.append(
  _APPLYRECOMMENDATIONOPERATION.fields_by_name['keyword'])
_APPLYRECOMMENDATIONOPERATION.fields_by_name['keyword'].containing_oneof = _APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters']
_APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters'].fields.append(
  _APPLYRECOMMENDATIONOPERATION.fields_by_name['target_cpa_opt_in'])
_APPLYRECOMMENDATIONOPERATION.fields_by_name['target_cpa_opt_in'].containing_oneof = _APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters']
_APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters'].fields.append(
  _APPLYRECOMMENDATIONOPERATION.fields_by_name['callout_extension'])
_APPLYRECOMMENDATIONOPERATION.fields_by_name['callout_extension'].containing_oneof = _APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters']
_APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters'].fields.append(
  _APPLYRECOMMENDATIONOPERATION.fields_by_name['call_extension'])
_APPLYRECOMMENDATIONOPERATION.fields_by_name['call_extension'].containing_oneof = _APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters']
_APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters'].fields.append(
  _APPLYRECOMMENDATIONOPERATION.fields_by_name['sitelink_extension'])
_APPLYRECOMMENDATIONOPERATION.fields_by_name['sitelink_extension'].containing_oneof = _APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters']
_APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters'].fields.append(
  _APPLYRECOMMENDATIONOPERATION.fields_by_name['move_unused_budget'])
_APPLYRECOMMENDATIONOPERATION.fields_by_name['move_unused_budget'].containing_oneof = _APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters']
_APPLYRECOMMENDATIONRESPONSE.fields_by_name['results'].message_type = _APPLYRECOMMENDATIONRESULT
_APPLYRECOMMENDATIONRESPONSE.fields_by_name['partial_failure_error'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_DISMISSRECOMMENDATIONREQUEST_DISMISSRECOMMENDATIONOPERATION.containing_type = _DISMISSRECOMMENDATIONREQUEST
_DISMISSRECOMMENDATIONREQUEST.fields_by_name['operations'].message_type = _DISMISSRECOMMENDATIONREQUEST_DISMISSRECOMMENDATIONOPERATION
_DISMISSRECOMMENDATIONRESPONSE_DISMISSRECOMMENDATIONRESULT.containing_type = _DISMISSRECOMMENDATIONRESPONSE
_DISMISSRECOMMENDATIONRESPONSE.fields_by_name['results'].message_type = _DISMISSRECOMMENDATIONRESPONSE_DISMISSRECOMMENDATIONRESULT
_DISMISSRECOMMENDATIONRESPONSE.fields_by_name['partial_failure_error'].message_type = google_dot_rpc_dot_status__pb2._STATUS
DESCRIPTOR.message_types_by_name['GetRecommendationRequest'] = _GETRECOMMENDATIONREQUEST
DESCRIPTOR.message_types_by_name['ApplyRecommendationRequest'] = _APPLYRECOMMENDATIONREQUEST
DESCRIPTOR.message_types_by_name['ApplyRecommendationOperation'] = _APPLYRECOMMENDATIONOPERATION
DESCRIPTOR.message_types_by_name['ApplyRecommendationResponse'] = _APPLYRECOMMENDATIONRESPONSE
DESCRIPTOR.message_types_by_name['ApplyRecommendationResult'] = _APPLYRECOMMENDATIONRESULT
DESCRIPTOR.message_types_by_name['DismissRecommendationRequest'] = _DISMISSRECOMMENDATIONREQUEST
DESCRIPTOR.message_types_by_name['DismissRecommendationResponse'] = _DISMISSRECOMMENDATIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetRecommendationRequest = _reflection.GeneratedProtocolMessageType('GetRecommendationRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETRECOMMENDATIONREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
  ,
  __doc__ = """Request message for
  [RecommendationService.GetRecommendation][google.ads.googleads.v1.services.RecommendationService.GetRecommendation].
  
  
  Attributes:
      resource_name:
          The resource name of the recommendation to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.GetRecommendationRequest)
  ))
_sym_db.RegisterMessage(GetRecommendationRequest)

ApplyRecommendationRequest = _reflection.GeneratedProtocolMessageType('ApplyRecommendationRequest', (_message.Message,), dict(
  DESCRIPTOR = _APPLYRECOMMENDATIONREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
  ,
  __doc__ = """Request message for
  [RecommendationService.ApplyRecommendation][google.ads.googleads.v1.services.RecommendationService.ApplyRecommendation].
  
  
  Attributes:
      customer_id:
          The ID of the customer with the recommendation.
      operations:
          The list of operations to apply recommendations. If
          partial\_failure=false all recommendations should be of the
          same type There is a limit of 100 operations per request.
      partial_failure:
          If true, successful operations will be carried out and invalid
          operations will return errors. If false, operations will be
          carried out as a transaction if and only if they are all
          valid. Default is false.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ApplyRecommendationRequest)
  ))
_sym_db.RegisterMessage(ApplyRecommendationRequest)

ApplyRecommendationOperation = _reflection.GeneratedProtocolMessageType('ApplyRecommendationOperation', (_message.Message,), dict(

  CampaignBudgetParameters = _reflection.GeneratedProtocolMessageType('CampaignBudgetParameters', (_message.Message,), dict(
    DESCRIPTOR = _APPLYRECOMMENDATIONOPERATION_CAMPAIGNBUDGETPARAMETERS,
    __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
    ,
    __doc__ = """Parameters to use when applying a campaign budget recommendation.
    
    
    Attributes:
        new_budget_amount_micros:
            New budget amount to set for target budget resource. This is a
            required field.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ApplyRecommendationOperation.CampaignBudgetParameters)
    ))
  ,

  TextAdParameters = _reflection.GeneratedProtocolMessageType('TextAdParameters', (_message.Message,), dict(
    DESCRIPTOR = _APPLYRECOMMENDATIONOPERATION_TEXTADPARAMETERS,
    __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
    ,
    __doc__ = """Parameters to use when applying a text ad recommendation.
    
    
    Attributes:
        ad:
            New ad to add to recommended ad group. All necessary fields
            need to be set in this message. This is a required field.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ApplyRecommendationOperation.TextAdParameters)
    ))
  ,

  KeywordParameters = _reflection.GeneratedProtocolMessageType('KeywordParameters', (_message.Message,), dict(
    DESCRIPTOR = _APPLYRECOMMENDATIONOPERATION_KEYWORDPARAMETERS,
    __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
    ,
    __doc__ = """Parameters to use when applying keyword recommendation.
    
    
    Attributes:
        ad_group:
            The ad group resource to add keyword to. This is a required
            field.
        match_type:
            The match type of the keyword. This is a required field.
        cpc_bid_micros:
            Optional, CPC bid to set for the keyword. If not set, keyword
            will use bid based on bidding strategy used by target ad
            group.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ApplyRecommendationOperation.KeywordParameters)
    ))
  ,

  TargetCpaOptInParameters = _reflection.GeneratedProtocolMessageType('TargetCpaOptInParameters', (_message.Message,), dict(
    DESCRIPTOR = _APPLYRECOMMENDATIONOPERATION_TARGETCPAOPTINPARAMETERS,
    __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
    ,
    __doc__ = """Parameters to use when applying Target CPA recommendation.
    
    
    Attributes:
        target_cpa_micros:
            Average CPA to use for Target CPA bidding strategy. This is a
            required field.
        new_campaign_budget_amount_micros:
            Optional, budget amount to set for the campaign.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ApplyRecommendationOperation.TargetCpaOptInParameters)
    ))
  ,

  CalloutExtensionParameters = _reflection.GeneratedProtocolMessageType('CalloutExtensionParameters', (_message.Message,), dict(
    DESCRIPTOR = _APPLYRECOMMENDATIONOPERATION_CALLOUTEXTENSIONPARAMETERS,
    __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
    ,
    __doc__ = """Parameters to use when applying callout extension recommendation.
    
    
    Attributes:
        callout_extensions:
            Callout extensions to be added. This is a required field.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ApplyRecommendationOperation.CalloutExtensionParameters)
    ))
  ,

  CallExtensionParameters = _reflection.GeneratedProtocolMessageType('CallExtensionParameters', (_message.Message,), dict(
    DESCRIPTOR = _APPLYRECOMMENDATIONOPERATION_CALLEXTENSIONPARAMETERS,
    __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
    ,
    __doc__ = """Parameters to use when applying call extension recommendation.
    
    
    Attributes:
        call_extensions:
            Call extensions to be added. This is a required field.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ApplyRecommendationOperation.CallExtensionParameters)
    ))
  ,

  SitelinkExtensionParameters = _reflection.GeneratedProtocolMessageType('SitelinkExtensionParameters', (_message.Message,), dict(
    DESCRIPTOR = _APPLYRECOMMENDATIONOPERATION_SITELINKEXTENSIONPARAMETERS,
    __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
    ,
    __doc__ = """Parameters to use when applying sitelink extension recommendation.
    
    
    Attributes:
        sitelink_extensions:
            Sitelink extensions to be added. This is a required field.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ApplyRecommendationOperation.SitelinkExtensionParameters)
    ))
  ,

  MoveUnusedBudgetParameters = _reflection.GeneratedProtocolMessageType('MoveUnusedBudgetParameters', (_message.Message,), dict(
    DESCRIPTOR = _APPLYRECOMMENDATIONOPERATION_MOVEUNUSEDBUDGETPARAMETERS,
    __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
    ,
    __doc__ = """Parameters to use when applying move unused budget recommendation.
    
    
    Attributes:
        budget_micros_to_move:
            Budget amount to move from excess budget to constrained
            budget. This is a required field.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ApplyRecommendationOperation.MoveUnusedBudgetParameters)
    ))
  ,
  DESCRIPTOR = _APPLYRECOMMENDATIONOPERATION,
  __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
  ,
  __doc__ = """Information about the operation to apply a recommendation and any
  parameters to customize it.
  
  
  Attributes:
      resource_name:
          The resource name of the recommendation to apply.
      apply_parameters:
          Parameters to use when applying the recommendation.
      campaign_budget:
          Optional parameters to use when applying a campaign budget
          recommendation.
      text_ad:
          Optional parameters to use when applying a text ad
          recommendation.
      keyword:
          Optional parameters to use when applying keyword
          recommendation.
      target_cpa_opt_in:
          Optional parameters to use when applying target CPA opt-in
          recommendation.
      callout_extension:
          Parameters to use when applying callout extension
          recommendation.
      call_extension:
          Parameters to use when applying call extension recommendation.
      sitelink_extension:
          Parameters to use when applying sitelink extension
          recommendation.
      move_unused_budget:
          Parameters to use when applying move unused budget
          recommendation.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ApplyRecommendationOperation)
  ))
_sym_db.RegisterMessage(ApplyRecommendationOperation)
_sym_db.RegisterMessage(ApplyRecommendationOperation.CampaignBudgetParameters)
_sym_db.RegisterMessage(ApplyRecommendationOperation.TextAdParameters)
_sym_db.RegisterMessage(ApplyRecommendationOperation.KeywordParameters)
_sym_db.RegisterMessage(ApplyRecommendationOperation.TargetCpaOptInParameters)
_sym_db.RegisterMessage(ApplyRecommendationOperation.CalloutExtensionParameters)
_sym_db.RegisterMessage(ApplyRecommendationOperation.CallExtensionParameters)
_sym_db.RegisterMessage(ApplyRecommendationOperation.SitelinkExtensionParameters)
_sym_db.RegisterMessage(ApplyRecommendationOperation.MoveUnusedBudgetParameters)

ApplyRecommendationResponse = _reflection.GeneratedProtocolMessageType('ApplyRecommendationResponse', (_message.Message,), dict(
  DESCRIPTOR = _APPLYRECOMMENDATIONRESPONSE,
  __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
  ,
  __doc__ = """Response message for
  [RecommendationService.ApplyRecommendation][google.ads.googleads.v1.services.RecommendationService.ApplyRecommendation].
  
  
  Attributes:
      results:
          Results of operations to apply recommendations.
      partial_failure_error:
          Errors that pertain to operation failures in the partial
          failure mode. Returned only when partial\_failure = true and
          all errors occur inside the operations. If any errors occur
          outside the operations (e.g. auth errors) we return the RPC
          level error.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ApplyRecommendationResponse)
  ))
_sym_db.RegisterMessage(ApplyRecommendationResponse)

ApplyRecommendationResult = _reflection.GeneratedProtocolMessageType('ApplyRecommendationResult', (_message.Message,), dict(
  DESCRIPTOR = _APPLYRECOMMENDATIONRESULT,
  __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
  ,
  __doc__ = """The result of applying a recommendation.
  
  
  Attributes:
      resource_name:
          Returned for successful applies.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ApplyRecommendationResult)
  ))
_sym_db.RegisterMessage(ApplyRecommendationResult)

DismissRecommendationRequest = _reflection.GeneratedProtocolMessageType('DismissRecommendationRequest', (_message.Message,), dict(

  DismissRecommendationOperation = _reflection.GeneratedProtocolMessageType('DismissRecommendationOperation', (_message.Message,), dict(
    DESCRIPTOR = _DISMISSRECOMMENDATIONREQUEST_DISMISSRECOMMENDATIONOPERATION,
    __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
    ,
    __doc__ = """Operation to dismiss a single recommendation identified by
    resource\_name.
    
    
    Attributes:
        resource_name:
            The resource name of the recommendation to dismiss.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.DismissRecommendationRequest.DismissRecommendationOperation)
    ))
  ,
  DESCRIPTOR = _DISMISSRECOMMENDATIONREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
  ,
  __doc__ = """Request message for
  [RecommendationService.DismissRecommendation][google.ads.googleads.v1.services.RecommendationService.DismissRecommendation].
  
  
  Attributes:
      customer_id:
          The ID of the customer with the recommendation.
      operations:
          The list of operations to dismiss recommendations. If
          partial\_failure=false all recommendations should be of the
          same type There is a limit of 100 operations per request.
      partial_failure:
          If true, successful operations will be carried out and invalid
          operations will return errors. If false, operations will be
          carried in a single transaction if and only if they are all
          valid. Default is false.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.DismissRecommendationRequest)
  ))
_sym_db.RegisterMessage(DismissRecommendationRequest)
_sym_db.RegisterMessage(DismissRecommendationRequest.DismissRecommendationOperation)

DismissRecommendationResponse = _reflection.GeneratedProtocolMessageType('DismissRecommendationResponse', (_message.Message,), dict(

  DismissRecommendationResult = _reflection.GeneratedProtocolMessageType('DismissRecommendationResult', (_message.Message,), dict(
    DESCRIPTOR = _DISMISSRECOMMENDATIONRESPONSE_DISMISSRECOMMENDATIONRESULT,
    __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
    ,
    __doc__ = """The result of dismissing a recommendation.
    
    
    Attributes:
        resource_name:
            Returned for successful dismissals.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.DismissRecommendationResponse.DismissRecommendationResult)
    ))
  ,
  DESCRIPTOR = _DISMISSRECOMMENDATIONRESPONSE,
  __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
  ,
  __doc__ = """Response message for
  [RecommendationService.DismissRecommendation][google.ads.googleads.v1.services.RecommendationService.DismissRecommendation].
  
  
  Attributes:
      results:
          Results of operations to dismiss recommendations.
      partial_failure_error:
          Errors that pertain to operation failures in the partial
          failure mode. Returned only when partial\_failure = true and
          all errors occur inside the operations. If any errors occur
          outside the operations (e.g. auth errors) we return the RPC
          level error.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.DismissRecommendationResponse)
  ))
_sym_db.RegisterMessage(DismissRecommendationResponse)
_sym_db.RegisterMessage(DismissRecommendationResponse.DismissRecommendationResult)


DESCRIPTOR._options = None

_RECOMMENDATIONSERVICE = _descriptor.ServiceDescriptor(
  name='RecommendationService',
  full_name='google.ads.googleads.v1.services.RecommendationService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=3272,
  serialized_end=3921,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetRecommendation',
    full_name='google.ads.googleads.v1.services.RecommendationService.GetRecommendation',
    index=0,
    containing_service=None,
    input_type=_GETRECOMMENDATIONREQUEST,
    output_type=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_recommendation__pb2._RECOMMENDATION,
    serialized_options=_b('\202\323\344\223\0023\0221/v1/{resource_name=customers/*/recommendations/*}'),
  ),
  _descriptor.MethodDescriptor(
    name='ApplyRecommendation',
    full_name='google.ads.googleads.v1.services.RecommendationService.ApplyRecommendation',
    index=1,
    containing_service=None,
    input_type=_APPLYRECOMMENDATIONREQUEST,
    output_type=_APPLYRECOMMENDATIONRESPONSE,
    serialized_options=_b('\202\323\344\223\0028\"3/v1/customers/{customer_id=*}/recommendations:apply:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='DismissRecommendation',
    full_name='google.ads.googleads.v1.services.RecommendationService.DismissRecommendation',
    index=2,
    containing_service=None,
    input_type=_DISMISSRECOMMENDATIONREQUEST,
    output_type=_DISMISSRECOMMENDATIONRESPONSE,
    serialized_options=_b('\202\323\344\223\002:\"5/v1/customers/{customer_id=*}/recommendations:dismiss:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_RECOMMENDATIONSERVICE)

DESCRIPTOR.services_by_name['RecommendationService'] = _RECOMMENDATIONSERVICE

# @@protoc_insertion_point(module_scope)
