# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/dynamic_search_ads_search_term_view.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/dynamic_search_ads_search_term_view.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB#DynamicSearchAdsSearchTermViewProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\nQgoogle/ads/googleads_v2/proto/resources/dynamic_search_ads_search_term_view.proto\x12!google.ads.googleads.v2.resources\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xfe\x01\n\x1e\x44ynamicSearchAdsSearchTermView\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\x31\n\x0bsearch_term\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08headline\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0clanding_page\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08page_url\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x90\x02\n%com.google.ads.googleads.v2.resourcesB#DynamicSearchAdsSearchTermViewProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_DYNAMICSEARCHADSSEARCHTERMVIEW = _descriptor.Descriptor(
  name='DynamicSearchAdsSearchTermView',
  full_name='google.ads.googleads.v2.resources.DynamicSearchAdsSearchTermView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.DynamicSearchAdsSearchTermView.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_term', full_name='google.ads.googleads.v2.resources.DynamicSearchAdsSearchTermView.search_term', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headline', full_name='google.ads.googleads.v2.resources.DynamicSearchAdsSearchTermView.headline', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='landing_page', full_name='google.ads.googleads.v2.resources.DynamicSearchAdsSearchTermView.landing_page', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_url', full_name='google.ads.googleads.v2.resources.DynamicSearchAdsSearchTermView.page_url', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=183,
  serialized_end=437,
)

_DYNAMICSEARCHADSSEARCHTERMVIEW.fields_by_name['search_term'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DYNAMICSEARCHADSSEARCHTERMVIEW.fields_by_name['headline'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DYNAMICSEARCHADSSEARCHTERMVIEW.fields_by_name['landing_page'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DYNAMICSEARCHADSSEARCHTERMVIEW.fields_by_name['page_url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['DynamicSearchAdsSearchTermView'] = _DYNAMICSEARCHADSSEARCHTERMVIEW
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DynamicSearchAdsSearchTermView = _reflection.GeneratedProtocolMessageType('DynamicSearchAdsSearchTermView', (_message.Message,), dict(
  DESCRIPTOR = _DYNAMICSEARCHADSSEARCHTERMVIEW,
  __module__ = 'google.ads.googleads_v2.proto.resources.dynamic_search_ads_search_term_view_pb2'
  ,
  __doc__ = """A dynamic search ads search term view.
  
  
  Attributes:
      resource_name:
          The resource name of the dynamic search ads search term view.
          Dynamic search ads search term view resource names have the
          form:  ``customers/{customer_id}/dynamicSearchAdsSearchTermVie
          ws/{ad_group_id}~{search_term_fp}~{headline_fp}~{landing_page_
          fp}~{page_url_fp}``
      search_term:
          Search term  This field is read-only.
      headline:
          The dynamically generated headline of the Dynamic Search Ad.
          This field is read-only.
      landing_page:
          The dynamically selected landing page URL of the impression.
          This field is read-only.
      page_url:
          The URL of page feed item served for the impression.  This
          field is read-only.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.DynamicSearchAdsSearchTermView)
  ))
_sym_db.RegisterMessage(DynamicSearchAdsSearchTermView)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
