# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/account_budget.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.enums import account_budget_proposal_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_account__budget__proposal__type__pb2
from google.ads.google_ads.v1.proto.enums import account_budget_status_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_account__budget__status__pb2
from google.ads.google_ads.v1.proto.enums import spending_limit_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_spending__limit__type__pb2
from google.ads.google_ads.v1.proto.enums import time_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_time__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/account_budget.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\022AccountBudgetProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\n<google/ads/googleads_v1/proto/resources/account_budget.proto\x12!google.ads.googleads.v1.resources\x1a\x46google/ads/googleads_v1/proto/enums/account_budget_proposal_type.proto\x1a?google/ads/googleads_v1/proto/enums/account_budget_status.proto\x1a=google/ads/googleads_v1/proto/enums/spending_limit_type.proto\x1a\x33google/ads/googleads_v1/proto/enums/time_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xc8\x13\n\rAccountBudget\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\'\n\x02id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x33\n\rbilling_setup\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12Z\n\x06status\x18\x04 \x01(\x0e\x32J.google.ads.googleads.v1.enums.AccountBudgetStatusEnum.AccountBudgetStatus\x12*\n\x04name\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12>\n\x18proposed_start_date_time\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12>\n\x18\x61pproved_start_date_time\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12=\n\x18total_adjustments_micros\x18\x12 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x14\x61mount_served_micros\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x15purchase_order_number\x18\x14 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05notes\x18\x15 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12g\n\x10pending_proposal\x18\x16 \x01(\x0b\x32M.google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal\x12>\n\x16proposed_end_date_time\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x00\x12V\n\x16proposed_end_time_type\x18\t \x01(\x0e\x32\x34.google.ads.googleads.v1.enums.TimeTypeEnum.TimeTypeH\x00\x12>\n\x16\x61pproved_end_date_time\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x01\x12V\n\x16\x61pproved_end_time_type\x18\x0b \x01(\x0e\x32\x34.google.ads.googleads.v1.enums.TimeTypeEnum.TimeTypeH\x01\x12\x45\n\x1eproposed_spending_limit_micros\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64ValueH\x02\x12n\n\x1cproposed_spending_limit_type\x18\r \x01(\x0e\x32\x46.google.ads.googleads.v1.enums.SpendingLimitTypeEnum.SpendingLimitTypeH\x02\x12\x45\n\x1e\x61pproved_spending_limit_micros\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.Int64ValueH\x03\x12n\n\x1c\x61pproved_spending_limit_type\x18\x0f \x01(\x0e\x32\x46.google.ads.googleads.v1.enums.SpendingLimitTypeEnum.SpendingLimitTypeH\x03\x12\x45\n\x1e\x61\x64justed_spending_limit_micros\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueH\x04\x12n\n\x1c\x61\x64justed_spending_limit_type\x18\x11 \x01(\x0e\x32\x46.google.ads.googleads.v1.enums.SpendingLimitTypeEnum.SpendingLimitTypeH\x04\x1a\x9c\x06\n\x1cPendingAccountBudgetProposal\x12=\n\x17\x61\x63\x63ount_budget_proposal\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12m\n\rproposal_type\x18\x02 \x01(\x0e\x32V.google.ads.googleads.v1.enums.AccountBudgetProposalTypeEnum.AccountBudgetProposalType\x12*\n\x04name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0fstart_date_time\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12;\n\x15purchase_order_number\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05notes\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x38\n\x12\x63reation_date_time\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\rend_date_time\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x00\x12M\n\rend_time_type\x18\x06 \x01(\x0e\x32\x34.google.ads.googleads.v1.enums.TimeTypeEnum.TimeTypeH\x00\x12<\n\x15spending_limit_micros\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueH\x01\x12\x65\n\x13spending_limit_type\x18\x08 \x01(\x0e\x32\x46.google.ads.googleads.v1.enums.SpendingLimitTypeEnum.SpendingLimitTypeH\x01\x42\n\n\x08\x65nd_timeB\x10\n\x0espending_limitB\x13\n\x11proposed_end_timeB\x13\n\x11\x61pproved_end_timeB\x19\n\x17proposed_spending_limitB\x19\n\x17\x61pproved_spending_limitB\x19\n\x17\x61\x64justed_spending_limitB\xff\x01\n%com.google.ads.googleads.v1.resourcesB\x12\x41\x63\x63ountBudgetProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_account__budget__proposal__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_account__budget__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_spending__limit__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_time__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL = _descriptor.Descriptor(
  name='PendingAccountBudgetProposal',
  full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_budget_proposal', full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal.account_budget_proposal', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proposal_type', full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal.proposal_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal.name', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_date_time', full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal.start_date_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='purchase_order_number', full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal.purchase_order_number', index=4,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notes', full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal.notes', index=5,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creation_date_time', full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal.creation_date_time', index=6,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_date_time', full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal.end_date_time', index=7,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time_type', full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal.end_time_type', index=8,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spending_limit_micros', full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal.spending_limit_micros', index=9,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spending_limit_type', full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal.spending_limit_type', index=10,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='end_time', full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal.end_time',
      index=0, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='spending_limit', full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal.spending_limit',
      index=1, containing_type=None, fields=[]),
  ],
  serialized_start=2000,
  serialized_end=2796,
)

_ACCOUNTBUDGET = _descriptor.Descriptor(
  name='AccountBudget',
  full_name='google.ads.googleads.v1.resources.AccountBudget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.AccountBudget.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v1.resources.AccountBudget.id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='billing_setup', full_name='google.ads.googleads.v1.resources.AccountBudget.billing_setup', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v1.resources.AccountBudget.status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v1.resources.AccountBudget.name', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proposed_start_date_time', full_name='google.ads.googleads.v1.resources.AccountBudget.proposed_start_date_time', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='approved_start_date_time', full_name='google.ads.googleads.v1.resources.AccountBudget.approved_start_date_time', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_adjustments_micros', full_name='google.ads.googleads.v1.resources.AccountBudget.total_adjustments_micros', index=7,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amount_served_micros', full_name='google.ads.googleads.v1.resources.AccountBudget.amount_served_micros', index=8,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='purchase_order_number', full_name='google.ads.googleads.v1.resources.AccountBudget.purchase_order_number', index=9,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notes', full_name='google.ads.googleads.v1.resources.AccountBudget.notes', index=10,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pending_proposal', full_name='google.ads.googleads.v1.resources.AccountBudget.pending_proposal', index=11,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proposed_end_date_time', full_name='google.ads.googleads.v1.resources.AccountBudget.proposed_end_date_time', index=12,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proposed_end_time_type', full_name='google.ads.googleads.v1.resources.AccountBudget.proposed_end_time_type', index=13,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='approved_end_date_time', full_name='google.ads.googleads.v1.resources.AccountBudget.approved_end_date_time', index=14,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='approved_end_time_type', full_name='google.ads.googleads.v1.resources.AccountBudget.approved_end_time_type', index=15,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proposed_spending_limit_micros', full_name='google.ads.googleads.v1.resources.AccountBudget.proposed_spending_limit_micros', index=16,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proposed_spending_limit_type', full_name='google.ads.googleads.v1.resources.AccountBudget.proposed_spending_limit_type', index=17,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='approved_spending_limit_micros', full_name='google.ads.googleads.v1.resources.AccountBudget.approved_spending_limit_micros', index=18,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='approved_spending_limit_type', full_name='google.ads.googleads.v1.resources.AccountBudget.approved_spending_limit_type', index=19,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='adjusted_spending_limit_micros', full_name='google.ads.googleads.v1.resources.AccountBudget.adjusted_spending_limit_micros', index=20,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='adjusted_spending_limit_type', full_name='google.ads.googleads.v1.resources.AccountBudget.adjusted_spending_limit_type', index=21,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='proposed_end_time', full_name='google.ads.googleads.v1.resources.AccountBudget.proposed_end_time',
      index=0, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='approved_end_time', full_name='google.ads.googleads.v1.resources.AccountBudget.approved_end_time',
      index=1, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='proposed_spending_limit', full_name='google.ads.googleads.v1.resources.AccountBudget.proposed_spending_limit',
      index=2, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='approved_spending_limit', full_name='google.ads.googleads.v1.resources.AccountBudget.approved_spending_limit',
      index=3, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='adjusted_spending_limit', full_name='google.ads.googleads.v1.resources.AccountBudget.adjusted_spending_limit',
      index=4, containing_type=None, fields=[]),
  ],
  serialized_start=415,
  serialized_end=2919,
)

_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['account_budget_proposal'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['proposal_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_account__budget__proposal__type__pb2._ACCOUNTBUDGETPROPOSALTYPEENUM_ACCOUNTBUDGETPROPOSALTYPE
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['start_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['purchase_order_number'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['notes'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['creation_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['end_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['end_time_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_time__type__pb2._TIMETYPEENUM_TIMETYPE
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['spending_limit_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['spending_limit_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_spending__limit__type__pb2._SPENDINGLIMITTYPEENUM_SPENDINGLIMITTYPE
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.containing_type = _ACCOUNTBUDGET
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.oneofs_by_name['end_time'].fields.append(
  _ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['end_date_time'])
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['end_date_time'].containing_oneof = _ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.oneofs_by_name['end_time']
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.oneofs_by_name['end_time'].fields.append(
  _ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['end_time_type'])
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['end_time_type'].containing_oneof = _ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.oneofs_by_name['end_time']
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.oneofs_by_name['spending_limit'].fields.append(
  _ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['spending_limit_micros'])
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['spending_limit_micros'].containing_oneof = _ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.oneofs_by_name['spending_limit']
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.oneofs_by_name['spending_limit'].fields.append(
  _ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['spending_limit_type'])
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['spending_limit_type'].containing_oneof = _ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.oneofs_by_name['spending_limit']
_ACCOUNTBUDGET.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ACCOUNTBUDGET.fields_by_name['billing_setup'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_account__budget__status__pb2._ACCOUNTBUDGETSTATUSENUM_ACCOUNTBUDGETSTATUS
_ACCOUNTBUDGET.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET.fields_by_name['proposed_start_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET.fields_by_name['approved_start_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET.fields_by_name['total_adjustments_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ACCOUNTBUDGET.fields_by_name['amount_served_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ACCOUNTBUDGET.fields_by_name['purchase_order_number'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET.fields_by_name['notes'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET.fields_by_name['pending_proposal'].message_type = _ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL
_ACCOUNTBUDGET.fields_by_name['proposed_end_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET.fields_by_name['proposed_end_time_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_time__type__pb2._TIMETYPEENUM_TIMETYPE
_ACCOUNTBUDGET.fields_by_name['approved_end_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET.fields_by_name['approved_end_time_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_time__type__pb2._TIMETYPEENUM_TIMETYPE
_ACCOUNTBUDGET.fields_by_name['proposed_spending_limit_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ACCOUNTBUDGET.fields_by_name['proposed_spending_limit_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_spending__limit__type__pb2._SPENDINGLIMITTYPEENUM_SPENDINGLIMITTYPE
_ACCOUNTBUDGET.fields_by_name['approved_spending_limit_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ACCOUNTBUDGET.fields_by_name['approved_spending_limit_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_spending__limit__type__pb2._SPENDINGLIMITTYPEENUM_SPENDINGLIMITTYPE
_ACCOUNTBUDGET.fields_by_name['adjusted_spending_limit_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ACCOUNTBUDGET.fields_by_name['adjusted_spending_limit_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_spending__limit__type__pb2._SPENDINGLIMITTYPEENUM_SPENDINGLIMITTYPE
_ACCOUNTBUDGET.oneofs_by_name['proposed_end_time'].fields.append(
  _ACCOUNTBUDGET.fields_by_name['proposed_end_date_time'])
_ACCOUNTBUDGET.fields_by_name['proposed_end_date_time'].containing_oneof = _ACCOUNTBUDGET.oneofs_by_name['proposed_end_time']
_ACCOUNTBUDGET.oneofs_by_name['proposed_end_time'].fields.append(
  _ACCOUNTBUDGET.fields_by_name['proposed_end_time_type'])
_ACCOUNTBUDGET.fields_by_name['proposed_end_time_type'].containing_oneof = _ACCOUNTBUDGET.oneofs_by_name['proposed_end_time']
_ACCOUNTBUDGET.oneofs_by_name['approved_end_time'].fields.append(
  _ACCOUNTBUDGET.fields_by_name['approved_end_date_time'])
_ACCOUNTBUDGET.fields_by_name['approved_end_date_time'].containing_oneof = _ACCOUNTBUDGET.oneofs_by_name['approved_end_time']
_ACCOUNTBUDGET.oneofs_by_name['approved_end_time'].fields.append(
  _ACCOUNTBUDGET.fields_by_name['approved_end_time_type'])
_ACCOUNTBUDGET.fields_by_name['approved_end_time_type'].containing_oneof = _ACCOUNTBUDGET.oneofs_by_name['approved_end_time']
_ACCOUNTBUDGET.oneofs_by_name['proposed_spending_limit'].fields.append(
  _ACCOUNTBUDGET.fields_by_name['proposed_spending_limit_micros'])
_ACCOUNTBUDGET.fields_by_name['proposed_spending_limit_micros'].containing_oneof = _ACCOUNTBUDGET.oneofs_by_name['proposed_spending_limit']
_ACCOUNTBUDGET.oneofs_by_name['proposed_spending_limit'].fields.append(
  _ACCOUNTBUDGET.fields_by_name['proposed_spending_limit_type'])
_ACCOUNTBUDGET.fields_by_name['proposed_spending_limit_type'].containing_oneof = _ACCOUNTBUDGET.oneofs_by_name['proposed_spending_limit']
_ACCOUNTBUDGET.oneofs_by_name['approved_spending_limit'].fields.append(
  _ACCOUNTBUDGET.fields_by_name['approved_spending_limit_micros'])
_ACCOUNTBUDGET.fields_by_name['approved_spending_limit_micros'].containing_oneof = _ACCOUNTBUDGET.oneofs_by_name['approved_spending_limit']
_ACCOUNTBUDGET.oneofs_by_name['approved_spending_limit'].fields.append(
  _ACCOUNTBUDGET.fields_by_name['approved_spending_limit_type'])
_ACCOUNTBUDGET.fields_by_name['approved_spending_limit_type'].containing_oneof = _ACCOUNTBUDGET.oneofs_by_name['approved_spending_limit']
_ACCOUNTBUDGET.oneofs_by_name['adjusted_spending_limit'].fields.append(
  _ACCOUNTBUDGET.fields_by_name['adjusted_spending_limit_micros'])
_ACCOUNTBUDGET.fields_by_name['adjusted_spending_limit_micros'].containing_oneof = _ACCOUNTBUDGET.oneofs_by_name['adjusted_spending_limit']
_ACCOUNTBUDGET.oneofs_by_name['adjusted_spending_limit'].fields.append(
  _ACCOUNTBUDGET.fields_by_name['adjusted_spending_limit_type'])
_ACCOUNTBUDGET.fields_by_name['adjusted_spending_limit_type'].containing_oneof = _ACCOUNTBUDGET.oneofs_by_name['adjusted_spending_limit']
DESCRIPTOR.message_types_by_name['AccountBudget'] = _ACCOUNTBUDGET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AccountBudget = _reflection.GeneratedProtocolMessageType('AccountBudget', (_message.Message,), dict(

  PendingAccountBudgetProposal = _reflection.GeneratedProtocolMessageType('PendingAccountBudgetProposal', (_message.Message,), dict(
    DESCRIPTOR = _ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL,
    __module__ = 'google.ads.googleads_v1.proto.resources.account_budget_pb2'
    ,
    __doc__ = """A pending proposal associated with the enclosing account-level budget,
    if applicable.
    
    
    Attributes:
        account_budget_proposal:
            The resource name of the proposal. AccountBudgetProposal
            resource names have the form:  ``customers/{customer_id}/accou
            ntBudgetProposals/{account_budget_proposal_id}``
        proposal_type:
            The type of this proposal, e.g. END to end the budget
            associated with this proposal.
        name:
            The name to assign to the account-level budget.
        start_date_time:
            The start time in yyyy-MM-dd HH:mm:ss format.
        purchase_order_number:
            A purchase order number is a value that helps users reference
            this budget in their monthly invoices.
        notes:
            Notes associated with this budget.
        creation_date_time:
            The time when this account-level budget proposal was created.
            Formatted as yyyy-MM-dd HH:mm:ss.
        end_time:
            The end time of the account-level budget.
        end_date_time:
            The end time in yyyy-MM-dd HH:mm:ss format.
        end_time_type:
            The end time as a well-defined type, e.g. FOREVER.
        spending_limit:
            The spending limit.
        spending_limit_micros:
            The spending limit in micros. One million is equivalent to one
            unit.
        spending_limit_type:
            The spending limit as a well-defined type, e.g. INFINITE.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal)
    ))
  ,
  DESCRIPTOR = _ACCOUNTBUDGET,
  __module__ = 'google.ads.googleads_v1.proto.resources.account_budget_pb2'
  ,
  __doc__ = """An account-level budget. It contains information about the budget
  itself, as well as the most recently approved changes to the budget and
  proposed changes that are pending approval. The proposed changes that
  are pending approval, if any, are found in 'pending\_proposal'.
  Effective details about the budget are found in fields prefixed
  'approved\_', 'adjusted\_' and those without a prefix. Since some
  effective details may differ from what the user had originally requested
  (e.g. spending limit), these differences are juxtaposed via
  'proposed\_', 'approved\_', and possibly 'adjusted\_' fields.
  
  This resource is mutated using AccountBudgetProposal and cannot be
  mutated directly. A budget may have at most one pending proposal at any
  given time. It is read through pending\_proposal.
  
  Once approved, a budget may be subject to adjustments, such as credit
  adjustments. Adjustments create differences between the 'approved' and
  'adjusted' fields, which would otherwise be identical.
  
  
  Attributes:
      resource_name:
          The resource name of the account-level budget. AccountBudget
          resource names have the form:
          ``customers/{customer_id}/accountBudgets/{account_budget_id}``
      id:
          The ID of the account-level budget.
      billing_setup:
          The resource name of the billing setup associated with this
          account-level budget. BillingSetup resource names have the
          form:
          ``customers/{customer_id}/billingSetups/{billing_setup_id}``
      status:
          The status of this account-level budget.
      name:
          The name of the account-level budget.
      proposed_start_date_time:
          The proposed start time of the account-level budget in yyyy-
          MM-dd HH:mm:ss format. If a start time type of NOW was
          proposed, this is the time of request.
      approved_start_date_time:
          The approved start time of the account-level budget in yyyy-
          MM-dd HH:mm:ss format.  For example, if a new budget is
          approved after the proposed start time, the approved start
          time is the time of approval.
      total_adjustments_micros:
          The total adjustments amount.  An example of an adjustment is
          courtesy credits.
      amount_served_micros:
          The value of Ads that have been served, in micros.  This
          includes overdelivery costs, in which case a credit might be
          automatically applied to the budget (see
          total\_adjustments\_micros).
      purchase_order_number:
          A purchase order number is a value that helps users reference
          this budget in their monthly invoices.
      notes:
          Notes associated with the budget.
      pending_proposal:
          The pending proposal to modify this budget, if applicable.
      proposed_end_time:
          The proposed end time of the account-level budget.
      proposed_end_date_time:
          The proposed end time in yyyy-MM-dd HH:mm:ss format.
      proposed_end_time_type:
          The proposed end time as a well-defined type, e.g. FOREVER.
      approved_end_time:
          The approved end time of the account-level budget.  For
          example, if a budget's end time is updated and the proposal is
          approved after the proposed end time, the approved end time is
          the time of approval.
      approved_end_date_time:
          The approved end time in yyyy-MM-dd HH:mm:ss format.
      approved_end_time_type:
          The approved end time as a well-defined type, e.g. FOREVER.
      proposed_spending_limit:
          The proposed spending limit.
      proposed_spending_limit_micros:
          The proposed spending limit in micros. One million is
          equivalent to one unit.
      proposed_spending_limit_type:
          The proposed spending limit as a well-defined type, e.g.
          INFINITE.
      approved_spending_limit:
          The approved spending limit.  For example, if the amount
          already spent by the account exceeds the proposed spending
          limit at the time the proposal is approved, the approved
          spending limit is set to the amount already spent.
      approved_spending_limit_micros:
          The approved spending limit in micros. One million is
          equivalent to one unit. This will only be populated if the
          proposed spending limit is finite, and will always be greater
          than or equal to the proposed spending limit.
      approved_spending_limit_type:
          The approved spending limit as a well-defined type, e.g.
          INFINITE. This will only be populated if the approved spending
          limit is INFINITE.
      adjusted_spending_limit:
          The spending limit after adjustments have been applied.
          Adjustments are stored in total\_adjustments\_micros.  This
          value has the final say on how much the account is allowed to
          spend.
      adjusted_spending_limit_micros:
          The adjusted spending limit in micros. One million is
          equivalent to one unit.  If the approved spending limit is
          finite, the adjusted spending limit may vary depending on the
          types of adjustments applied to this budget, if applicable.
          The different kinds of adjustments are described here:
          https://support.google.com/google-ads/answer/1704323  For
          example, a debit adjustment reduces how much the account is
          allowed to spend.
      adjusted_spending_limit_type:
          The adjusted spending limit as a well-defined type, e.g.
          INFINITE. This will only be populated if the adjusted spending
          limit is INFINITE, which is guaranteed to be true if the
          approved spending limit is INFINITE.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.AccountBudget)
  ))
_sym_db.RegisterMessage(AccountBudget)
_sym_db.RegisterMessage(AccountBudget.PendingAccountBudgetProposal)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
