# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/campaign_bid_modifier.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.common import criteria_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_criteria__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/campaign_bid_modifier.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\030CampaignBidModifierProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\nCgoogle/ads/googleads_v1/proto/resources/campaign_bid_modifier.proto\x12!google.ads.googleads.v1.resources\x1a\x33google/ads/googleads_v1/proto/common/criteria.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xa1\x02\n\x13\x43\x61mpaignBidModifier\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12.\n\x08\x63\x61mpaign\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0c\x63riterion_id\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x32\n\x0c\x62id_modifier\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12O\n\x10interaction_type\x18\x05 \x01(\x0b\x32\x33.google.ads.googleads.v1.common.InteractionTypeInfoH\x00\x42\x0b\n\tcriterionB\x85\x02\n%com.google.ads.googleads.v1.resourcesB\x18\x43\x61mpaignBidModifierProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_criteria__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_CAMPAIGNBIDMODIFIER = _descriptor.Descriptor(
  name='CampaignBidModifier',
  full_name='google.ads.googleads.v1.resources.CampaignBidModifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.CampaignBidModifier.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign', full_name='google.ads.googleads.v1.resources.CampaignBidModifier.campaign', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='criterion_id', full_name='google.ads.googleads.v1.resources.CampaignBidModifier.criterion_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bid_modifier', full_name='google.ads.googleads.v1.resources.CampaignBidModifier.bid_modifier', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interaction_type', full_name='google.ads.googleads.v1.resources.CampaignBidModifier.interaction_type', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='criterion', full_name='google.ads.googleads.v1.resources.CampaignBidModifier.criterion',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=222,
  serialized_end=511,
)

_CAMPAIGNBIDMODIFIER.fields_by_name['campaign'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGNBIDMODIFIER.fields_by_name['criterion_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CAMPAIGNBIDMODIFIER.fields_by_name['bid_modifier'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_CAMPAIGNBIDMODIFIER.fields_by_name['interaction_type'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_criteria__pb2._INTERACTIONTYPEINFO
_CAMPAIGNBIDMODIFIER.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNBIDMODIFIER.fields_by_name['interaction_type'])
_CAMPAIGNBIDMODIFIER.fields_by_name['interaction_type'].containing_oneof = _CAMPAIGNBIDMODIFIER.oneofs_by_name['criterion']
DESCRIPTOR.message_types_by_name['CampaignBidModifier'] = _CAMPAIGNBIDMODIFIER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CampaignBidModifier = _reflection.GeneratedProtocolMessageType('CampaignBidModifier', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNBIDMODIFIER,
  __module__ = 'google.ads.googleads_v1.proto.resources.campaign_bid_modifier_pb2'
  ,
  __doc__ = """Represents a bid-modifiable only criterion at the campaign level.
  
  
  Attributes:
      resource_name:
          The resource name of the campaign bid modifier. Campaign bid
          modifier resource names have the form:  ``customers/{customer_
          id}/campaignBidModifiers/{campaign_id}~{criterion_id}``
      campaign:
          The campaign to which this criterion belongs.
      criterion_id:
          The ID of the criterion to bid modify.  This field is ignored
          for mutates.
      bid_modifier:
          The modifier for the bid when the criterion matches.
      criterion:
          The criterion of this campaign bid modifier.
      interaction_type:
          Criterion for interaction type. Only supported for search
          campaigns.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.CampaignBidModifier)
  ))
_sym_db.RegisterMessage(CampaignBidModifier)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
