# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/enums/price_placeholder_field.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/enums/price_placeholder_field.proto',
  package='google.ads.googleads.v1.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v1.enumsB\032PricePlaceholderFieldProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V1.Enums\312\002\035Google\\Ads\\GoogleAds\\V1\\Enums\352\002!Google::Ads::GoogleAds::V1::Enums'),
  serialized_pb=_b('\nAgoogle/ads/googleads_v1/proto/enums/price_placeholder_field.proto\x12\x1dgoogle.ads.googleads.v1.enums\x1a\x1cgoogle/api/annotations.proto\"\xef\t\n\x19PricePlaceholderFieldEnum\"\xd1\t\n\x15PricePlaceholderField\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x08\n\x04TYPE\x10\x02\x12\x13\n\x0fPRICE_QUALIFIER\x10\x03\x12\x15\n\x11TRACKING_TEMPLATE\x10\x04\x12\x0c\n\x08LANGUAGE\x10\x05\x12\x14\n\x10\x46INAL_URL_SUFFIX\x10\x06\x12\x11\n\rITEM_1_HEADER\x10\x64\x12\x16\n\x12ITEM_1_DESCRIPTION\x10\x65\x12\x10\n\x0cITEM_1_PRICE\x10\x66\x12\x0f\n\x0bITEM_1_UNIT\x10g\x12\x15\n\x11ITEM_1_FINAL_URLS\x10h\x12\x1c\n\x18ITEM_1_FINAL_MOBILE_URLS\x10i\x12\x12\n\rITEM_2_HEADER\x10\xc8\x01\x12\x17\n\x12ITEM_2_DESCRIPTION\x10\xc9\x01\x12\x11\n\x0cITEM_2_PRICE\x10\xca\x01\x12\x10\n\x0bITEM_2_UNIT\x10\xcb\x01\x12\x16\n\x11ITEM_2_FINAL_URLS\x10\xcc\x01\x12\x1d\n\x18ITEM_2_FINAL_MOBILE_URLS\x10\xcd\x01\x12\x12\n\rITEM_3_HEADER\x10\xac\x02\x12\x17\n\x12ITEM_3_DESCRIPTION\x10\xad\x02\x12\x11\n\x0cITEM_3_PRICE\x10\xae\x02\x12\x10\n\x0bITEM_3_UNIT\x10\xaf\x02\x12\x16\n\x11ITEM_3_FINAL_URLS\x10\xb0\x02\x12\x1d\n\x18ITEM_3_FINAL_MOBILE_URLS\x10\xb1\x02\x12\x12\n\rITEM_4_HEADER\x10\x90\x03\x12\x17\n\x12ITEM_4_DESCRIPTION\x10\x91\x03\x12\x11\n\x0cITEM_4_PRICE\x10\x92\x03\x12\x10\n\x0bITEM_4_UNIT\x10\x93\x03\x12\x16\n\x11ITEM_4_FINAL_URLS\x10\x94\x03\x12\x1d\n\x18ITEM_4_FINAL_MOBILE_URLS\x10\x95\x03\x12\x12\n\rITEM_5_HEADER\x10\xf4\x03\x12\x17\n\x12ITEM_5_DESCRIPTION\x10\xf5\x03\x12\x11\n\x0cITEM_5_PRICE\x10\xf6\x03\x12\x10\n\x0bITEM_5_UNIT\x10\xf7\x03\x12\x16\n\x11ITEM_5_FINAL_URLS\x10\xf8\x03\x12\x1d\n\x18ITEM_5_FINAL_MOBILE_URLS\x10\xf9\x03\x12\x12\n\rITEM_6_HEADER\x10\xd8\x04\x12\x17\n\x12ITEM_6_DESCRIPTION\x10\xd9\x04\x12\x11\n\x0cITEM_6_PRICE\x10\xda\x04\x12\x10\n\x0bITEM_6_UNIT\x10\xdb\x04\x12\x16\n\x11ITEM_6_FINAL_URLS\x10\xdc\x04\x12\x1d\n\x18ITEM_6_FINAL_MOBILE_URLS\x10\xdd\x04\x12\x12\n\rITEM_7_HEADER\x10\xbc\x05\x12\x17\n\x12ITEM_7_DESCRIPTION\x10\xbd\x05\x12\x11\n\x0cITEM_7_PRICE\x10\xbe\x05\x12\x10\n\x0bITEM_7_UNIT\x10\xbf\x05\x12\x16\n\x11ITEM_7_FINAL_URLS\x10\xc0\x05\x12\x1d\n\x18ITEM_7_FINAL_MOBILE_URLS\x10\xc1\x05\x12\x12\n\rITEM_8_HEADER\x10\xa0\x06\x12\x17\n\x12ITEM_8_DESCRIPTION\x10\xa1\x06\x12\x11\n\x0cITEM_8_PRICE\x10\xa2\x06\x12\x10\n\x0bITEM_8_UNIT\x10\xa3\x06\x12\x16\n\x11ITEM_8_FINAL_URLS\x10\xa4\x06\x12\x1d\n\x18ITEM_8_FINAL_MOBILE_URLS\x10\xa5\x06\x42\xef\x01\n!com.google.ads.googleads.v1.enumsB\x1aPricePlaceholderFieldProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V1.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V1\\Enums\xea\x02!Google::Ads::GoogleAds::V1::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_PRICEPLACEHOLDERFIELDENUM_PRICEPLACEHOLDERFIELD = _descriptor.EnumDescriptor(
  name='PricePlaceholderField',
  full_name='google.ads.googleads.v1.enums.PricePlaceholderFieldEnum.PricePlaceholderField',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TYPE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRICE_QUALIFIER', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRACKING_TEMPLATE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANGUAGE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINAL_URL_SUFFIX', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_1_HEADER', index=7, number=100,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_1_DESCRIPTION', index=8, number=101,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_1_PRICE', index=9, number=102,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_1_UNIT', index=10, number=103,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_1_FINAL_URLS', index=11, number=104,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_1_FINAL_MOBILE_URLS', index=12, number=105,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_2_HEADER', index=13, number=200,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_2_DESCRIPTION', index=14, number=201,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_2_PRICE', index=15, number=202,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_2_UNIT', index=16, number=203,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_2_FINAL_URLS', index=17, number=204,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_2_FINAL_MOBILE_URLS', index=18, number=205,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_3_HEADER', index=19, number=300,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_3_DESCRIPTION', index=20, number=301,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_3_PRICE', index=21, number=302,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_3_UNIT', index=22, number=303,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_3_FINAL_URLS', index=23, number=304,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_3_FINAL_MOBILE_URLS', index=24, number=305,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_4_HEADER', index=25, number=400,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_4_DESCRIPTION', index=26, number=401,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_4_PRICE', index=27, number=402,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_4_UNIT', index=28, number=403,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_4_FINAL_URLS', index=29, number=404,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_4_FINAL_MOBILE_URLS', index=30, number=405,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_5_HEADER', index=31, number=500,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_5_DESCRIPTION', index=32, number=501,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_5_PRICE', index=33, number=502,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_5_UNIT', index=34, number=503,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_5_FINAL_URLS', index=35, number=504,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_5_FINAL_MOBILE_URLS', index=36, number=505,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_6_HEADER', index=37, number=600,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_6_DESCRIPTION', index=38, number=601,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_6_PRICE', index=39, number=602,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_6_UNIT', index=40, number=603,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_6_FINAL_URLS', index=41, number=604,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_6_FINAL_MOBILE_URLS', index=42, number=605,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_7_HEADER', index=43, number=700,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_7_DESCRIPTION', index=44, number=701,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_7_PRICE', index=45, number=702,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_7_UNIT', index=46, number=703,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_7_FINAL_URLS', index=47, number=704,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_7_FINAL_MOBILE_URLS', index=48, number=705,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_8_HEADER', index=49, number=800,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_8_DESCRIPTION', index=50, number=801,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_8_PRICE', index=51, number=802,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_8_UNIT', index=52, number=803,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_8_FINAL_URLS', index=53, number=804,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_8_FINAL_MOBILE_URLS', index=54, number=805,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=161,
  serialized_end=1394,
)
_sym_db.RegisterEnumDescriptor(_PRICEPLACEHOLDERFIELDENUM_PRICEPLACEHOLDERFIELD)


_PRICEPLACEHOLDERFIELDENUM = _descriptor.Descriptor(
  name='PricePlaceholderFieldEnum',
  full_name='google.ads.googleads.v1.enums.PricePlaceholderFieldEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PRICEPLACEHOLDERFIELDENUM_PRICEPLACEHOLDERFIELD,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=131,
  serialized_end=1394,
)

_PRICEPLACEHOLDERFIELDENUM_PRICEPLACEHOLDERFIELD.containing_type = _PRICEPLACEHOLDERFIELDENUM
DESCRIPTOR.message_types_by_name['PricePlaceholderFieldEnum'] = _PRICEPLACEHOLDERFIELDENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PricePlaceholderFieldEnum = _reflection.GeneratedProtocolMessageType('PricePlaceholderFieldEnum', (_message.Message,), dict(
  DESCRIPTOR = _PRICEPLACEHOLDERFIELDENUM,
  __module__ = 'google.ads.googleads_v1.proto.enums.price_placeholder_field_pb2'
  ,
  __doc__ = """Values for Price placeholder fields.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.enums.PricePlaceholderFieldEnum)
  ))
_sym_db.RegisterMessage(PricePlaceholderFieldEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
