# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/feed_mapping.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.enums import ad_customizer_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_ad__customizer__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import affiliate_location_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_affiliate__location__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import app_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_app__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import call_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_call__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import callout_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_callout__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import custom_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_custom__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import dsa_page_feed_criterion_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_dsa__page__feed__criterion__field__pb2
from google.ads.google_ads.v2.proto.enums import education_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_education__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import feed_mapping_criterion_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__mapping__criterion__type__pb2
from google.ads.google_ads.v2.proto.enums import feed_mapping_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__mapping__status__pb2
from google.ads.google_ads.v2.proto.enums import flight_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_flight__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import hotel_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_hotel__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import job_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_job__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import local_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_local__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import location_extension_targeting_criterion_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_location__extension__targeting__criterion__field__pb2
from google.ads.google_ads.v2.proto.enums import location_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_location__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import message_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_message__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import placeholder_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_placeholder__type__pb2
from google.ads.google_ads.v2.proto.enums import price_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_price__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import promotion_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_promotion__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import real_estate_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_real__estate__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import sitelink_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_sitelink__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import structured_snippet_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_structured__snippet__placeholder__field__pb2
from google.ads.google_ads.v2.proto.enums import travel_placeholder_field_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_travel__placeholder__field__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/feed_mapping.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\020FeedMappingProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\n:google/ads/googleads_v2/proto/resources/feed_mapping.proto\x12!google.ads.googleads.v2.resources\x1aIgoogle/ads/googleads_v2/proto/enums/ad_customizer_placeholder_field.proto\x1aNgoogle/ads/googleads_v2/proto/enums/affiliate_location_placeholder_field.proto\x1a?google/ads/googleads_v2/proto/enums/app_placeholder_field.proto\x1a@google/ads/googleads_v2/proto/enums/call_placeholder_field.proto\x1a\x43google/ads/googleads_v2/proto/enums/callout_placeholder_field.proto\x1a\x42google/ads/googleads_v2/proto/enums/custom_placeholder_field.proto\x1aGgoogle/ads/googleads_v2/proto/enums/dsa_page_feed_criterion_field.proto\x1a\x45google/ads/googleads_v2/proto/enums/education_placeholder_field.proto\x1a\x45google/ads/googleads_v2/proto/enums/feed_mapping_criterion_type.proto\x1a=google/ads/googleads_v2/proto/enums/feed_mapping_status.proto\x1a\x42google/ads/googleads_v2/proto/enums/flight_placeholder_field.proto\x1a\x41google/ads/googleads_v2/proto/enums/hotel_placeholder_field.proto\x1a?google/ads/googleads_v2/proto/enums/job_placeholder_field.proto\x1a\x41google/ads/googleads_v2/proto/enums/local_placeholder_field.proto\x1aVgoogle/ads/googleads_v2/proto/enums/location_extension_targeting_criterion_field.proto\x1a\x44google/ads/googleads_v2/proto/enums/location_placeholder_field.proto\x1a\x43google/ads/googleads_v2/proto/enums/message_placeholder_field.proto\x1a:google/ads/googleads_v2/proto/enums/placeholder_type.proto\x1a\x41google/ads/googleads_v2/proto/enums/price_placeholder_field.proto\x1a\x45google/ads/googleads_v2/proto/enums/promotion_placeholder_field.proto\x1aGgoogle/ads/googleads_v2/proto/enums/real_estate_placeholder_field.proto\x1a\x44google/ads/googleads_v2/proto/enums/sitelink_placeholder_field.proto\x1aNgoogle/ads/googleads_v2/proto/enums/structured_snippet_placeholder_field.proto\x1a\x42google/ads/googleads_v2/proto/enums/travel_placeholder_field.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xde\x03\n\x0b\x46\x65\x65\x64Mapping\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12*\n\x04\x66\x65\x65\x64\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12Z\n\x18\x61ttribute_field_mappings\x18\x05 \x03(\x0b\x32\x38.google.ads.googleads.v2.resources.AttributeFieldMapping\x12V\n\x06status\x18\x06 \x01(\x0e\x32\x46.google.ads.googleads.v2.enums.FeedMappingStatusEnum.FeedMappingStatus\x12^\n\x10placeholder_type\x18\x03 \x01(\x0e\x32\x42.google.ads.googleads.v2.enums.PlaceholderTypeEnum.PlaceholderTypeH\x00\x12n\n\x0e\x63riterion_type\x18\x04 \x01(\x0e\x32T.google.ads.googleads.v2.enums.FeedMappingCriterionTypeEnum.FeedMappingCriterionTypeH\x00\x42\x08\n\x06target\"\xea\x13\n\x15\x41ttributeFieldMapping\x12\x36\n\x11\x66\x65\x65\x64_attribute_id\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12-\n\x08\x66ield_id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12n\n\x0esitelink_field\x18\x03 \x01(\x0e\x32T.google.ads.googleads.v2.enums.SitelinkPlaceholderFieldEnum.SitelinkPlaceholderFieldH\x00\x12\x62\n\ncall_field\x18\x04 \x01(\x0e\x32L.google.ads.googleads.v2.enums.CallPlaceholderFieldEnum.CallPlaceholderFieldH\x00\x12_\n\tapp_field\x18\x05 \x01(\x0e\x32J.google.ads.googleads.v2.enums.AppPlaceholderFieldEnum.AppPlaceholderFieldH\x00\x12n\n\x0elocation_field\x18\x06 \x01(\x0e\x32T.google.ads.googleads.v2.enums.LocationPlaceholderFieldEnum.LocationPlaceholderFieldH\x00\x12\x8a\x01\n\x18\x61\x66\x66iliate_location_field\x18\x07 \x01(\x0e\x32\x66.google.ads.googleads.v2.enums.AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderFieldH\x00\x12k\n\rcallout_field\x18\x08 \x01(\x0e\x32R.google.ads.googleads.v2.enums.CalloutPlaceholderFieldEnum.CalloutPlaceholderFieldH\x00\x12\x8a\x01\n\x18structured_snippet_field\x18\t \x01(\x0e\x32\x66.google.ads.googleads.v2.enums.StructuredSnippetPlaceholderFieldEnum.StructuredSnippetPlaceholderFieldH\x00\x12k\n\rmessage_field\x18\n \x01(\x0e\x32R.google.ads.googleads.v2.enums.MessagePlaceholderFieldEnum.MessagePlaceholderFieldH\x00\x12\x65\n\x0bprice_field\x18\x0b \x01(\x0e\x32N.google.ads.googleads.v2.enums.PricePlaceholderFieldEnum.PricePlaceholderFieldH\x00\x12q\n\x0fpromotion_field\x18\x0c \x01(\x0e\x32V.google.ads.googleads.v2.enums.PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldH\x00\x12{\n\x13\x61\x64_customizer_field\x18\r \x01(\x0e\x32\\.google.ads.googleads.v2.enums.AdCustomizerPlaceholderFieldEnum.AdCustomizerPlaceholderFieldH\x00\x12u\n\x13\x64sa_page_feed_field\x18\x0e \x01(\x0e\x32V.google.ads.googleads.v2.enums.DsaPageFeedCriterionFieldEnum.DsaPageFeedCriterionFieldH\x00\x12\xa2\x01\n\"location_extension_targeting_field\x18\x0f \x01(\x0e\x32t.google.ads.googleads.v2.enums.LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionFieldH\x00\x12q\n\x0f\x65\x64ucation_field\x18\x10 \x01(\x0e\x32V.google.ads.googleads.v2.enums.EducationPlaceholderFieldEnum.EducationPlaceholderFieldH\x00\x12h\n\x0c\x66light_field\x18\x11 \x01(\x0e\x32P.google.ads.googleads.v2.enums.FlightPlaceholderFieldEnum.FlightPlaceholderFieldH\x00\x12h\n\x0c\x63ustom_field\x18\x12 \x01(\x0e\x32P.google.ads.googleads.v2.enums.CustomPlaceholderFieldEnum.CustomPlaceholderFieldH\x00\x12\x65\n\x0bhotel_field\x18\x13 \x01(\x0e\x32N.google.ads.googleads.v2.enums.HotelPlaceholderFieldEnum.HotelPlaceholderFieldH\x00\x12u\n\x11real_estate_field\x18\x14 \x01(\x0e\x32X.google.ads.googleads.v2.enums.RealEstatePlaceholderFieldEnum.RealEstatePlaceholderFieldH\x00\x12h\n\x0ctravel_field\x18\x15 \x01(\x0e\x32P.google.ads.googleads.v2.enums.TravelPlaceholderFieldEnum.TravelPlaceholderFieldH\x00\x12\x65\n\x0blocal_field\x18\x16 \x01(\x0e\x32N.google.ads.googleads.v2.enums.LocalPlaceholderFieldEnum.LocalPlaceholderFieldH\x00\x12_\n\tjob_field\x18\x17 \x01(\x0e\x32J.google.ads.googleads.v2.enums.JobPlaceholderFieldEnum.JobPlaceholderFieldH\x00\x42\x07\n\x05\x66ieldB\xfd\x01\n%com.google.ads.googleads.v2.resourcesB\x10\x46\x65\x65\x64MappingProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_ad__customizer__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_affiliate__location__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_app__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_call__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_callout__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_custom__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_dsa__page__feed__criterion__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_education__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__mapping__criterion__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__mapping__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_flight__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_hotel__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_job__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_local__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_location__extension__targeting__criterion__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_location__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_message__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_placeholder__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_price__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_promotion__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_real__estate__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_sitelink__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_structured__snippet__placeholder__field__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_travel__placeholder__field__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_FEEDMAPPING = _descriptor.Descriptor(
  name='FeedMapping',
  full_name='google.ads.googleads.v2.resources.FeedMapping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.FeedMapping.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed', full_name='google.ads.googleads.v2.resources.FeedMapping.feed', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute_field_mappings', full_name='google.ads.googleads.v2.resources.FeedMapping.attribute_field_mappings', index=2,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v2.resources.FeedMapping.status', index=3,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placeholder_type', full_name='google.ads.googleads.v2.resources.FeedMapping.placeholder_type', index=4,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='criterion_type', full_name='google.ads.googleads.v2.resources.FeedMapping.criterion_type', index=5,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='target', full_name='google.ads.googleads.v2.resources.FeedMapping.target',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1844,
  serialized_end=2322,
)


_ATTRIBUTEFIELDMAPPING = _descriptor.Descriptor(
  name='AttributeFieldMapping',
  full_name='google.ads.googleads.v2.resources.AttributeFieldMapping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_attribute_id', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.feed_attribute_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_id', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.field_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sitelink_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.sitelink_field', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.call_field', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.app_field', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.location_field', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='affiliate_location_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.affiliate_location_field', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='callout_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.callout_field', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='structured_snippet_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.structured_snippet_field', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.message_field', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.price_field', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='promotion_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.promotion_field', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_customizer_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.ad_customizer_field', index=12,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dsa_page_feed_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.dsa_page_feed_field', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_extension_targeting_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.location_extension_targeting_field', index=14,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='education_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.education_field', index=15,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flight_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.flight_field', index=16,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.custom_field', index=17,
      number=18, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.hotel_field', index=18,
      number=19, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='real_estate_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.real_estate_field', index=19,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='travel_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.travel_field', index=20,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.local_field', index=21,
      number=22, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.job_field', index=22,
      number=23, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='field', full_name='google.ads.googleads.v2.resources.AttributeFieldMapping.field',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=2325,
  serialized_end=4863,
)

_FEEDMAPPING.fields_by_name['feed'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEEDMAPPING.fields_by_name['attribute_field_mappings'].message_type = _ATTRIBUTEFIELDMAPPING
_FEEDMAPPING.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__mapping__status__pb2._FEEDMAPPINGSTATUSENUM_FEEDMAPPINGSTATUS
_FEEDMAPPING.fields_by_name['placeholder_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_placeholder__type__pb2._PLACEHOLDERTYPEENUM_PLACEHOLDERTYPE
_FEEDMAPPING.fields_by_name['criterion_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__mapping__criterion__type__pb2._FEEDMAPPINGCRITERIONTYPEENUM_FEEDMAPPINGCRITERIONTYPE
_FEEDMAPPING.oneofs_by_name['target'].fields.append(
  _FEEDMAPPING.fields_by_name['placeholder_type'])
_FEEDMAPPING.fields_by_name['placeholder_type'].containing_oneof = _FEEDMAPPING.oneofs_by_name['target']
_FEEDMAPPING.oneofs_by_name['target'].fields.append(
  _FEEDMAPPING.fields_by_name['criterion_type'])
_FEEDMAPPING.fields_by_name['criterion_type'].containing_oneof = _FEEDMAPPING.oneofs_by_name['target']
_ATTRIBUTEFIELDMAPPING.fields_by_name['feed_attribute_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ATTRIBUTEFIELDMAPPING.fields_by_name['field_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ATTRIBUTEFIELDMAPPING.fields_by_name['sitelink_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_sitelink__placeholder__field__pb2._SITELINKPLACEHOLDERFIELDENUM_SITELINKPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['call_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_call__placeholder__field__pb2._CALLPLACEHOLDERFIELDENUM_CALLPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['app_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_app__placeholder__field__pb2._APPPLACEHOLDERFIELDENUM_APPPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['location_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_location__placeholder__field__pb2._LOCATIONPLACEHOLDERFIELDENUM_LOCATIONPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['affiliate_location_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_affiliate__location__placeholder__field__pb2._AFFILIATELOCATIONPLACEHOLDERFIELDENUM_AFFILIATELOCATIONPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['callout_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_callout__placeholder__field__pb2._CALLOUTPLACEHOLDERFIELDENUM_CALLOUTPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['structured_snippet_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_structured__snippet__placeholder__field__pb2._STRUCTUREDSNIPPETPLACEHOLDERFIELDENUM_STRUCTUREDSNIPPETPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['message_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_message__placeholder__field__pb2._MESSAGEPLACEHOLDERFIELDENUM_MESSAGEPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['price_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_price__placeholder__field__pb2._PRICEPLACEHOLDERFIELDENUM_PRICEPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['promotion_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_promotion__placeholder__field__pb2._PROMOTIONPLACEHOLDERFIELDENUM_PROMOTIONPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['ad_customizer_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_ad__customizer__placeholder__field__pb2._ADCUSTOMIZERPLACEHOLDERFIELDENUM_ADCUSTOMIZERPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['dsa_page_feed_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_dsa__page__feed__criterion__field__pb2._DSAPAGEFEEDCRITERIONFIELDENUM_DSAPAGEFEEDCRITERIONFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['location_extension_targeting_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_location__extension__targeting__criterion__field__pb2._LOCATIONEXTENSIONTARGETINGCRITERIONFIELDENUM_LOCATIONEXTENSIONTARGETINGCRITERIONFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['education_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_education__placeholder__field__pb2._EDUCATIONPLACEHOLDERFIELDENUM_EDUCATIONPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['flight_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_flight__placeholder__field__pb2._FLIGHTPLACEHOLDERFIELDENUM_FLIGHTPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['custom_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_custom__placeholder__field__pb2._CUSTOMPLACEHOLDERFIELDENUM_CUSTOMPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['hotel_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_hotel__placeholder__field__pb2._HOTELPLACEHOLDERFIELDENUM_HOTELPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['real_estate_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_real__estate__placeholder__field__pb2._REALESTATEPLACEHOLDERFIELDENUM_REALESTATEPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['travel_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_travel__placeholder__field__pb2._TRAVELPLACEHOLDERFIELDENUM_TRAVELPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['local_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_local__placeholder__field__pb2._LOCALPLACEHOLDERFIELDENUM_LOCALPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.fields_by_name['job_field'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_job__placeholder__field__pb2._JOBPLACEHOLDERFIELDENUM_JOBPLACEHOLDERFIELD
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['sitelink_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['sitelink_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['call_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['call_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['app_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['app_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['location_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['location_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['affiliate_location_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['affiliate_location_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['callout_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['callout_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['structured_snippet_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['structured_snippet_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['message_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['message_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['price_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['price_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['promotion_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['promotion_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['ad_customizer_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['ad_customizer_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['dsa_page_feed_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['dsa_page_feed_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['location_extension_targeting_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['location_extension_targeting_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['education_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['education_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['flight_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['flight_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['custom_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['custom_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['hotel_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['hotel_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['real_estate_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['real_estate_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['travel_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['travel_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['local_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['local_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
_ATTRIBUTEFIELDMAPPING.oneofs_by_name['field'].fields.append(
  _ATTRIBUTEFIELDMAPPING.fields_by_name['job_field'])
_ATTRIBUTEFIELDMAPPING.fields_by_name['job_field'].containing_oneof = _ATTRIBUTEFIELDMAPPING.oneofs_by_name['field']
DESCRIPTOR.message_types_by_name['FeedMapping'] = _FEEDMAPPING
DESCRIPTOR.message_types_by_name['AttributeFieldMapping'] = _ATTRIBUTEFIELDMAPPING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeedMapping = _reflection.GeneratedProtocolMessageType('FeedMapping', (_message.Message,), dict(
  DESCRIPTOR = _FEEDMAPPING,
  __module__ = 'google.ads.googleads_v2.proto.resources.feed_mapping_pb2'
  ,
  __doc__ = """A feed mapping.
  
  
  Attributes:
      resource_name:
          The resource name of the feed mapping. Feed mapping resource
          names have the form:  ``customers/{customer_id}/feedMappings/{
          feed_id}~{feed_mapping_id}``
      feed:
          The feed of this feed mapping.
      attribute_field_mappings:
          Feed attributes to field mappings. These mappings are a one-
          to-many relationship meaning that 1 feed attribute can be used
          to populate multiple placeholder fields, but 1 placeholder
          field can only draw data from 1 feed attribute. Ad Customizer
          is an exception, 1 placeholder field can be mapped to multiple
          feed attributes. Required.
      status:
          Status of the feed mapping. This field is read-only.
      target:
          Feed mapping target. Can be either a placeholder or a
          criterion. For a given feed, the active FeedMappings must have
          unique targets. Required.
      placeholder_type:
          The placeholder type of this mapping (i.e., if the mapping
          maps feed attributes to placeholder fields).
      criterion_type:
          The criterion type of this mapping (i.e., if the mapping maps
          feed attributes to criterion fields).
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.FeedMapping)
  ))
_sym_db.RegisterMessage(FeedMapping)

AttributeFieldMapping = _reflection.GeneratedProtocolMessageType('AttributeFieldMapping', (_message.Message,), dict(
  DESCRIPTOR = _ATTRIBUTEFIELDMAPPING,
  __module__ = 'google.ads.googleads_v2.proto.resources.feed_mapping_pb2'
  ,
  __doc__ = """Maps from feed attribute id to a placeholder or criterion field id.
  
  
  Attributes:
      feed_attribute_id:
          Feed attribute from which to map.
      field_id:
          The placeholder field ID. If a placeholder field enum is not
          published in the current API version, then this field will be
          populated and the field oneof will be empty. This field is
          read-only.
      field:
          Placeholder or criterion field to be populated using data from
          the above feed attribute. Required.
      sitelink_field:
          Sitelink Placeholder Fields.
      call_field:
          Call Placeholder Fields.
      app_field:
          App Placeholder Fields.
      location_field:
          Location Placeholder Fields. This field is read-only.
      affiliate_location_field:
          Affiliate Location Placeholder Fields. This field is read-
          only.
      callout_field:
          Callout Placeholder Fields.
      structured_snippet_field:
          Structured Snippet Placeholder Fields.
      message_field:
          Message Placeholder Fields.
      price_field:
          Price Placeholder Fields.
      promotion_field:
          Promotion Placeholder Fields.
      ad_customizer_field:
          Ad Customizer Placeholder Fields
      dsa_page_feed_field:
          Dynamic Search Ad Page Feed Fields.
      location_extension_targeting_field:
          Location Target Fields.
      education_field:
          Education Placeholder Fields
      flight_field:
          Flight Placeholder Fields
      custom_field:
          Custom Placeholder Fields
      hotel_field:
          Hotel Placeholder Fields
      real_estate_field:
          Real Estate Placeholder Fields
      travel_field:
          Travel Placeholder Fields
      local_field:
          Local Placeholder Fields
      job_field:
          Job Placeholder Fields
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.AttributeFieldMapping)
  ))
_sym_db.RegisterMessage(AttributeFieldMapping)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
