# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/enums/vanity_pharma_text.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/enums/vanity_pharma_text.proto',
  package='google.ads.googleads.v1.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v1.enumsB\025VanityPharmaTextProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V1.Enums\312\002\035Google\\Ads\\GoogleAds\\V1\\Enums\352\002!Google::Ads::GoogleAds::V1::Enums'),
  serialized_pb=_b('\n<google/ads/googleads_v1/proto/enums/vanity_pharma_text.proto\x12\x1dgoogle.ads.googleads.v1.enums\x1a\x1cgoogle/api/annotations.proto\"\x8b\x04\n\x14VanityPharmaTextEnum\"\xf2\x03\n\x10VanityPharmaText\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12%\n!PRESCRIPTION_TREATMENT_WEBSITE_EN\x10\x02\x12%\n!PRESCRIPTION_TREATMENT_WEBSITE_ES\x10\x03\x12\"\n\x1ePRESCRIPTION_DEVICE_WEBSITE_EN\x10\x04\x12\"\n\x1ePRESCRIPTION_DEVICE_WEBSITE_ES\x10\x05\x12\x1d\n\x19MEDICAL_DEVICE_WEBSITE_EN\x10\x06\x12\x1d\n\x19MEDICAL_DEVICE_WEBSITE_ES\x10\x07\x12%\n!PREVENTATIVE_TREATMENT_WEBSITE_EN\x10\x08\x12%\n!PREVENTATIVE_TREATMENT_WEBSITE_ES\x10\t\x12)\n%PRESCRIPTION_CONTRACEPTION_WEBSITE_EN\x10\n\x12)\n%PRESCRIPTION_CONTRACEPTION_WEBSITE_ES\x10\x0b\x12#\n\x1fPRESCRIPTION_VACCINE_WEBSITE_EN\x10\x0c\x12#\n\x1fPRESCRIPTION_VACCINE_WEBSITE_ES\x10\rB\xea\x01\n!com.google.ads.googleads.v1.enumsB\x15VanityPharmaTextProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V1.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V1\\Enums\xea\x02!Google::Ads::GoogleAds::V1::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_VANITYPHARMATEXTENUM_VANITYPHARMATEXT = _descriptor.EnumDescriptor(
  name='VanityPharmaText',
  full_name='google.ads.googleads.v1.enums.VanityPharmaTextEnum.VanityPharmaText',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRESCRIPTION_TREATMENT_WEBSITE_EN', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRESCRIPTION_TREATMENT_WEBSITE_ES', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRESCRIPTION_DEVICE_WEBSITE_EN', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRESCRIPTION_DEVICE_WEBSITE_ES', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MEDICAL_DEVICE_WEBSITE_EN', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MEDICAL_DEVICE_WEBSITE_ES', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PREVENTATIVE_TREATMENT_WEBSITE_EN', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PREVENTATIVE_TREATMENT_WEBSITE_ES', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRESCRIPTION_CONTRACEPTION_WEBSITE_EN', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRESCRIPTION_CONTRACEPTION_WEBSITE_ES', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRESCRIPTION_VACCINE_WEBSITE_EN', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRESCRIPTION_VACCINE_WEBSITE_ES', index=13, number=13,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=151,
  serialized_end=649,
)
_sym_db.RegisterEnumDescriptor(_VANITYPHARMATEXTENUM_VANITYPHARMATEXT)


_VANITYPHARMATEXTENUM = _descriptor.Descriptor(
  name='VanityPharmaTextEnum',
  full_name='google.ads.googleads.v1.enums.VanityPharmaTextEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VANITYPHARMATEXTENUM_VANITYPHARMATEXT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=649,
)

_VANITYPHARMATEXTENUM_VANITYPHARMATEXT.containing_type = _VANITYPHARMATEXTENUM
DESCRIPTOR.message_types_by_name['VanityPharmaTextEnum'] = _VANITYPHARMATEXTENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VanityPharmaTextEnum = _reflection.GeneratedProtocolMessageType('VanityPharmaTextEnum', (_message.Message,), dict(
  DESCRIPTOR = _VANITYPHARMATEXTENUM,
  __module__ = 'google.ads.googleads_v1.proto.enums.vanity_pharma_text_pb2'
  ,
  __doc__ = """The text that will be displayed in display URL of the text ad when
  website description is the selected display mode for vanity pharma URLs.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.enums.VanityPharmaTextEnum)
  ))
_sym_db.RegisterMessage(VanityPharmaTextEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
