# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import managed_placement_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_managed__placement__view__pb2
from google.ads.google_ads.v2.proto.services import managed_placement_view_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_managed__placement__view__service__pb2


class ManagedPlacementViewServiceStub(object):
  """Proto file describing the Managed Placement View service.

  Service to manage Managed Placement views.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetManagedPlacementView = channel.unary_unary(
        '/google.ads.googleads.v2.services.ManagedPlacementViewService/GetManagedPlacementView',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_managed__placement__view__service__pb2.GetManagedPlacementViewRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_managed__placement__view__pb2.ManagedPlacementView.FromString,
        )


class ManagedPlacementViewServiceServicer(object):
  """Proto file describing the Managed Placement View service.

  Service to manage Managed Placement views.
  """

  def GetManagedPlacementView(self, request, context):
    """Returns the requested Managed Placement view in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ManagedPlacementViewServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetManagedPlacementView': grpc.unary_unary_rpc_method_handler(
          servicer.GetManagedPlacementView,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_managed__placement__view__service__pb2.GetManagedPlacementViewRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_managed__placement__view__pb2.ManagedPlacementView.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.ManagedPlacementViewService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
