# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/common/segments.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.common import criteria_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2
from google.ads.google_ads.v2.proto.enums import ad_network_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_ad__network__type__pb2
from google.ads.google_ads.v2.proto.enums import click_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_click__type__pb2
from google.ads.google_ads.v2.proto.enums import conversion_action_category_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_conversion__action__category__pb2
from google.ads.google_ads.v2.proto.enums import conversion_attribution_event_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_conversion__attribution__event__type__pb2
from google.ads.google_ads.v2.proto.enums import conversion_lag_bucket_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_conversion__lag__bucket__pb2
from google.ads.google_ads.v2.proto.enums import conversion_or_adjustment_lag_bucket_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_conversion__or__adjustment__lag__bucket__pb2
from google.ads.google_ads.v2.proto.enums import day_of_week_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_day__of__week__pb2
from google.ads.google_ads.v2.proto.enums import device_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_device__pb2
from google.ads.google_ads.v2.proto.enums import external_conversion_source_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_external__conversion__source__pb2
from google.ads.google_ads.v2.proto.enums import hotel_date_selection_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_hotel__date__selection__type__pb2
from google.ads.google_ads.v2.proto.enums import hotel_price_bucket_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_hotel__price__bucket__pb2
from google.ads.google_ads.v2.proto.enums import hotel_rate_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_hotel__rate__type__pb2
from google.ads.google_ads.v2.proto.enums import month_of_year_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_month__of__year__pb2
from google.ads.google_ads.v2.proto.enums import placeholder_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_placeholder__type__pb2
from google.ads.google_ads.v2.proto.enums import product_channel_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_product__channel__pb2
from google.ads.google_ads.v2.proto.enums import product_channel_exclusivity_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_product__channel__exclusivity__pb2
from google.ads.google_ads.v2.proto.enums import product_condition_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_product__condition__pb2
from google.ads.google_ads.v2.proto.enums import search_engine_results_page_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_search__engine__results__page__type__pb2
from google.ads.google_ads.v2.proto.enums import search_term_match_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_search__term__match__type__pb2
from google.ads.google_ads.v2.proto.enums import slot_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_slot__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/common/segments.proto',
  package='google.ads.googleads.v2.common',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v2.commonB\rSegmentsProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V2.Common\312\002\036Google\\Ads\\GoogleAds\\V2\\Common\352\002\"Google::Ads::GoogleAds::V2::Common'),
  serialized_pb=_b('\n3google/ads/googleads_v2/proto/common/segments.proto\x12\x1egoogle.ads.googleads.v2.common\x1a\x33google/ads/googleads_v2/proto/common/criteria.proto\x1a\x39google/ads/googleads_v2/proto/enums/ad_network_type.proto\x1a\x34google/ads/googleads_v2/proto/enums/click_type.proto\x1a\x44google/ads/googleads_v2/proto/enums/conversion_action_category.proto\x1aKgoogle/ads/googleads_v2/proto/enums/conversion_attribution_event_type.proto\x1a?google/ads/googleads_v2/proto/enums/conversion_lag_bucket.proto\x1aMgoogle/ads/googleads_v2/proto/enums/conversion_or_adjustment_lag_bucket.proto\x1a\x35google/ads/googleads_v2/proto/enums/day_of_week.proto\x1a\x30google/ads/googleads_v2/proto/enums/device.proto\x1a\x44google/ads/googleads_v2/proto/enums/external_conversion_source.proto\x1a\x43google/ads/googleads_v2/proto/enums/hotel_date_selection_type.proto\x1a<google/ads/googleads_v2/proto/enums/hotel_price_bucket.proto\x1a\x39google/ads/googleads_v2/proto/enums/hotel_rate_type.proto\x1a\x37google/ads/googleads_v2/proto/enums/month_of_year.proto\x1a:google/ads/googleads_v2/proto/enums/placeholder_type.proto\x1a\x39google/ads/googleads_v2/proto/enums/product_channel.proto\x1a\x45google/ads/googleads_v2/proto/enums/product_channel_exclusivity.proto\x1a;google/ads/googleads_v2/proto/enums/product_condition.proto\x1aIgoogle/ads/googleads_v2/proto/enums/search_engine_results_page_type.proto\x1a@google/ads/googleads_v2/proto/enums/search_term_match_type.proto\x1a.google/ads/googleads_v2/proto/enums/slot.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xb1*\n\x08Segments\x12W\n\x0f\x61\x64_network_type\x18\x03 \x01(\x0e\x32>.google.ads.googleads.v2.enums.AdNetworkTypeEnum.AdNetworkType\x12J\n\nclick_type\x18\x1a \x01(\x0e\x32\x36.google.ads.googleads.v2.enums.ClickTypeEnum.ClickType\x12\x37\n\x11\x63onversion_action\x18\x34 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12x\n\x1a\x63onversion_action_category\x18\x35 \x01(\x0e\x32T.google.ads.googleads.v2.enums.ConversionActionCategoryEnum.ConversionActionCategory\x12<\n\x16\x63onversion_action_name\x18\x36 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x15\x63onversion_adjustment\x18\x1b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x8b\x01\n!conversion_attribution_event_type\x18\x02 \x01(\x0e\x32`.google.ads.googleads.v2.enums.ConversionAttributionEventTypeEnum.ConversionAttributionEventType\x12i\n\x15\x63onversion_lag_bucket\x18\x32 \x01(\x0e\x32J.google.ads.googleads.v2.enums.ConversionLagBucketEnum.ConversionLagBucket\x12\x8f\x01\n#conversion_or_adjustment_lag_bucket\x18\x33 \x01(\x0e\x32\x62.google.ads.googleads.v2.enums.ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket\x12*\n\x04\x64\x61te\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12K\n\x0b\x64\x61y_of_week\x18\x05 \x01(\x0e\x32\x36.google.ads.googleads.v2.enums.DayOfWeekEnum.DayOfWeek\x12@\n\x06\x64\x65vice\x18\x01 \x01(\x0e\x32\x30.google.ads.googleads.v2.enums.DeviceEnum.Device\x12x\n\x1a\x65xternal_conversion_source\x18\x37 \x01(\x0e\x32T.google.ads.googleads.v2.enums.ExternalConversionSourceEnum.ExternalConversionSource\x12\x38\n\x12geo_target_airport\x18\x41 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x11geo_target_canton\x18L \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0fgeo_target_city\x18> \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x38\n\x12geo_target_country\x18M \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x11geo_target_county\x18\x44 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x13geo_target_district\x18\x45 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x10geo_target_metro\x18? \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12G\n!geo_target_most_specific_location\x18H \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12<\n\x16geo_target_postal_code\x18G \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x13geo_target_province\x18K \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x11geo_target_region\x18@ \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x10geo_target_state\x18\x43 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12>\n\x19hotel_booking_window_days\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x34\n\x0fhotel_center_id\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x13hotel_check_in_date\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12Z\n\x1ahotel_check_in_day_of_week\x18\t \x01(\x0e\x32\x36.google.ads.googleads.v2.enums.DayOfWeekEnum.DayOfWeek\x12\x30\n\nhotel_city\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\x0bhotel_class\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x33\n\rhotel_country\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12s\n\x19hotel_date_selection_type\x18\r \x01(\x0e\x32P.google.ads.googleads.v2.enums.HotelDateSelectionTypeEnum.HotelDateSelectionType\x12\x39\n\x14hotel_length_of_stay\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x38\n\x12hotel_rate_rule_id\x18I \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12W\n\x0fhotel_rate_type\x18J \x01(\x0e\x32>.google.ads.googleads.v2.enums.HotelRateTypeEnum.HotelRateType\x12`\n\x12hotel_price_bucket\x18N \x01(\x0e\x32\x44.google.ads.googleads.v2.enums.HotelPriceBucketEnum.HotelPriceBucket\x12\x31\n\x0bhotel_state\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12)\n\x04hour\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x41\n\x1dinteraction_on_this_extension\x18\x31 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x38\n\x07keyword\x18= \x01(\x0b\x32\'.google.ads.googleads.v2.common.Keyword\x12+\n\x05month\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12Q\n\rmonth_of_year\x18\x12 \x01(\x0e\x32:.google.ads.googleads.v2.enums.MonthOfYearEnum.MonthOfYear\x12\x36\n\x10partner_hotel_id\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\\\n\x10placeholder_type\x18\x14 \x01(\x0e\x32\x42.google.ads.googleads.v2.enums.PlaceholderTypeEnum.PlaceholderType\x12;\n\x15product_aggregator_id\x18\x1c \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x45\n\x1fproduct_bidding_category_level1\x18\x38 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x45\n\x1fproduct_bidding_category_level2\x18\x39 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x45\n\x1fproduct_bidding_category_level3\x18: \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x45\n\x1fproduct_bidding_category_level4\x18; \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x45\n\x1fproduct_bidding_category_level5\x18< \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rproduct_brand\x18\x1d \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12Y\n\x0fproduct_channel\x18\x1e \x01(\x0e\x32@.google.ads.googleads.v2.enums.ProductChannelEnum.ProductChannel\x12{\n\x1bproduct_channel_exclusivity\x18\x1f \x01(\x0e\x32V.google.ads.googleads.v2.enums.ProductChannelExclusivityEnum.ProductChannelExclusivity\x12_\n\x11product_condition\x18  \x01(\x0e\x32\x44.google.ads.googleads.v2.enums.ProductConditionEnum.ProductCondition\x12\x35\n\x0fproduct_country\x18! \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12?\n\x19product_custom_attribute0\x18\" \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12?\n\x19product_custom_attribute1\x18# \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12?\n\x19product_custom_attribute2\x18$ \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12?\n\x19product_custom_attribute3\x18% \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12?\n\x19product_custom_attribute4\x18& \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0fproduct_item_id\x18\' \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x10product_language\x18( \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x13product_merchant_id\x18) \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x36\n\x10product_store_id\x18* \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rproduct_title\x18+ \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0fproduct_type_l1\x18, \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0fproduct_type_l2\x18- \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0fproduct_type_l3\x18. \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0fproduct_type_l4\x18/ \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0fproduct_type_l5\x18\x30 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07quarter\x18\x15 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x83\x01\n\x1fsearch_engine_results_page_type\x18\x46 \x01(\x0e\x32Z.google.ads.googleads.v2.enums.SearchEngineResultsPageTypeEnum.SearchEngineResultsPageType\x12j\n\x16search_term_match_type\x18\x16 \x01(\x0e\x32J.google.ads.googleads.v2.enums.SearchTermMatchTypeEnum.SearchTermMatchType\x12:\n\x04slot\x18\x17 \x01(\x0e\x32,.google.ads.googleads.v2.enums.SlotEnum.Slot\x12-\n\x07webpage\x18\x42 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04week\x18\x18 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12)\n\x04year\x18\x19 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\"~\n\x07Keyword\x12\x38\n\x12\x61\x64_group_criterion\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x04info\x18\x02 \x01(\x0b\x32+.google.ads.googleads.v2.common.KeywordInfoB\xe8\x01\n\"com.google.ads.googleads.v2.commonB\rSegmentsProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V2.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V2\\Common\xea\x02\"Google::Ads::GoogleAds::V2::Commonb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_ad__network__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_click__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_conversion__action__category__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_conversion__attribution__event__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_conversion__lag__bucket__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_conversion__or__adjustment__lag__bucket__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_day__of__week__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_device__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_external__conversion__source__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_hotel__date__selection__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_hotel__price__bucket__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_hotel__rate__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_month__of__year__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_placeholder__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_product__channel__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_product__channel__exclusivity__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_product__condition__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_search__engine__results__page__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_search__term__match__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_slot__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_SEGMENTS = _descriptor.Descriptor(
  name='Segments',
  full_name='google.ads.googleads.v2.common.Segments',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ad_network_type', full_name='google.ads.googleads.v2.common.Segments.ad_network_type', index=0,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='click_type', full_name='google.ads.googleads.v2.common.Segments.click_type', index=1,
      number=26, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_action', full_name='google.ads.googleads.v2.common.Segments.conversion_action', index=2,
      number=52, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_action_category', full_name='google.ads.googleads.v2.common.Segments.conversion_action_category', index=3,
      number=53, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_action_name', full_name='google.ads.googleads.v2.common.Segments.conversion_action_name', index=4,
      number=54, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_adjustment', full_name='google.ads.googleads.v2.common.Segments.conversion_adjustment', index=5,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_attribution_event_type', full_name='google.ads.googleads.v2.common.Segments.conversion_attribution_event_type', index=6,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_lag_bucket', full_name='google.ads.googleads.v2.common.Segments.conversion_lag_bucket', index=7,
      number=50, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_or_adjustment_lag_bucket', full_name='google.ads.googleads.v2.common.Segments.conversion_or_adjustment_lag_bucket', index=8,
      number=51, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='google.ads.googleads.v2.common.Segments.date', index=9,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='day_of_week', full_name='google.ads.googleads.v2.common.Segments.day_of_week', index=10,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device', full_name='google.ads.googleads.v2.common.Segments.device', index=11,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='external_conversion_source', full_name='google.ads.googleads.v2.common.Segments.external_conversion_source', index=12,
      number=55, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_airport', full_name='google.ads.googleads.v2.common.Segments.geo_target_airport', index=13,
      number=65, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_canton', full_name='google.ads.googleads.v2.common.Segments.geo_target_canton', index=14,
      number=76, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_city', full_name='google.ads.googleads.v2.common.Segments.geo_target_city', index=15,
      number=62, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_country', full_name='google.ads.googleads.v2.common.Segments.geo_target_country', index=16,
      number=77, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_county', full_name='google.ads.googleads.v2.common.Segments.geo_target_county', index=17,
      number=68, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_district', full_name='google.ads.googleads.v2.common.Segments.geo_target_district', index=18,
      number=69, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_metro', full_name='google.ads.googleads.v2.common.Segments.geo_target_metro', index=19,
      number=63, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_most_specific_location', full_name='google.ads.googleads.v2.common.Segments.geo_target_most_specific_location', index=20,
      number=72, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_postal_code', full_name='google.ads.googleads.v2.common.Segments.geo_target_postal_code', index=21,
      number=71, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_province', full_name='google.ads.googleads.v2.common.Segments.geo_target_province', index=22,
      number=75, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_region', full_name='google.ads.googleads.v2.common.Segments.geo_target_region', index=23,
      number=64, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_state', full_name='google.ads.googleads.v2.common.Segments.geo_target_state', index=24,
      number=67, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_booking_window_days', full_name='google.ads.googleads.v2.common.Segments.hotel_booking_window_days', index=25,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_center_id', full_name='google.ads.googleads.v2.common.Segments.hotel_center_id', index=26,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_check_in_date', full_name='google.ads.googleads.v2.common.Segments.hotel_check_in_date', index=27,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_check_in_day_of_week', full_name='google.ads.googleads.v2.common.Segments.hotel_check_in_day_of_week', index=28,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_city', full_name='google.ads.googleads.v2.common.Segments.hotel_city', index=29,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_class', full_name='google.ads.googleads.v2.common.Segments.hotel_class', index=30,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_country', full_name='google.ads.googleads.v2.common.Segments.hotel_country', index=31,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_date_selection_type', full_name='google.ads.googleads.v2.common.Segments.hotel_date_selection_type', index=32,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_length_of_stay', full_name='google.ads.googleads.v2.common.Segments.hotel_length_of_stay', index=33,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_rate_rule_id', full_name='google.ads.googleads.v2.common.Segments.hotel_rate_rule_id', index=34,
      number=73, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_rate_type', full_name='google.ads.googleads.v2.common.Segments.hotel_rate_type', index=35,
      number=74, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_price_bucket', full_name='google.ads.googleads.v2.common.Segments.hotel_price_bucket', index=36,
      number=78, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_state', full_name='google.ads.googleads.v2.common.Segments.hotel_state', index=37,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hour', full_name='google.ads.googleads.v2.common.Segments.hour', index=38,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interaction_on_this_extension', full_name='google.ads.googleads.v2.common.Segments.interaction_on_this_extension', index=39,
      number=49, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword', full_name='google.ads.googleads.v2.common.Segments.keyword', index=40,
      number=61, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='month', full_name='google.ads.googleads.v2.common.Segments.month', index=41,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='month_of_year', full_name='google.ads.googleads.v2.common.Segments.month_of_year', index=42,
      number=18, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partner_hotel_id', full_name='google.ads.googleads.v2.common.Segments.partner_hotel_id', index=43,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placeholder_type', full_name='google.ads.googleads.v2.common.Segments.placeholder_type', index=44,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_aggregator_id', full_name='google.ads.googleads.v2.common.Segments.product_aggregator_id', index=45,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_bidding_category_level1', full_name='google.ads.googleads.v2.common.Segments.product_bidding_category_level1', index=46,
      number=56, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_bidding_category_level2', full_name='google.ads.googleads.v2.common.Segments.product_bidding_category_level2', index=47,
      number=57, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_bidding_category_level3', full_name='google.ads.googleads.v2.common.Segments.product_bidding_category_level3', index=48,
      number=58, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_bidding_category_level4', full_name='google.ads.googleads.v2.common.Segments.product_bidding_category_level4', index=49,
      number=59, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_bidding_category_level5', full_name='google.ads.googleads.v2.common.Segments.product_bidding_category_level5', index=50,
      number=60, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_brand', full_name='google.ads.googleads.v2.common.Segments.product_brand', index=51,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_channel', full_name='google.ads.googleads.v2.common.Segments.product_channel', index=52,
      number=30, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_channel_exclusivity', full_name='google.ads.googleads.v2.common.Segments.product_channel_exclusivity', index=53,
      number=31, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_condition', full_name='google.ads.googleads.v2.common.Segments.product_condition', index=54,
      number=32, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_country', full_name='google.ads.googleads.v2.common.Segments.product_country', index=55,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_custom_attribute0', full_name='google.ads.googleads.v2.common.Segments.product_custom_attribute0', index=56,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_custom_attribute1', full_name='google.ads.googleads.v2.common.Segments.product_custom_attribute1', index=57,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_custom_attribute2', full_name='google.ads.googleads.v2.common.Segments.product_custom_attribute2', index=58,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_custom_attribute3', full_name='google.ads.googleads.v2.common.Segments.product_custom_attribute3', index=59,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_custom_attribute4', full_name='google.ads.googleads.v2.common.Segments.product_custom_attribute4', index=60,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_item_id', full_name='google.ads.googleads.v2.common.Segments.product_item_id', index=61,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_language', full_name='google.ads.googleads.v2.common.Segments.product_language', index=62,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_merchant_id', full_name='google.ads.googleads.v2.common.Segments.product_merchant_id', index=63,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_store_id', full_name='google.ads.googleads.v2.common.Segments.product_store_id', index=64,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_title', full_name='google.ads.googleads.v2.common.Segments.product_title', index=65,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_type_l1', full_name='google.ads.googleads.v2.common.Segments.product_type_l1', index=66,
      number=44, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_type_l2', full_name='google.ads.googleads.v2.common.Segments.product_type_l2', index=67,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_type_l3', full_name='google.ads.googleads.v2.common.Segments.product_type_l3', index=68,
      number=46, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_type_l4', full_name='google.ads.googleads.v2.common.Segments.product_type_l4', index=69,
      number=47, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_type_l5', full_name='google.ads.googleads.v2.common.Segments.product_type_l5', index=70,
      number=48, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quarter', full_name='google.ads.googleads.v2.common.Segments.quarter', index=71,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_engine_results_page_type', full_name='google.ads.googleads.v2.common.Segments.search_engine_results_page_type', index=72,
      number=70, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_term_match_type', full_name='google.ads.googleads.v2.common.Segments.search_term_match_type', index=73,
      number=22, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slot', full_name='google.ads.googleads.v2.common.Segments.slot', index=74,
      number=23, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='webpage', full_name='google.ads.googleads.v2.common.Segments.webpage', index=75,
      number=66, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='week', full_name='google.ads.googleads.v2.common.Segments.week', index=76,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='year', full_name='google.ads.googleads.v2.common.Segments.year', index=77,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1469,
  serialized_end=6894,
)


_KEYWORD = _descriptor.Descriptor(
  name='Keyword',
  full_name='google.ads.googleads.v2.common.Keyword',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ad_group_criterion', full_name='google.ads.googleads.v2.common.Keyword.ad_group_criterion', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='info', full_name='google.ads.googleads.v2.common.Keyword.info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6896,
  serialized_end=7022,
)

_SEGMENTS.fields_by_name['ad_network_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_ad__network__type__pb2._ADNETWORKTYPEENUM_ADNETWORKTYPE
_SEGMENTS.fields_by_name['click_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_click__type__pb2._CLICKTYPEENUM_CLICKTYPE
_SEGMENTS.fields_by_name['conversion_action'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['conversion_action_category'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_conversion__action__category__pb2._CONVERSIONACTIONCATEGORYENUM_CONVERSIONACTIONCATEGORY
_SEGMENTS.fields_by_name['conversion_action_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['conversion_adjustment'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_SEGMENTS.fields_by_name['conversion_attribution_event_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_conversion__attribution__event__type__pb2._CONVERSIONATTRIBUTIONEVENTTYPEENUM_CONVERSIONATTRIBUTIONEVENTTYPE
_SEGMENTS.fields_by_name['conversion_lag_bucket'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_conversion__lag__bucket__pb2._CONVERSIONLAGBUCKETENUM_CONVERSIONLAGBUCKET
_SEGMENTS.fields_by_name['conversion_or_adjustment_lag_bucket'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_conversion__or__adjustment__lag__bucket__pb2._CONVERSIONORADJUSTMENTLAGBUCKETENUM_CONVERSIONORADJUSTMENTLAGBUCKET
_SEGMENTS.fields_by_name['date'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['day_of_week'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_day__of__week__pb2._DAYOFWEEKENUM_DAYOFWEEK
_SEGMENTS.fields_by_name['device'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_device__pb2._DEVICEENUM_DEVICE
_SEGMENTS.fields_by_name['external_conversion_source'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_external__conversion__source__pb2._EXTERNALCONVERSIONSOURCEENUM_EXTERNALCONVERSIONSOURCE
_SEGMENTS.fields_by_name['geo_target_airport'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['geo_target_canton'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['geo_target_city'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['geo_target_country'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['geo_target_county'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['geo_target_district'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['geo_target_metro'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['geo_target_most_specific_location'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['geo_target_postal_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['geo_target_province'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['geo_target_region'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['geo_target_state'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['hotel_booking_window_days'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_SEGMENTS.fields_by_name['hotel_center_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_SEGMENTS.fields_by_name['hotel_check_in_date'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['hotel_check_in_day_of_week'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_day__of__week__pb2._DAYOFWEEKENUM_DAYOFWEEK
_SEGMENTS.fields_by_name['hotel_city'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['hotel_class'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_SEGMENTS.fields_by_name['hotel_country'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['hotel_date_selection_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_hotel__date__selection__type__pb2._HOTELDATESELECTIONTYPEENUM_HOTELDATESELECTIONTYPE
_SEGMENTS.fields_by_name['hotel_length_of_stay'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_SEGMENTS.fields_by_name['hotel_rate_rule_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['hotel_rate_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_hotel__rate__type__pb2._HOTELRATETYPEENUM_HOTELRATETYPE
_SEGMENTS.fields_by_name['hotel_price_bucket'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_hotel__price__bucket__pb2._HOTELPRICEBUCKETENUM_HOTELPRICEBUCKET
_SEGMENTS.fields_by_name['hotel_state'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['hour'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_SEGMENTS.fields_by_name['interaction_on_this_extension'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_SEGMENTS.fields_by_name['keyword'].message_type = _KEYWORD
_SEGMENTS.fields_by_name['month'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['month_of_year'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_month__of__year__pb2._MONTHOFYEARENUM_MONTHOFYEAR
_SEGMENTS.fields_by_name['partner_hotel_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['placeholder_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_placeholder__type__pb2._PLACEHOLDERTYPEENUM_PLACEHOLDERTYPE
_SEGMENTS.fields_by_name['product_aggregator_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT64VALUE
_SEGMENTS.fields_by_name['product_bidding_category_level1'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_bidding_category_level2'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_bidding_category_level3'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_bidding_category_level4'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_bidding_category_level5'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_brand'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_channel'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_product__channel__pb2._PRODUCTCHANNELENUM_PRODUCTCHANNEL
_SEGMENTS.fields_by_name['product_channel_exclusivity'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_product__channel__exclusivity__pb2._PRODUCTCHANNELEXCLUSIVITYENUM_PRODUCTCHANNELEXCLUSIVITY
_SEGMENTS.fields_by_name['product_condition'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_product__condition__pb2._PRODUCTCONDITIONENUM_PRODUCTCONDITION
_SEGMENTS.fields_by_name['product_country'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_custom_attribute0'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_custom_attribute1'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_custom_attribute2'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_custom_attribute3'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_custom_attribute4'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_item_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_language'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_merchant_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT64VALUE
_SEGMENTS.fields_by_name['product_store_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_title'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_type_l1'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_type_l2'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_type_l3'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_type_l4'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_type_l5'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['quarter'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['search_engine_results_page_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_search__engine__results__page__type__pb2._SEARCHENGINERESULTSPAGETYPEENUM_SEARCHENGINERESULTSPAGETYPE
_SEGMENTS.fields_by_name['search_term_match_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_search__term__match__type__pb2._SEARCHTERMMATCHTYPEENUM_SEARCHTERMMATCHTYPE
_SEGMENTS.fields_by_name['slot'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_slot__pb2._SLOTENUM_SLOT
_SEGMENTS.fields_by_name['webpage'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['week'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['year'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_KEYWORD.fields_by_name['ad_group_criterion'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_KEYWORD.fields_by_name['info'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._KEYWORDINFO
DESCRIPTOR.message_types_by_name['Segments'] = _SEGMENTS
DESCRIPTOR.message_types_by_name['Keyword'] = _KEYWORD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Segments = _reflection.GeneratedProtocolMessageType('Segments', (_message.Message,), dict(
  DESCRIPTOR = _SEGMENTS,
  __module__ = 'google.ads.googleads_v2.proto.common.segments_pb2'
  ,
  __doc__ = """Segment only fields.
  
  
  Attributes:
      ad_network_type:
          Ad network type.
      click_type:
          Click type.
      conversion_action:
          Resource name of the conversion action.
      conversion_action_category:
          Conversion action category.
      conversion_action_name:
          Conversion action name.
      conversion_adjustment:
          This segments your conversion columns by the original
          conversion and conversion value vs. the delta if conversions
          were adjusted. False row has the data as originally stated;
          While true row has the delta between data now and the data as
          originally stated. Summing the two together results post-
          adjustment data.
      conversion_attribution_event_type:
          Conversion attribution event type.
      conversion_lag_bucket:
          An enum value representing the number of days between the
          impression and the conversion.
      conversion_or_adjustment_lag_bucket:
          An enum value representing the number of days between the
          impression and the conversion or between the impression and
          adjustments to the conversion.
      date:
          Date to which metrics apply. yyyy-MM-dd format, e.g.,
          2018-04-17.
      day_of_week:
          Day of the week, e.g., MONDAY.
      device:
          Device to which metrics apply.
      external_conversion_source:
          External conversion source.
      geo_target_airport:
          Resource name of the geo target constant that represents an
          airport.
      geo_target_canton:
          Resource name of the geo target constant that represents a
          canton.
      geo_target_city:
          Resource name of the geo target constant that represents a
          city.
      geo_target_country:
          Resource name of the geo target constant that represents a
          country.
      geo_target_county:
          Resource name of the geo target constant that represents a
          county.
      geo_target_district:
          Resource name of the geo target constant that represents a
          district.
      geo_target_metro:
          Resource name of the geo target constant that represents a
          metro.
      geo_target_most_specific_location:
          Resource name of the geo target constant that represents the
          most specific location.
      geo_target_postal_code:
          Resource name of the geo target constant that represents a
          postal code.
      geo_target_province:
          Resource name of the geo target constant that represents a
          province.
      geo_target_region:
          Resource name of the geo target constant that represents a
          region.
      geo_target_state:
          Resource name of the geo target constant that represents a
          state.
      hotel_booking_window_days:
          Hotel booking window in days.
      hotel_center_id:
          Hotel center ID.
      hotel_check_in_date:
          Hotel check-in date. Formatted as yyyy-MM-dd.
      hotel_check_in_day_of_week:
          Hotel check-in day of week.
      hotel_city:
          Hotel city.
      hotel_class:
          Hotel class.
      hotel_country:
          Hotel country.
      hotel_date_selection_type:
          Hotel date selection type.
      hotel_length_of_stay:
          Hotel length of stay.
      hotel_rate_rule_id:
          Hotel rate rule ID.
      hotel_rate_type:
          Hotel rate type.
      hotel_price_bucket:
          Hotel price bucket.
      hotel_state:
          Hotel state.
      hour:
          Hour of day as a number between 0 and 23, inclusive.
      interaction_on_this_extension:
          Only used with feed item metrics. Indicates whether the
          interaction metrics occurred on the feed item itself or a
          different extension or ad unit.
      keyword:
          Keyword criterion.
      month:
          Month as represented by the date of the first day of a month.
          Formatted as yyyy-MM-dd.
      month_of_year:
          Month of the year, e.g., January.
      partner_hotel_id:
          Partner hotel ID.
      placeholder_type:
          Placeholder type. This is only used with feed item metrics.
      product_aggregator_id:
          Aggregator ID of the product.
      product_bidding_category_level1:
          Bidding category (level 1) of the product.
      product_bidding_category_level2:
          Bidding category (level 2) of the product.
      product_bidding_category_level3:
          Bidding category (level 3) of the product.
      product_bidding_category_level4:
          Bidding category (level 4) of the product.
      product_bidding_category_level5:
          Bidding category (level 5) of the product.
      product_brand:
          Brand of the product.
      product_channel:
          Channel of the product.
      product_channel_exclusivity:
          Channel exclusivity of the product.
      product_condition:
          Condition of the product.
      product_country:
          Resource name of the geo target constant for the country of
          sale of the product.
      product_custom_attribute0:
          Custom attribute 0 of the product.
      product_custom_attribute1:
          Custom attribute 1 of the product.
      product_custom_attribute2:
          Custom attribute 2 of the product.
      product_custom_attribute3:
          Custom attribute 3 of the product.
      product_custom_attribute4:
          Custom attribute 4 of the product.
      product_item_id:
          Item ID of the product.
      product_language:
          Resource name of the language constant for the language of the
          product.
      product_merchant_id:
          Merchant ID of the product.
      product_store_id:
          Store ID of the product.
      product_title:
          Title of the product.
      product_type_l1:
          Type (level 1) of the product.
      product_type_l2:
          Type (level 2) of the product.
      product_type_l3:
          Type (level 3) of the product.
      product_type_l4:
          Type (level 4) of the product.
      product_type_l5:
          Type (level 5) of the product.
      quarter:
          Quarter as represented by the date of the first day of a
          quarter. Uses the calendar year for quarters, e.g., the second
          quarter of 2018 starts on 2018-04-01. Formatted as yyyy-MM-dd.
      search_engine_results_page_type:
          Type of the search engine results page.
      search_term_match_type:
          Match type of the keyword that triggered the ad, including
          variants.
      slot:
          Position of the ad.
      webpage:
          Resource name of the ad group criterion that represents
          webpage criterion.
      week:
          Week as defined as Monday through Sunday, and represented by
          the date of Monday. Formatted as yyyy-MM-dd.
      year:
          Year, formatted as yyyy.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.Segments)
  ))
_sym_db.RegisterMessage(Segments)

Keyword = _reflection.GeneratedProtocolMessageType('Keyword', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORD,
  __module__ = 'google.ads.googleads_v2.proto.common.segments_pb2'
  ,
  __doc__ = """A Keyword criterion segment.
  
  
  Attributes:
      ad_group_criterion:
          The AdGroupCriterion resource name.
      info:
          Keyword info.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.Keyword)
  ))
_sym_db.RegisterMessage(Keyword)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
