# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/keyword_plan.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.common import dates_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_dates__pb2
from google.ads.google_ads.v2.proto.enums import keyword_plan_forecast_interval_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_keyword__plan__forecast__interval__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/keyword_plan.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\020KeywordPlanProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\n:google/ads/googleads_v2/proto/resources/keyword_plan.proto\x12!google.ads.googleads.v2.resources\x1a\x30google/ads/googleads_v2/proto/common/dates.proto\x1aHgoogle/ads/googleads_v2/proto/enums/keyword_plan_forecast_interval.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xd0\x01\n\x0bKeywordPlan\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\'\n\x02id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12*\n\x04name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12U\n\x0f\x66orecast_period\x18\x04 \x01(\x0b\x32<.google.ads.googleads.v2.resources.KeywordPlanForecastPeriod\"\xdd\x01\n\x19KeywordPlanForecastPeriod\x12s\n\rdate_interval\x18\x01 \x01(\x0e\x32Z.google.ads.googleads.v2.enums.KeywordPlanForecastIntervalEnum.KeywordPlanForecastIntervalH\x00\x12?\n\ndate_range\x18\x02 \x01(\x0b\x32).google.ads.googleads.v2.common.DateRangeH\x00\x42\n\n\x08intervalB\xfd\x01\n%com.google.ads.googleads.v2.resourcesB\x10KeywordPlanProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_dates__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_keyword__plan__forecast__interval__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_KEYWORDPLAN = _descriptor.Descriptor(
  name='KeywordPlan',
  full_name='google.ads.googleads.v2.resources.KeywordPlan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.KeywordPlan.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v2.resources.KeywordPlan.id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v2.resources.KeywordPlan.name', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forecast_period', full_name='google.ads.googleads.v2.resources.KeywordPlan.forecast_period', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=284,
  serialized_end=492,
)


_KEYWORDPLANFORECASTPERIOD = _descriptor.Descriptor(
  name='KeywordPlanForecastPeriod',
  full_name='google.ads.googleads.v2.resources.KeywordPlanForecastPeriod',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='date_interval', full_name='google.ads.googleads.v2.resources.KeywordPlanForecastPeriod.date_interval', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_range', full_name='google.ads.googleads.v2.resources.KeywordPlanForecastPeriod.date_range', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='interval', full_name='google.ads.googleads.v2.resources.KeywordPlanForecastPeriod.interval',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=495,
  serialized_end=716,
)

_KEYWORDPLAN.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_KEYWORDPLAN.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_KEYWORDPLAN.fields_by_name['forecast_period'].message_type = _KEYWORDPLANFORECASTPERIOD
_KEYWORDPLANFORECASTPERIOD.fields_by_name['date_interval'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_keyword__plan__forecast__interval__pb2._KEYWORDPLANFORECASTINTERVALENUM_KEYWORDPLANFORECASTINTERVAL
_KEYWORDPLANFORECASTPERIOD.fields_by_name['date_range'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_dates__pb2._DATERANGE
_KEYWORDPLANFORECASTPERIOD.oneofs_by_name['interval'].fields.append(
  _KEYWORDPLANFORECASTPERIOD.fields_by_name['date_interval'])
_KEYWORDPLANFORECASTPERIOD.fields_by_name['date_interval'].containing_oneof = _KEYWORDPLANFORECASTPERIOD.oneofs_by_name['interval']
_KEYWORDPLANFORECASTPERIOD.oneofs_by_name['interval'].fields.append(
  _KEYWORDPLANFORECASTPERIOD.fields_by_name['date_range'])
_KEYWORDPLANFORECASTPERIOD.fields_by_name['date_range'].containing_oneof = _KEYWORDPLANFORECASTPERIOD.oneofs_by_name['interval']
DESCRIPTOR.message_types_by_name['KeywordPlan'] = _KEYWORDPLAN
DESCRIPTOR.message_types_by_name['KeywordPlanForecastPeriod'] = _KEYWORDPLANFORECASTPERIOD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KeywordPlan = _reflection.GeneratedProtocolMessageType('KeywordPlan', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDPLAN,
  __module__ = 'google.ads.googleads_v2.proto.resources.keyword_plan_pb2'
  ,
  __doc__ = """A Keyword Planner plan. Max number of saved keyword plans: 10000. It's
  possible to remove plans if limit is reached.
  
  
  Attributes:
      resource_name:
          The resource name of the Keyword Planner plan. KeywordPlan
          resource names have the form:
          ``customers/{customer_id}/keywordPlans/{kp_plan_id}``
      id:
          The ID of the keyword plan.
      name:
          The name of the keyword plan.  This field is required and
          should not be empty when creating new keyword plans.
      forecast_period:
          The date period used for forecasting the plan.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.KeywordPlan)
  ))
_sym_db.RegisterMessage(KeywordPlan)

KeywordPlanForecastPeriod = _reflection.GeneratedProtocolMessageType('KeywordPlanForecastPeriod', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDPLANFORECASTPERIOD,
  __module__ = 'google.ads.googleads_v2.proto.resources.keyword_plan_pb2'
  ,
  __doc__ = """The forecasting period associated with the keyword plan.
  
  
  Attributes:
      interval:
          Required. The date used for forecasting the Plan.
      date_interval:
          A future date range relative to the current date used for
          forecasting.
      date_range:
          The custom date range used for forecasting. The start and end
          dates must be in the future. Otherwise, an error will be
          returned when the forecasting action is performed. The start
          and end dates are inclusive.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.KeywordPlanForecastPeriod)
  ))
_sym_db.RegisterMessage(KeywordPlanForecastPeriod)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
