# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/feed_item.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.common import custom_parameter_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_custom__parameter__pb2
from google.ads.google_ads.v2.proto.common import feed_common_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_feed__common__pb2
from google.ads.google_ads.v2.proto.common import policy_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_policy__pb2
from google.ads.google_ads.v2.proto.enums import feed_item_quality_approval_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__quality__approval__status__pb2
from google.ads.google_ads.v2.proto.enums import feed_item_quality_disapproval_reason_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__quality__disapproval__reason__pb2
from google.ads.google_ads.v2.proto.enums import feed_item_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__status__pb2
from google.ads.google_ads.v2.proto.enums import feed_item_validation_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__validation__status__pb2
from google.ads.google_ads.v2.proto.enums import geo_targeting_restriction_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_geo__targeting__restriction__pb2
from google.ads.google_ads.v2.proto.enums import placeholder_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_placeholder__type__pb2
from google.ads.google_ads.v2.proto.enums import policy_approval_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_policy__approval__status__pb2
from google.ads.google_ads.v2.proto.enums import policy_review_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_policy__review__status__pb2
from google.ads.google_ads.v2.proto.errors import feed_item_validation_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_feed__item__validation__error__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/feed_item.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\rFeedItemProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\n7google/ads/googleads_v2/proto/resources/feed_item.proto\x12!google.ads.googleads.v2.resources\x1a;google/ads/googleads_v2/proto/common/custom_parameter.proto\x1a\x36google/ads/googleads_v2/proto/common/feed_common.proto\x1a\x31google/ads/googleads_v2/proto/common/policy.proto\x1aKgoogle/ads/googleads_v2/proto/enums/feed_item_quality_approval_status.proto\x1aNgoogle/ads/googleads_v2/proto/enums/feed_item_quality_disapproval_reason.proto\x1a:google/ads/googleads_v2/proto/enums/feed_item_status.proto\x1a\x45google/ads/googleads_v2/proto/enums/feed_item_validation_status.proto\x1a\x43google/ads/googleads_v2/proto/enums/geo_targeting_restriction.proto\x1a:google/ads/googleads_v2/proto/enums/placeholder_type.proto\x1a@google/ads/googleads_v2/proto/enums/policy_approval_status.proto\x1a>google/ads/googleads_v2/proto/enums/policy_review_status.proto\x1a\x45google/ads/googleads_v2/proto/errors/feed_item_validation_error.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xa8\x05\n\x08\x46\x65\x65\x64Item\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12*\n\x04\x66\x65\x65\x64\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\'\n\x02id\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x35\n\x0fstart_date_time\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rend_date_time\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12S\n\x10\x61ttribute_values\x18\x06 \x03(\x0b\x32\x39.google.ads.googleads.v2.resources.FeedItemAttributeValue\x12u\n\x19geo_targeting_restriction\x18\x07 \x01(\x0e\x32R.google.ads.googleads.v2.enums.GeoTargetingRestrictionEnum.GeoTargetingRestriction\x12N\n\x15url_custom_parameters\x18\x08 \x03(\x0b\x32/.google.ads.googleads.v2.common.CustomParameter\x12P\n\x06status\x18\t \x01(\x0e\x32@.google.ads.googleads.v2.enums.FeedItemStatusEnum.FeedItemStatus\x12V\n\x0cpolicy_infos\x18\n \x03(\x0b\x32@.google.ads.googleads.v2.resources.FeedItemPlaceholderPolicyInfo\"\xae\x04\n\x16\x46\x65\x65\x64ItemAttributeValue\x12\x36\n\x11\x66\x65\x65\x64_attribute_id\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x32\n\rinteger_value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\rboolean_value\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0cstring_value\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0c\x64ouble_value\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12:\n\x0bprice_value\x18\x06 \x01(\x0b\x32%.google.ads.googleads.v2.common.Money\x12\x33\n\x0einteger_values\x18\x07 \x03(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x32\n\x0e\x62oolean_values\x18\x08 \x03(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x33\n\rstring_values\x18\t \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rdouble_values\x18\n \x03(\x0b\x32\x1c.google.protobuf.DoubleValue\"\xb1\x07\n\x1d\x46\x65\x65\x64ItemPlaceholderPolicyInfo\x12\x61\n\x15placeholder_type_enum\x18\n \x01(\x0e\x32\x42.google.ads.googleads.v2.enums.PlaceholderTypeEnum.PlaceholderType\x12@\n\x1a\x66\x65\x65\x64_mapping_resource_name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12_\n\rreview_status\x18\x03 \x01(\x0e\x32H.google.ads.googleads.v2.enums.PolicyReviewStatusEnum.PolicyReviewStatus\x12\x65\n\x0f\x61pproval_status\x18\x04 \x01(\x0e\x32L.google.ads.googleads.v2.enums.PolicyApprovalStatusEnum.PolicyApprovalStatus\x12N\n\x14policy_topic_entries\x18\x05 \x03(\x0b\x32\x30.google.ads.googleads.v2.common.PolicyTopicEntry\x12o\n\x11validation_status\x18\x06 \x01(\x0e\x32T.google.ads.googleads.v2.enums.FeedItemValidationStatusEnum.FeedItemValidationStatus\x12U\n\x11validation_errors\x18\x07 \x03(\x0b\x32:.google.ads.googleads.v2.resources.FeedItemValidationError\x12\x7f\n\x17quality_approval_status\x18\x08 \x01(\x0e\x32^.google.ads.googleads.v2.enums.FeedItemQualityApprovalStatusEnum.FeedItemQualityApprovalStatus\x12\x89\x01\n\x1bquality_disapproval_reasons\x18\t \x03(\x0e\x32\x64.google.ads.googleads.v2.enums.FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason\"\xa6\x02\n\x17\x46\x65\x65\x64ItemValidationError\x12m\n\x10validation_error\x18\x01 \x01(\x0e\x32S.google.ads.googleads.v2.errors.FeedItemValidationErrorEnum.FeedItemValidationError\x12\x31\n\x0b\x64\x65scription\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x12\x66\x65\x65\x64_attribute_ids\x18\x03 \x03(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x30\n\nextra_info\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\xfa\x01\n%com.google.ads.googleads.v2.resourcesB\rFeedItemProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_custom__parameter__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_feed__common__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_policy__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__quality__approval__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__quality__disapproval__reason__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__validation__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_geo__targeting__restriction__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_placeholder__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_policy__approval__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_policy__review__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_feed__item__validation__error__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_FEEDITEM = _descriptor.Descriptor(
  name='FeedItem',
  full_name='google.ads.googleads.v2.resources.FeedItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.FeedItem.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed', full_name='google.ads.googleads.v2.resources.FeedItem.feed', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v2.resources.FeedItem.id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_date_time', full_name='google.ads.googleads.v2.resources.FeedItem.start_date_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_date_time', full_name='google.ads.googleads.v2.resources.FeedItem.end_date_time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute_values', full_name='google.ads.googleads.v2.resources.FeedItem.attribute_values', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_targeting_restriction', full_name='google.ads.googleads.v2.resources.FeedItem.geo_targeting_restriction', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url_custom_parameters', full_name='google.ads.googleads.v2.resources.FeedItem.url_custom_parameters', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v2.resources.FeedItem.status', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='policy_infos', full_name='google.ads.googleads.v2.resources.FeedItem.policy_infos', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=943,
  serialized_end=1623,
)


_FEEDITEMATTRIBUTEVALUE = _descriptor.Descriptor(
  name='FeedItemAttributeValue',
  full_name='google.ads.googleads.v2.resources.FeedItemAttributeValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_attribute_id', full_name='google.ads.googleads.v2.resources.FeedItemAttributeValue.feed_attribute_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='integer_value', full_name='google.ads.googleads.v2.resources.FeedItemAttributeValue.integer_value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='boolean_value', full_name='google.ads.googleads.v2.resources.FeedItemAttributeValue.boolean_value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='google.ads.googleads.v2.resources.FeedItemAttributeValue.string_value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='double_value', full_name='google.ads.googleads.v2.resources.FeedItemAttributeValue.double_value', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price_value', full_name='google.ads.googleads.v2.resources.FeedItemAttributeValue.price_value', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='integer_values', full_name='google.ads.googleads.v2.resources.FeedItemAttributeValue.integer_values', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='boolean_values', full_name='google.ads.googleads.v2.resources.FeedItemAttributeValue.boolean_values', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_values', full_name='google.ads.googleads.v2.resources.FeedItemAttributeValue.string_values', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='double_values', full_name='google.ads.googleads.v2.resources.FeedItemAttributeValue.double_values', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1626,
  serialized_end=2184,
)


_FEEDITEMPLACEHOLDERPOLICYINFO = _descriptor.Descriptor(
  name='FeedItemPlaceholderPolicyInfo',
  full_name='google.ads.googleads.v2.resources.FeedItemPlaceholderPolicyInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='placeholder_type_enum', full_name='google.ads.googleads.v2.resources.FeedItemPlaceholderPolicyInfo.placeholder_type_enum', index=0,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_mapping_resource_name', full_name='google.ads.googleads.v2.resources.FeedItemPlaceholderPolicyInfo.feed_mapping_resource_name', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='review_status', full_name='google.ads.googleads.v2.resources.FeedItemPlaceholderPolicyInfo.review_status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='approval_status', full_name='google.ads.googleads.v2.resources.FeedItemPlaceholderPolicyInfo.approval_status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='policy_topic_entries', full_name='google.ads.googleads.v2.resources.FeedItemPlaceholderPolicyInfo.policy_topic_entries', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validation_status', full_name='google.ads.googleads.v2.resources.FeedItemPlaceholderPolicyInfo.validation_status', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validation_errors', full_name='google.ads.googleads.v2.resources.FeedItemPlaceholderPolicyInfo.validation_errors', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quality_approval_status', full_name='google.ads.googleads.v2.resources.FeedItemPlaceholderPolicyInfo.quality_approval_status', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quality_disapproval_reasons', full_name='google.ads.googleads.v2.resources.FeedItemPlaceholderPolicyInfo.quality_disapproval_reasons', index=8,
      number=9, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2187,
  serialized_end=3132,
)


_FEEDITEMVALIDATIONERROR = _descriptor.Descriptor(
  name='FeedItemValidationError',
  full_name='google.ads.googleads.v2.resources.FeedItemValidationError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='validation_error', full_name='google.ads.googleads.v2.resources.FeedItemValidationError.validation_error', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='google.ads.googleads.v2.resources.FeedItemValidationError.description', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_attribute_ids', full_name='google.ads.googleads.v2.resources.FeedItemValidationError.feed_attribute_ids', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra_info', full_name='google.ads.googleads.v2.resources.FeedItemValidationError.extra_info', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3135,
  serialized_end=3429,
)

_FEEDITEM.fields_by_name['feed'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEEDITEM.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_FEEDITEM.fields_by_name['start_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEEDITEM.fields_by_name['end_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEEDITEM.fields_by_name['attribute_values'].message_type = _FEEDITEMATTRIBUTEVALUE
_FEEDITEM.fields_by_name['geo_targeting_restriction'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_geo__targeting__restriction__pb2._GEOTARGETINGRESTRICTIONENUM_GEOTARGETINGRESTRICTION
_FEEDITEM.fields_by_name['url_custom_parameters'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_custom__parameter__pb2._CUSTOMPARAMETER
_FEEDITEM.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__status__pb2._FEEDITEMSTATUSENUM_FEEDITEMSTATUS
_FEEDITEM.fields_by_name['policy_infos'].message_type = _FEEDITEMPLACEHOLDERPOLICYINFO
_FEEDITEMATTRIBUTEVALUE.fields_by_name['feed_attribute_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_FEEDITEMATTRIBUTEVALUE.fields_by_name['integer_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_FEEDITEMATTRIBUTEVALUE.fields_by_name['boolean_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_FEEDITEMATTRIBUTEVALUE.fields_by_name['string_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEEDITEMATTRIBUTEVALUE.fields_by_name['double_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_FEEDITEMATTRIBUTEVALUE.fields_by_name['price_value'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_feed__common__pb2._MONEY
_FEEDITEMATTRIBUTEVALUE.fields_by_name['integer_values'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_FEEDITEMATTRIBUTEVALUE.fields_by_name['boolean_values'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_FEEDITEMATTRIBUTEVALUE.fields_by_name['string_values'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEEDITEMATTRIBUTEVALUE.fields_by_name['double_values'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_FEEDITEMPLACEHOLDERPOLICYINFO.fields_by_name['placeholder_type_enum'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_placeholder__type__pb2._PLACEHOLDERTYPEENUM_PLACEHOLDERTYPE
_FEEDITEMPLACEHOLDERPOLICYINFO.fields_by_name['feed_mapping_resource_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEEDITEMPLACEHOLDERPOLICYINFO.fields_by_name['review_status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_policy__review__status__pb2._POLICYREVIEWSTATUSENUM_POLICYREVIEWSTATUS
_FEEDITEMPLACEHOLDERPOLICYINFO.fields_by_name['approval_status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_policy__approval__status__pb2._POLICYAPPROVALSTATUSENUM_POLICYAPPROVALSTATUS
_FEEDITEMPLACEHOLDERPOLICYINFO.fields_by_name['policy_topic_entries'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_policy__pb2._POLICYTOPICENTRY
_FEEDITEMPLACEHOLDERPOLICYINFO.fields_by_name['validation_status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__validation__status__pb2._FEEDITEMVALIDATIONSTATUSENUM_FEEDITEMVALIDATIONSTATUS
_FEEDITEMPLACEHOLDERPOLICYINFO.fields_by_name['validation_errors'].message_type = _FEEDITEMVALIDATIONERROR
_FEEDITEMPLACEHOLDERPOLICYINFO.fields_by_name['quality_approval_status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__quality__approval__status__pb2._FEEDITEMQUALITYAPPROVALSTATUSENUM_FEEDITEMQUALITYAPPROVALSTATUS
_FEEDITEMPLACEHOLDERPOLICYINFO.fields_by_name['quality_disapproval_reasons'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__quality__disapproval__reason__pb2._FEEDITEMQUALITYDISAPPROVALREASONENUM_FEEDITEMQUALITYDISAPPROVALREASON
_FEEDITEMVALIDATIONERROR.fields_by_name['validation_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_feed__item__validation__error__pb2._FEEDITEMVALIDATIONERRORENUM_FEEDITEMVALIDATIONERROR
_FEEDITEMVALIDATIONERROR.fields_by_name['description'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEEDITEMVALIDATIONERROR.fields_by_name['feed_attribute_ids'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_FEEDITEMVALIDATIONERROR.fields_by_name['extra_info'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['FeedItem'] = _FEEDITEM
DESCRIPTOR.message_types_by_name['FeedItemAttributeValue'] = _FEEDITEMATTRIBUTEVALUE
DESCRIPTOR.message_types_by_name['FeedItemPlaceholderPolicyInfo'] = _FEEDITEMPLACEHOLDERPOLICYINFO
DESCRIPTOR.message_types_by_name['FeedItemValidationError'] = _FEEDITEMVALIDATIONERROR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeedItem = _reflection.GeneratedProtocolMessageType('FeedItem', (_message.Message,), dict(
  DESCRIPTOR = _FEEDITEM,
  __module__ = 'google.ads.googleads_v2.proto.resources.feed_item_pb2'
  ,
  __doc__ = """A feed item.
  
  
  Attributes:
      resource_name:
          The resource name of the feed item. Feed item resource names
          have the form:
          ``customers/{customer_id}/feedItems/{feed_id}~{feed_item_id}``
      feed:
          The feed to which this feed item belongs.
      id:
          The ID of this feed item.
      start_date_time:
          Start time in which this feed item is effective and can begin
          serving. The time is in the customer's time zone. The format
          is "YYYY-MM-DD HH:MM:SS". Examples: "2018-03-05 09:15:00" or
          "2018-02-01 14:34:30"
      end_date_time:
          End time in which this feed item is no longer effective and
          will stop serving. The time is in the customer's time zone.
          The format is "YYYY-MM-DD HH:MM:SS". Examples: "2018-03-05
          09:15:00" or "2018-02-01 14:34:30"
      attribute_values:
          The feed item's attribute values.
      geo_targeting_restriction:
          Geo targeting restriction specifies the type of location that
          can be used for targeting.
      url_custom_parameters:
          The list of mappings used to substitute custom parameter tags
          in a ``tracking_url_template``, ``final_urls``, or
          ``mobile_final_urls``.
      status:
          Status of the feed item. This field is read-only.
      policy_infos:
          List of info about a feed item's validation and approval state
          for active feed mappings. There will be an entry in the list
          for each type of feed mapping associated with the feed, e.g. a
          feed with a sitelink and a call feed mapping would cause every
          feed item associated with that feed to have an entry in this
          list for both sitelink and call. This field is read-only.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.FeedItem)
  ))
_sym_db.RegisterMessage(FeedItem)

FeedItemAttributeValue = _reflection.GeneratedProtocolMessageType('FeedItemAttributeValue', (_message.Message,), dict(
  DESCRIPTOR = _FEEDITEMATTRIBUTEVALUE,
  __module__ = 'google.ads.googleads_v2.proto.resources.feed_item_pb2'
  ,
  __doc__ = """A feed item attribute value.
  
  
  Attributes:
      feed_attribute_id:
          Id of the feed attribute for which the value is associated
          with.
      integer_value:
          Int64 value. Should be set if feed\_attribute\_id refers to a
          feed attribute of type INT64.
      boolean_value:
          Bool value. Should be set if feed\_attribute\_id refers to a
          feed attribute of type BOOLEAN.
      string_value:
          String value. Should be set if feed\_attribute\_id refers to a
          feed attribute of type STRING, URL or DATE\_TIME. For STRING
          the maximum length is 1500 characters. For URL the maximum
          length is 2076 characters. For DATE\_TIME the format of the
          string must be the same as start and end time for the feed
          item.
      double_value:
          Double value. Should be set if feed\_attribute\_id refers to a
          feed attribute of type DOUBLE.
      price_value:
          Price value. Should be set if feed\_attribute\_id refers to a
          feed attribute of type PRICE.
      integer_values:
          Repeated int64 value. Should be set if feed\_attribute\_id
          refers to a feed attribute of type INT64\_LIST.
      boolean_values:
          Repeated bool value. Should be set if feed\_attribute\_id
          refers to a feed attribute of type BOOLEAN\_LIST.
      string_values:
          Repeated string value. Should be set if feed\_attribute\_id
          refers to a feed attribute of type STRING\_LIST, URL\_LIST or
          DATE\_TIME\_LIST. For STRING\_LIST and URL\_LIST the total
          size of the list in bytes may not exceed 3000. For
          DATE\_TIME\_LIST the number of elements may not exceed 200.
          For STRING\_LIST the maximum length of each string element is
          1500 characters. For URL\_LIST the maximum length is 2076
          characters. For DATE\_TIME the format of the string must be
          the same as start and end time for the feed item.
      double_values:
          Repeated double value. Should be set if feed\_attribute\_id
          refers to a feed attribute of type DOUBLE\_LIST.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.FeedItemAttributeValue)
  ))
_sym_db.RegisterMessage(FeedItemAttributeValue)

FeedItemPlaceholderPolicyInfo = _reflection.GeneratedProtocolMessageType('FeedItemPlaceholderPolicyInfo', (_message.Message,), dict(
  DESCRIPTOR = _FEEDITEMPLACEHOLDERPOLICYINFO,
  __module__ = 'google.ads.googleads_v2.proto.resources.feed_item_pb2'
  ,
  __doc__ = """Policy, validation, and quality approval info for a feed item for the
  specified placeholder type.
  
  
  Attributes:
      placeholder_type_enum:
          The placeholder type.
      feed_mapping_resource_name:
          The FeedMapping that contains the placeholder type.
      review_status:
          Where the placeholder type is in the review process.
      approval_status:
          The overall approval status of the placeholder type,
          calculated based on the status of its individual policy topic
          entries.
      policy_topic_entries:
          The list of policy findings for the placeholder type.
      validation_status:
          The validation status of the palceholder type.
      validation_errors:
          List of placeholder type validation errors.
      quality_approval_status:
          Placeholder type quality evaluation approval status.
      quality_disapproval_reasons:
          List of placeholder type quality evaluation disapproval
          reasons.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.FeedItemPlaceholderPolicyInfo)
  ))
_sym_db.RegisterMessage(FeedItemPlaceholderPolicyInfo)

FeedItemValidationError = _reflection.GeneratedProtocolMessageType('FeedItemValidationError', (_message.Message,), dict(
  DESCRIPTOR = _FEEDITEMVALIDATIONERROR,
  __module__ = 'google.ads.googleads_v2.proto.resources.feed_item_pb2'
  ,
  __doc__ = """Stores a validation error and the set of offending feed attributes which
  together are responsible for causing a feed item validation error.
  
  
  Attributes:
      validation_error:
          Error code indicating what validation error was triggered. The
          description of the error can be found in the 'description'
          field.
      description:
          The description of the validation error.
      feed_attribute_ids:
          Set of feed attributes in the feed item flagged during
          validation. If empty, no specific feed attributes can be
          associated with the error (e.g. error across the entire feed
          item).
      extra_info:
          Any extra information related to this error which is not
          captured by validation\_error and feed\_attribute\_id (e.g.
          placeholder field IDs when feed\_attribute\_id is not mapped).
          Note that extra\_info is not localized.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.FeedItemValidationError)
  ))
_sym_db.RegisterMessage(FeedItemValidationError)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
