# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/click_view.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.common import click_location_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_click__location__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/click_view.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\016ClickViewProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\n8google/ads/googleads_v1/proto/resources/click_view.proto\x12!google.ads.googleads.v1.resources\x1a\x39google/ads/googleads_v1/proto/common/click_location.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\x97\x02\n\tClickView\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12+\n\x05gclid\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12G\n\x10\x61rea_of_interest\x18\x03 \x01(\x0b\x32-.google.ads.googleads.v1.common.ClickLocation\x12K\n\x14location_of_presence\x18\x04 \x01(\x0b\x32-.google.ads.googleads.v1.common.ClickLocation\x12\x30\n\x0bpage_number\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\xfb\x01\n%com.google.ads.googleads.v1.resourcesB\x0e\x43lickViewProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_click__location__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_CLICKVIEW = _descriptor.Descriptor(
  name='ClickView',
  full_name='google.ads.googleads.v1.resources.ClickView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.ClickView.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gclid', full_name='google.ads.googleads.v1.resources.ClickView.gclid', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_of_interest', full_name='google.ads.googleads.v1.resources.ClickView.area_of_interest', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_of_presence', full_name='google.ads.googleads.v1.resources.ClickView.location_of_presence', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_number', full_name='google.ads.googleads.v1.resources.ClickView.page_number', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=217,
  serialized_end=496,
)

_CLICKVIEW.fields_by_name['gclid'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CLICKVIEW.fields_by_name['area_of_interest'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_click__location__pb2._CLICKLOCATION
_CLICKVIEW.fields_by_name['location_of_presence'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_click__location__pb2._CLICKLOCATION
_CLICKVIEW.fields_by_name['page_number'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
DESCRIPTOR.message_types_by_name['ClickView'] = _CLICKVIEW
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClickView = _reflection.GeneratedProtocolMessageType('ClickView', (_message.Message,), dict(
  DESCRIPTOR = _CLICKVIEW,
  __module__ = 'google.ads.googleads_v1.proto.resources.click_view_pb2'
  ,
  __doc__ = """A click view with metrics aggregated at each click level, including both
  valid and invalid clicks. For non-Search campaigns, metrics.clicks
  represents the number of valid and invalid interactions.
  
  
  Attributes:
      resource_name:
          The resource name of the click view. Click view resource names
          have the form:  ``customers/{customer_id}/clickViews/{date
          (yyyy-MM-dd)}~{gclid}``
      gclid:
          The Google Click ID.
      area_of_interest:
          The location criteria matching the area of interest associated
          with the impression.
      location_of_presence:
          The location criteria matching the location of presence
          associated with the impression.
      page_number:
          Page number in search results where the ad was shown.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.ClickView)
  ))
_sym_db.RegisterMessage(ClickView)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
