# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import ad_group_extension_setting_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__extension__setting__pb2
from google.ads.google_ads.v2.proto.services import ad_group_extension_setting_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__extension__setting__service__pb2


class AdGroupExtensionSettingServiceStub(object):
  """Proto file describing the AdGroupExtensionSetting service.

  Service to manage ad group extension settings.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetAdGroupExtensionSetting = channel.unary_unary(
        '/google.ads.googleads.v2.services.AdGroupExtensionSettingService/GetAdGroupExtensionSetting',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__extension__setting__service__pb2.GetAdGroupExtensionSettingRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__extension__setting__pb2.AdGroupExtensionSetting.FromString,
        )
    self.MutateAdGroupExtensionSettings = channel.unary_unary(
        '/google.ads.googleads.v2.services.AdGroupExtensionSettingService/MutateAdGroupExtensionSettings',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__extension__setting__service__pb2.MutateAdGroupExtensionSettingsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__extension__setting__service__pb2.MutateAdGroupExtensionSettingsResponse.FromString,
        )


class AdGroupExtensionSettingServiceServicer(object):
  """Proto file describing the AdGroupExtensionSetting service.

  Service to manage ad group extension settings.
  """

  def GetAdGroupExtensionSetting(self, request, context):
    """Returns the requested ad group extension setting in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateAdGroupExtensionSettings(self, request, context):
    """Creates, updates, or removes ad group extension settings. Operation
    statuses are returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_AdGroupExtensionSettingServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetAdGroupExtensionSetting': grpc.unary_unary_rpc_method_handler(
          servicer.GetAdGroupExtensionSetting,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__extension__setting__service__pb2.GetAdGroupExtensionSettingRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__extension__setting__pb2.AdGroupExtensionSetting.SerializeToString,
      ),
      'MutateAdGroupExtensionSettings': grpc.unary_unary_rpc_method_handler(
          servicer.MutateAdGroupExtensionSettings,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__extension__setting__service__pb2.MutateAdGroupExtensionSettingsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__extension__setting__service__pb2.MutateAdGroupExtensionSettingsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.AdGroupExtensionSettingService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
